@@ -1,34 +1,33 @@
 /*
  * © Copyright 1996-2012 ECMWF.
- * 
+ *
  * This software is licensed under the terms of the Apache Licence Version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
- * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-#include "mars.h"
 #include <errno.h>
+#include "mars.h"
 
 
+static err setargs(FILE* f, int n) {
+    if (n == 0)
+        return 0;
+    if (!(pop()))
+        return -1;
+    if (setargs(f, n - 1))
+        return -1;
+    abort();
 
-
-static err setargs(FILE *f,int n)
-{
-	if(n == 0)                return 0;
-	if(!(pop()))              return -1;
-	if(setargs(f,n-1))        return -1;
-	abort();
-
-	return 0;
+    return 0;
 }
 
 
-err extern_func(math *p)
-{
-	marslog(LOG_EROR,"Undefined function '%s' with %d arguments",p->name,p->arity);
-	return -1;
+err extern_func(math* p) {
+    marslog(LOG_EROR, "Undefined function '%s' with %d arguments", p->name, p->arity);
+    return -1;
 
 #if 0
 	char buf[1024];
