@@ -501,6 +501,15 @@ static option mars_opts[] = {
      sizeof(boolean),
      OFFSET(globals, gridded_observations_postproc)},
 
+
+    {"proxies",
+     "MARS_PROXIES",
+     "-proxies",
+     NULL,
+     t_str,
+     sizeof(char*),
+     OFFSET(globals, proxies)},
+
     /*
     #define SCHEDULE_FAIL   0x01
     #define SCHEDULE_INFORM 0x02
