@@ -12,8 +12,6 @@
 #include "mars_client_config.h"
 
 
-#include <iostream>
-
 //----------------------------------------------------------------------------------------------------------------------
 
 
@@ -169,7 +167,10 @@ int pproc_initialise(int argc, char** argv) {
 err pproc_print_version() {
     if (!valid_pproc())
         return POSTPROC_ERROR;
+
+    marslog(LOG_DBUG, "Post-processing backend is %s", pproc_name());
     pproc->print_version();
+
     return NOERR;
 }
 
