@@ -13,19 +13,17 @@
 #include "CellMethodInputVariable.h"
 #include "CellMethodOutputVariable.h"
 
-CellMethodInputVariable::CellMethodInputVariable(Field &owner, const std::string &name, int id, const std::vector<Dimension *> &dimensions):
-    InputVariable(owner, name, id, dimensions)
-{
+CellMethodInputVariable::CellMethodInputVariable(Field& owner, const std::string& name, int id, const std::vector<Dimension*>& dimensions) :
+    InputVariable(owner, name, id, dimensions) {
 }
 
 CellMethodInputVariable::~CellMethodInputVariable() {
 }
 
-Variable *CellMethodInputVariable::makeOutputVariable(Field &owner, const std::string &name, const std::vector<Dimension *> &dimensions) const {
+Variable* CellMethodInputVariable::makeOutputVariable(Field& owner, const std::string& name, const std::vector<Dimension*>& dimensions) const {
     return new CellMethodOutputVariable(owner, name, dimensions);
 }
 
-void CellMethodInputVariable::print(std::ostream &out) const {
+void CellMethodInputVariable::print(std::ostream& out) const {
     out << "CellMethodInputVariable[name=" << name_ << "]";
 }
-
