@@ -17,22 +17,19 @@
 
 #include <ostream>
 
-InputDimension::InputDimension(Field &owner, const std::string &name, int id, size_t len):
+InputDimension::InputDimension(Field& owner, const std::string& name, int id, size_t len) :
     Dimension(owner, name, len),
-    id_(id)
-{
+    id_(id) {
 }
 
-InputDimension::~InputDimension()
-{
-
+InputDimension::~InputDimension() {
 }
 
-void InputDimension::clone(Field &owner) const {
+void InputDimension::clone(Field& owner) const {
     owner.add(new OutputDimension(owner, name_, len_));
 }
 
-void InputDimension::print(std::ostream &out) const {
+void InputDimension::print(std::ostream& out) const {
     out << "InputDimension[name=" << name_ << "]";
 }
 
