@@ -600,12 +600,11 @@ void BufrJsonDumpWidget::dataDumpDoubleClicked(const QModelIndex&)
 void BufrJsonDumpWidget::slotCopyDumpKey()
 {
     QModelIndex index = tree_->currentIndex();
-    if (!index.isValid())
-        return;
-
-    QString name = index.data().toString();
-    if (!name.isEmpty()) {
-        MvQ::toClipboard(name);
+    if (index.isValid()) {
+        QString name = index.data().toString();
+        if (!name.isEmpty()) {
+            MvQ::toClipboard(name);
+        }
     }
 }
 
