@@ -15,13 +15,10 @@ class ActionCommand : public Command
 {
 public:
     ActionCommand(const std::string& name);
-    virtual ~ActionCommand();
+    ~ActionCommand() override;
+    ActionCommand(const ActionCommand&) = delete;
+    ActionCommand& operator=(const ActionCommand&) = delete;
 
-    virtual void execute(IconObject*);
+    void execute(IconObject*) override;
     static void execute(const std::string&, IconObject*);
-
-private:
-    // No copy allowed
-    ActionCommand(const ActionCommand&);
-    ActionCommand& operator=(const ActionCommand&);
 };
