@@ -19,7 +19,7 @@ public:
 
 private:
     std::set<Counted*> dead_;
-    virtual void run();
+    void run() override;
 };
 
 void CountedGC::push(Counted* c)
@@ -47,12 +47,6 @@ void CountedGC::run()
     }
 }
 
-
-Counted::Counted() :
-    count_(0)
-{
-}
-
 Counted::~Counted() = default;
 
 void Counted::attach()
