@@ -22,8 +22,8 @@
 class Drop : public QObject, public TaskObserver
 {
 public:
-    Drop(const std::set<IconObject*>&, const Request&, const std::string&, const Request&, QObject* obj = 0);
-    virtual ~Drop();
+    Drop(const std::set<IconObject*>&, const Request&, const std::string&, const Request&, QObject* obj = nullptr);
+    ~Drop() override;
 
     void start();
 
@@ -35,8 +35,8 @@ private:
     Drop& operator=(const Drop&);
 
     void check();
-    virtual void success(Task*, const Request&);
-    virtual void failure(Task*, const Request&);
+    void success(Task*, const Request&) override;
+    void failure(Task*, const Request&) override;
 
     Request request_;
     std::string service_;
