@@ -12,7 +12,7 @@
 #include <map>
 #include <string>
 
-//UKMO/HP/aCC:
+// UKMO/HP/aCC:
 #ifdef hp
 #include <MvQEditor.h>
 #endif
@@ -38,7 +38,7 @@ private:
 template <class T, class E>
 class EditorDrawerMaker : public EditorDrawerFactory
 {
-    EditorDrawer* make(MvQEditor* e)
+    EditorDrawer* make(MvQEditor* e) override
     {
         E* a = dynamic_cast<E*>(e);
         return a ? new T(a) : 0;
