@@ -34,7 +34,7 @@ public:
 
     static bool read(const Path& folderPath, std::map<std::string, std::string>& icons);
 
-protected:
+private:
     void read();
     void check();
     static void adjustIcName(std::string& icName);
