@@ -36,7 +36,7 @@ private:
 template <class T>
 class HelpMaker : public HelpFactory
 {
-    MvQRequestPanelHelp* make(RequestPanel& owner, const MvIconParameter& def) { return new T(owner, def); }
+    MvQRequestPanelHelp* make(RequestPanel& owner, const MvIconParameter& def) override { return new T(owner, def); }
 
 public:
     HelpMaker(const std::string& name) :
