@@ -15,14 +15,14 @@ class InternalService : public Service
 {
 public:
     InternalService();
-    virtual ~InternalService();
+    ~InternalService() override;
 
 private:
     // No copy allowed
     InternalService(const InternalService&);
     InternalService& operator=(const InternalService&);
 
-    virtual Task* task(const Action&, IconObject*);
+    Task* task(const Action&, IconObject*) override;
 };
 
 inline void destroy(InternalService**) {}
