@@ -14,12 +14,12 @@
 class MethodCommand : public Command
 {
 public:
-    typedef void (IconObject::*Proc)();
+    using Proc = void (IconObject::*)();
 
     MethodCommand(const std::string&, Proc);
-    virtual ~MethodCommand();
+    ~MethodCommand() override;
 
-    virtual void execute(IconObject*);
+    void execute(IconObject*) override;
     static void execute(const std::string&, IconObject*);
 
 protected:
