@@ -16,7 +16,7 @@ class QAction;
 class MvQActionList
 {
 public:
-    MvQActionList() {}
+    MvQActionList() = default;
     void add(QAction* ac) { lst_ << ac; }
     bool trigger(QString);
     QAction* action(QString);
