@@ -25,11 +25,11 @@ class MvQBoolLine : public MvQRequestPanelLine
 
 public:
     MvQBoolLine(RequestPanel& owner, const MvIconParameter& param);
-    ~MvQBoolLine();
+    ~MvQBoolLine() override;
 
-    QString currentValue() { return QString(); }
+    QString currentValue() { return {}; }
     void addValue(QString) {}
-    void refresh(const std::vector<std::string>&);
+    void refresh(const std::vector<std::string>&) override;
 
 public slots:
     void slotStatusChanged(bool);
