@@ -68,8 +68,8 @@ MvQDrawerPanel::MvQDrawerPanel(QWidget* parent) :
 
     bar_ = new MvQDrawerTabBar(this);
 
-    //bar_->setDrawBase(false);
-    //bar_->setDocumentMode(true);
+    // bar_->setDrawBase(false);
+    // bar_->setDocumentMode(true);
     bar_->setExpanding(true);
     barLayout_->addWidget(bar_);
 
@@ -88,15 +88,15 @@ MvQDrawerPanel::MvQDrawerPanel(QWidget* parent) :
     connect(bar_, SIGNAL(leftClicked(int)),
             this, SLOT(slotTabClicked(int)));
 
-    //Contextmenu
+    // Contextmenu
     bar_->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(bar_, SIGNAL(customContextMenuRequested(const QPoint&)),
             this, SLOT(slotContextMenu(const QPoint&)));
 
 
-    openIcon_  = QIcon(QPixmap(":/desktop/drawer_open.svg"));
+    openIcon_ = QIcon(QPixmap(":/desktop/drawer_open.svg"));
     closeIcon_ = QIcon(QPixmap(":/desktop/drawer_close.svg"));
-    noIcon_    = QIcon();
+    noIcon_ = QIcon();
 }
 
 MvQDrawerPanel::~MvQDrawerPanel() = default;
@@ -113,7 +113,7 @@ void MvQDrawerPanel::addDrawer(QWidget* w, QString name)
     bar_->addTab(name);
     stacked_->addWidget(w);
 
-    //Add tool button
+    // Add tool button
     auto* tb = new QToolButton(this);
     tb->setToolButtonStyle(Qt::ToolButtonIconOnly);
     tb->setAutoRaise(true);
@@ -166,18 +166,18 @@ void MvQDrawerPanel::sortDrawers()
     sorted = ori;
     sorted.sort();
 
-    //qDebug() << oriIdx;
-    //qDebug() << ori;
-    //qDebug() << sorted;
+    // qDebug() << oriIdx;
+    // qDebug() << ori;
+    // qDebug() << sorted;
 
     for (int i = 0; i < sorted.count(); i++) {
-        //qDebug() << i << sorted[i] <<bar_->tabText(i);
+        // qDebug() << i << sorted[i] <<bar_->tabText(i);
 
         if (sorted[i] != bar_->tabText(i)) {
             int from = oriIdx[sorted[i]];
-            int to   = i;
+            int to = i;
 
-            //qDebug() << "--> to from" << to << from;
+            // qDebug() << "--> to from" << to << from;
 
             bar_->moveTab(from, to);
 
@@ -211,7 +211,7 @@ int MvQDrawerPanel::drawerIndex(QWidget* w)
 
 QWidget* MvQDrawerPanel::drawer(int index)
 {
-    return (index >= 0 && index < stacked_->count()) ? stacked_->widget(index) : 0;
+    return (index >= 0 && index < stacked_->count()) ? stacked_->widget(index) : nullptr;
 }
 
 QString MvQDrawerPanel::drawerText(int index)
@@ -266,7 +266,7 @@ void MvQDrawerPanel::updateTabButtonStatus()
 
 void MvQDrawerPanel::slotTabButton()
 {
-    if (auto* w = static_cast<QWidget*>(sender())) {
+    if (auto* w = dynamic_cast<QWidget*>(sender())) {
         for (int i = 0; i < bar_->count(); i++)
             if (w == bar_->tabButton(i, QTabBar::RightSide)) {
                 slotTabClicked(i);
@@ -278,7 +278,7 @@ void MvQDrawerPanel::slotTabButton()
 void MvQDrawerPanel::setTabButtonStatus(int index, const QIcon& icon, QString txt)
 {
     if (QWidget* w = bar_->tabButton(index, QTabBar::RightSide))
-        if (auto* tb = static_cast<QToolButton*>(w)) {
+        if (auto* tb = dynamic_cast<QToolButton*>(w)) {
             tb->setIcon(icon);
             tb->setToolTip(txt);
         }
