@@ -24,9 +24,7 @@ MvQDrawerView::MvQDrawerView(MvQFolderModel* folderModel, QWidget* parent) :
     setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored);
 }
 
-MvQDrawerView::~MvQDrawerView()
-{
-}
+MvQDrawerView::~MvQDrawerView() = default;
 
 MvQContextItemSet* MvQDrawerView::cmSet()
 {
