@@ -20,10 +20,10 @@ class QSplitter;
 class MvQEcLayerDelegate : public QStyledItemDelegate
 {
 public:
-    MvQEcLayerDelegate(QWidget* parent = 0);
+    MvQEcLayerDelegate(QWidget* parent = nullptr);
     void paint(QPainter* painter, const QStyleOptionViewItem& option,
-               const QModelIndex& index) const;
-    QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const;
+               const QModelIndex& index) const override;
+    QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const override;
 
 protected:
     QColor borderCol_;
@@ -36,7 +36,7 @@ class MvQEcLayerTreeWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit MvQEcLayerTreeWidget(QWidget* parent = 0);
+    explicit MvQEcLayerTreeWidget(QWidget* parent = nullptr);
 
     void setLayer(MvQEcLayerDbItem* item);
     QTreeView* tree() const { return tree_; }
