@@ -11,7 +11,7 @@
 
 #include <QObject>
 
-#include <stdio.h>
+#include <cstdio>
 #include <string>
 
 
@@ -23,7 +23,7 @@ class MvQFileWatcher : public QObject
 
 public:
     MvQFileWatcher();
-    virtual ~MvQFileWatcher();
+    ~MvQFileWatcher() override;
 
     void start(FILE*, const std::string&);
     void stop();
