@@ -15,8 +15,7 @@
 class MvQFolderNavigation
 {
 public:
-    MvQFolderNavigation() :
-        pos_(-1), maxSize_(300) {}
+    MvQFolderNavigation() = default;
 
     void clear();
     bool isEmpty() const { return folders_.isEmpty(); }
@@ -34,6 +33,6 @@ protected:
     bool isPosCorrect();
 
     QStringList folders_;
-    int pos_;
-    int maxSize_;
+    int pos_{-1};
+    int maxSize_{300};
 };
