@@ -27,13 +27,13 @@ class QShortcut;
 class MvQIconHolderModel : public QAbstractItemModel
 {
 public:
-    MvQIconHolderModel(const std::vector<std::string>&, QObject* parent = 0);
+    MvQIconHolderModel(const std::vector<std::string>&, QObject* parent = nullptr);
 
-    int columnCount(const QModelIndex&) const;
-    int rowCount(const QModelIndex& parent = QModelIndex()) const;
-    QVariant data(const QModelIndex&, int role = Qt::DisplayRole) const;
-    QModelIndex index(int, int, const QModelIndex& parent = QModelIndex()) const;
-    QModelIndex parent(const QModelIndex&) const;
+    int columnCount(const QModelIndex&) const override;
+    int rowCount(const QModelIndex& parent = QModelIndex()) const override;
+    QVariant data(const QModelIndex&, int role = Qt::DisplayRole) const override;
+    QModelIndex index(int, int, const QModelIndex& parent = QModelIndex()) const override;
+    QModelIndex parent(const QModelIndex&) const override;
 
     void setIcons(const std::vector<IconObjectH>&);
     void clearIcons(const std::vector<IconObjectH>&);
@@ -54,8 +54,8 @@ class MvQIconHolderView : public QListView
     Q_OBJECT
 
 public:
-    MvQIconHolderView(MvQIconHolderModel*, RequestPanelItem*, QWidget* parent = 0);
-    ~MvQIconHolderView();
+    MvQIconHolderView(MvQIconHolderModel*, RequestPanelItem*, QWidget* parent = nullptr);
+    ~MvQIconHolderView() override;
 
 protected slots:
     void slotDoubleClickItem(const QModelIndex& index);
@@ -73,9 +73,9 @@ protected:
     void remove(IconObjectH);
     void command(QString, IconObjectH);
 
-    void dragEnterEvent(QDragEnterEvent*);
-    void dragMoveEvent(QDragMoveEvent*);
-    void dropEvent(QDropEvent*);
+    void dragEnterEvent(QDragEnterEvent*) override;
+    void dragMoveEvent(QDragMoveEvent*) override;
+    void dropEvent(QDropEvent*) override;
 
     MvQIconHolderModel* model_;
     std::vector<std::string> classes_;
