@@ -34,27 +34,27 @@ MvQIconLine::MvQIconLine(RequestPanel& owner, const MvIconParameter& param) :
     Request interface = param_.interfaceRequest();
 
     model_ = new MvQIconHolderModel(interface.get("class"), parentWidget_);
-    view_  = new MvQIconHolderView(model_, this, parentWidget_);
+    view_ = new MvQIconHolderView(model_, this, parentWidget_);
 
     const std::vector<std::string>& classes = interface.get("class");
 
     /*QString title(tr("Icons: "));
-	const std::vector<std::string>& classes=interface.get("class");
-	for(vector<std::string>::const_iterator it = classes.begin(); it != classes.end(); ++it)
-	{	
-	  	if(it != classes.begin())
-		{  
-			title+=", ";	  
-		}  
-	  	title+=QString::fromStdString(IconClass::find(*it).defaultName());
-	}*/
+    const std::vector<std::string>& classes=interface.get("class");
+    for(vector<std::string>::const_iterator it = classes.begin(); it != classes.end(); ++it)
+    {
+        if(it != classes.begin())
+        {
+            title+=", ";
+        }
+        title+=QString::fromStdString(IconClass::find(*it).defaultName());
+    }*/
 
-    //QLabel *titleLabel=new QLabel(title,parentWidget_);
+    // QLabel *titleLabel=new QLabel(title,parentWidget_);
 
     acceptLayout_ = buildAcceptLayout(classes);
 
-    //QLabel *titleLabel=new QLabel(parentWidget_);
-    //titleLabel->setPixmap(iconClassPixmap(classes));
+    // QLabel *titleLabel=new QLabel(parentWidget_);
+    // titleLabel->setPixmap(iconClassPixmap(classes));
 
     auto* layout = new QVBoxLayout(parentWidget_);
     layout->setSpacing(3);
@@ -66,7 +66,7 @@ MvQIconLine::MvQIconLine(RequestPanel& owner, const MvIconParameter& param) :
     layout->addLayout(acceptLayout_);
     layout->addWidget(view_);
 
-    owner_.addWidget(w, row_, 3);
+    owner_.addWidget(w, row_, WidgetColumn);
 
     connect(view_, SIGNAL(edited()),
             this, SLOT(slotHolderEdited()));
@@ -87,12 +87,12 @@ void MvQIconLine::reset()
     std::vector<IconObjectH> sub = currentObject_->subObjects(parName, r);
 
     grey();
-    //This will clear the unwanted iconobjects!!
+    // This will clear the unwanted iconobjects!!
     model_->setIcons(sub);
 
     mark(model_->rowCount() > 0);
 
-    //changed_ = false;
+    // changed_ = false;
 }
 
 void MvQIconLine::update()
@@ -113,19 +113,19 @@ void MvQIconLine::set(Request& r)
     currentObject_->setSubObjects(param_.name(), vals, r, true);
 }
 
-//Should be called when we close the editor
+// Should be called when we close the editor
 void MvQIconLine::cleanup()
 {
     if (!currentObject_)
         return;
 
-    //We read the saved request
+    // We read the saved request
     const Request& r = owner_.request();
 
     std::string parName(param_.name());
     std::vector<IconObjectH> sub = currentObject_->subObjects(parName, r);
 
-    //This will clear the unwanted iconObjects!!
+    // This will clear the unwanted iconObjects!!
     model_->clearIcons(sub);
 }
 
@@ -145,19 +145,19 @@ QHBoxLayout* MvQIconLine::buildAcceptLayout(const std::vector<std::string>& clas
     int pixSize = 16;
     for (const auto& classe : classes) {
         QPixmap pix = MvQIconProvider::pixmap(IconClass::find(classe), pixSize);
-        lw          = new QLabel(parentWidget_);
+        lw = new QLabel(parentWidget_);
         lw->setPixmap(pix);
         lw->setToolTip(QString::fromStdString(IconClass::find(classe).defaultName()));
         hb->addSpacing(4);
         hb->addWidget(lw);
 
-        //painter.drawPixmap(i*pixSize+i*pixGap,0,pix);
+        // painter.drawPixmap(i*pixSize+i*pixGap,0,pix);
     }
 
     hb->addStretch(1);
     return hb;
 
-    //return cpix;
+    // return cpix;
 }
 
 
