@@ -16,9 +16,9 @@ class MvQIconMimeData;
 class MvQIconStripView : public MvQListFolderViewBase
 {
 public:
-    MvQIconStripView(MvQFolderModel*, QWidget* parent = 0);
-    ~MvQIconStripView();
+    MvQIconStripView(MvQFolderModel*, QWidget* parent = nullptr);
+    ~MvQIconStripView() override;
 
 protected:
-    void performDrop(Qt::DropAction, const MvQIconMimeData*, QPoint, bool);
+    void performDrop(Qt::DropAction, const MvQIconMimeData*, QPoint, bool) override;
 };
