@@ -28,8 +28,17 @@ class MvQRequestPanelLine : public QObject, public RequestPanelItem
     Q_OBJECT
 
 public:
+    enum ColumnPos
+    {
+        DefaultColumn = 0,
+        NameColumn = 1,
+        ExpandColumn = 2,
+        WarningColumn = 3,
+        WidgetColumn = 4
+    };
+
     MvQRequestPanelLine(RequestPanel&, const MvIconParameter&, bool buildLine = true);
-    virtual ~MvQRequestPanelLine();
+    ~MvQRequestPanelLine() override;
 
     static MvQRequestPanelLine* build(RequestPanel&, const MvIconParameter&);
 
@@ -41,6 +50,8 @@ public:
     bool hasDefaultTb() override;
     bool isGray() const override { return gray_; }
     bool isVisibleByFilter() const override { return visibleByFilter_; }
+    void setWarningLabelStatus(bool st, QString msg={});
+    bool warningLabelStatus() const {return warningLabelStatus_;}
 
 public slots:
     void slotChangeToDefault(bool);
@@ -56,30 +67,24 @@ protected slots:
 
 protected:
     virtual void buildHelper();
-    //void setEnabled(bool);
+    // void setEnabled(bool);
     void setLineVisible(bool, bool forced);
     void setLineEnabled(bool);
     void adjustState(bool forced = false);
 
-    enum ColumnPos
-    {
-        DefaultColumn = 0,
-        NameColumn    = 1,
-        ExpandColumn  = 2,
-        WidgetColumn  = 3
-    };
-
     QToolButton* defaultTb_;
     QLabel* nameLabel_;
     QToolButton* helpTb_;
+    QLabel* warningLabel_{nullptr};
+    bool warningLabelStatus_{false};
     QString name_;
     QString source_;
     int row_;
 
     bool lineVisible_{true};
     bool gray_{false};
-    bool mark_{false};  //indicates that a non-default value is set
-    bool visibleByFilter_{true}; 
+    bool mark_{false};  // indicates that a non-default value is set
+    bool visibleByFilter_{true};
 
     MvQRequestPanelHelp* helper_;
     QWidget* parentWidget_;
