@@ -25,17 +25,17 @@ class MvQStringLine : public MvQRequestPanelLine
 
 public:
     MvQStringLine(RequestPanel& owner, const MvIconParameter& param);
-    ~MvQStringLine() = default;
+    ~MvQStringLine() override = default;
 
-    QString currentValue() { return QString(); }
+    QString currentValue() { return {}; }
     void addValue(QString) {}
 
-    void refresh(const std::vector<std::string>&);
+    void refresh(const std::vector<std::string>&) override;
 
 public slots:
     void slotCleared();
     void slotTextEdited(const QString&);
-    void slotHelperEdited(const std::vector<std::string>&);
+    void slotHelperEdited(const std::vector<std::string>&) override;
 
 protected:
     void dispatchChange();
