@@ -28,16 +28,16 @@ class MvQStyleLine : public MvQRequestPanelLine, public ParameterScanner
 
 public:
     MvQStyleLine(RequestPanel& owner, const MvIconParameter& param);
-    ~MvQStyleLine() {}
+    ~MvQStyleLine() override = default;
 
-    void refresh(const std::vector<std::string>&);
+    void refresh(const std::vector<std::string>&) override;
     void widgetClicked();
 
 public slots:
-    void slotHelperEdited(const std::vector<std::string>&);
+    void slotHelperEdited(const std::vector<std::string>&) override;
 
 protected:
-    void next(const MvIconParameter&, const char* first, const char* second);
+    void next(const MvIconParameter&, const char* first, const char* second) override;
     void updateHelper();
 
     QPixmap pix_;
