@@ -24,25 +24,25 @@ class MvQTemporaryEditor : public QDialog, public Editor
     Q_OBJECT
 
 public:
-    MvQTemporaryEditor(const IconClass& name, const std::string& kind, QWidget* parent = 0);
-    ~MvQTemporaryEditor();
+    MvQTemporaryEditor(const IconClass& name, const std::string& kind, QWidget* parent = nullptr);
+    ~MvQTemporaryEditor() override;
 
-    void changed();
+    void changed() override;
 
 public slots:
     void slotButtonClicked(QAbstractButton*);
-    void accept();
-    void reject();
+    void accept() override;
+    void reject() override;
 
 protected:
-    void raiseIt();
-    void showIt() { show(); }
-    void closeIt();
+    void raiseIt() override;
+    void showIt() override { show(); }
+    void closeIt() override;
     void updateHeader();
     virtual void apply() = 0;
     virtual void reset() = 0;
     virtual void close() = 0;
-    virtual void edit();
+    void edit() override;
 
     QLabel* headerLabel_;
     QHBoxLayout* centralLayout_;
