@@ -18,16 +18,16 @@
 class PythonGuiObject : public IconClass
 {
 public:
-    PythonGuiObject(const Request& lang, const IconClass* = 0);
-    virtual ~PythonGuiObject();
+    PythonGuiObject(const Request& lang, const IconClass* = nullptr);
+    ~PythonGuiObject() override;
 
 private:
     // No copy allowed
     PythonGuiObject(const PythonGuiObject&);
     PythonGuiObject& operator=(const PythonGuiObject&);
 
-    virtual MvIconLanguage& language() const;
-    virtual std::string editor() const;
+    MvIconLanguage& language() const override;
+    std::string editor() const override;
 
     MvIconLanguage lang_;
     IconMaker<StandardObject> maker_;
