@@ -31,7 +31,7 @@ void Queue::ownerGone()
 void Queue::push(Task* t)
 {
     t->add(this);
-    tasks_.push_back(t);
+    tasks_.emplace_back(t);
 
     enable();
 }
