@@ -48,16 +48,16 @@ long RequestPanelItem::flags()
     return EXPAND_2ND_NAME;
 }
 
-//void RequestPanelItem::refresh(const std::vector<std::string>&)
+// void RequestPanelItem::refresh(const std::vector<std::string>&)
 //{
-//}
+// }
 
 void RequestPanelItem::grey()
 {
-    const Request& r                = owner_.request(flags());
+    const Request& r = owner_.request(flags());
     std::vector<std::string> values = r.get("_UNSET");
-    bool g                          = false;
-    std::string name                = param_.name();
+    bool g = false;
+    std::string name = param_.name();
     for (auto& value : values)
         if (name == value) {
             g = true;
@@ -69,7 +69,7 @@ void RequestPanelItem::grey()
 
 void RequestPanelItem::reset()
 {
-    const Request& r                = owner_.request(flags());
+    const Request& r = owner_.request(flags());
     std::vector<std::string> values = r.get(param_.name());
 
     bool valChanged = (values != cache_);
@@ -101,7 +101,7 @@ void RequestPanelItem::update()
 
 void RequestPanelItem::checkDefault()
 {
-    const Request& r                = owner_.request(flags());
+    const Request& r = owner_.request(flags());
     std::vector<std::string> values = r.get(param_.name());
     mark(values != cache_);
 }
@@ -113,7 +113,7 @@ void RequestPanelItem::apply()
 void RequestPanelItem::decache()
 {
     cache_.clear();
-    cache_.push_back("\1\2\3");  // Something imposible
+    cache_.emplace_back("\1\2\3");  // Something imposible
 }
 
 /*void RequestPanelItem::mark(bool)
