@@ -10,14 +10,12 @@
 #include "ShellService.h"
 #include "ShellTask.h"
 
-ShellService::ShellService(const string& name) :
+ShellService::ShellService(const std::string& name) :
     Service(name)
 {
 }
 
-ShellService::~ShellService()
-{
-}
+ShellService::~ShellService() = default;
 
 Task* ShellService::task(const Action&, IconObject* o)
 {
