@@ -9,7 +9,7 @@
 
 #include "TeeBuffer.h"
 
-#include <stdio.h>
+#include <cstdio>
 
 TeeBuffer::TeeBuffer(std::ostream& one, std::ostream& two) :
     std::streambuf(),
