@@ -17,14 +17,14 @@ public:
     TemporaryFolder(Folder* parent, const IconClass& kind,
                     const std::string& name, IconInfo* info);
 
-    virtual ~TemporaryFolder();  // Change to virtual if base class
+    ~TemporaryFolder() override;  // Change to virtual if base class
 
 private:
     // No copy allowed
     TemporaryFolder(const TemporaryFolder&);
     TemporaryFolder& operator=(const TemporaryFolder&);
 
-    virtual void createFiles();
+    void createFiles() override;
 };
 
 inline void destroy(TemporaryFolder**) {}
