@@ -56,7 +56,7 @@ ViewEditor::ViewEditor(const IconClass& name, const std::string& kind) :
     MvQEditor(name, kind)
 {
     paper_ = new PaperSizeHandler;
-    snap_  = new GridSnapHandler;
+    snap_ = new GridSnapHandler;
 
     undoStack_ = new QUndoStack(this);
 
@@ -66,17 +66,17 @@ ViewEditor::ViewEditor(const IconClass& name, const std::string& kind) :
 
     QList<QToolButton*> tbLst;
 
-    //redo
+    // redo
     QAction* redoAc = undoStack_->createRedoAction(this, tr("&Redo"));
     redoAc->setShortcuts(QKeySequence::Redo);
     redoAc->setIcon(QPixmap(":/desktop/redo.svg"));
 
-    //undo
+    // undo
     QAction* undoAc = undoStack_->createUndoAction(this, tr("&Undo"));
     undoAc->setShortcuts(QKeySequence::Undo);
     undoAc->setIcon(QPixmap(":/desktop/undo.svg"));
 
-    //Duplicate
+    // Duplicate
     auto* duplicateAc = new QAction(this);
     duplicateAc->setToolTip(tr("Duplicate selected frames"));
     duplicateAc->setIcon(QPixmap(":/desktop/duplicate.svg"));
@@ -84,7 +84,7 @@ ViewEditor::ViewEditor(const IconClass& name, const std::string& kind) :
     connect(duplicateAc, SIGNAL(triggered(bool)),
             this, SLOT(slotDuplicateSelection(bool)));
 
-    //page setup
+    // page setup
     auto* pageAc = new QAction(this);
     pageAc->setToolTip(tr("Page setup"));
     pageAc->setIcon(QPixmap(":/desktop/page_setup.svg"));
@@ -138,7 +138,7 @@ ViewEditor::ViewEditor(const IconClass& name, const std::string& kind) :
     // Sidebar on the right
     //-----------------------
 
-    //Sidebar on the right
+    // Sidebar on the right
     auto* rightVb = new QVBoxLayout;
     rightVb->setSpacing(0);
     rightVb->setContentsMargins(1, 1, 1, 1);
@@ -193,8 +193,8 @@ ViewEditor::ViewEditor(const IconClass& name, const std::string& kind) :
     connect(expandAc, SIGNAL(triggered(bool)),
             this, SLOT(slotExpandSelection(bool)));
 
-    //connect(connectAc,SIGNAL(triggered(bool)),
-    //this,SLOT(slotConnectSelection(bool)));
+    // connect(connectAc,SIGNAL(triggered(bool)),
+    // this,SLOT(slotConnectSelection(bool)));
 
     connect(disconnectAc, SIGNAL(triggered(bool)),
             this, SLOT(slotDisconnectSelection(bool)));
@@ -215,8 +215,8 @@ ViewEditor::ViewEditor(const IconClass& name, const std::string& kind) :
     // View
     //--------------------
 
-    MvIconLanguage& lang                    = IconClass::find("PLOT_PAGE").language();
-    Request interface                       = lang.interfaceRequest("VIEW");
+    MvIconLanguage& lang = IconClass::find("PLOT_PAGE").language();
+    Request interface = lang.interfaceRequest("VIEW");
     const std::vector<std::string>& classes = interface.get("class");
 
     view_ = new MvQPageView(classes, undoStack_, this);
@@ -242,8 +242,8 @@ void ViewEditor::apply()
 
 void ViewEditor::reset()
 {
-    //cache_.clear();
-    //save_.clear();
+    // cache_.clear();
+    // save_.clear();
     request_ = current_->request();
     request_.print();
 
@@ -251,15 +251,15 @@ void ViewEditor::reset()
     loadPaperSize(request_);
     loadPages(current_, request_);
 
-    //PaperSetPages(paper_,loadPages(current_,request_));
-    //updateDrawers();
-    //PaperSelectFirst(paper_);
+    // PaperSetPages(paper_,loadPages(current_,request_));
+    // updateDrawers();
+    // PaperSelectFirst(paper_);
 }
 
 void ViewEditor::close()
 {
     view_->clear();
-    //save_.clear();
+    // save_.clear();
 }
 
 void ViewEditor::merge(IconObjectH /*o*/)
@@ -280,50 +280,50 @@ void ViewEditor::loadPaperSize(const Request& r)
 
     setPaperSize(h, w);
 
-    //cout << "h = " << h << " w = " << w << std::endl;
+    // cout << "h = " << h << " w = " << w << std::endl;
 
-    /*	
+    /*
   std::cout << "paperSize " << std::endl;
-	r.print();
+    r.print();
 
-	// Set paper size...
-	double w = r("CUSTOM_HEIGHT");
-	double h = r("CUSTOM_WIDTH");
+    // Set paper size...
+    double w = r("CUSTOM_HEIGHT");
+    double h = r("CUSTOM_WIDTH");
 
-	const char* size  = r("LAYOUT_SIZE");
-	const char* orien = r("LAYOUT_ORIENTATION");
+    const char* size  = r("LAYOUT_SIZE");
+    const char* orien = r("LAYOUT_ORIENTATION");
 
-	if(size && orien)
-	{  	
-		for(int i = 0; i < static_cast<int>(paperSizes_.size()) ; i++)
-		{
+    if(size && orien)
+    {
+        for(int i = 0; i < static_cast<int>(paperSizes_.size()) ; i++)
+        {
             if(paperSizes_[i].name() == std::string(size))
-			{
-				if(strcmp(orien,"PORTRAIT") == 0)
-				{
-					h = paperSizes_[i].height();
-					w = paperSizes_[i].width();
-					break;
-				}
-				else
-				{
-					w = paperSizes_[i].height();
-					h = paperSizes_[i].width();
-					break;
-				}	
-			}
-		}	
-	}
+            {
+                if(strcmp(orien,"PORTRAIT") == 0)
+                {
+                    h = paperSizes_[i].height();
+                    w = paperSizes_[i].width();
+                    break;
+                }
+                else
+                {
+                    w = paperSizes_[i].height();
+                    h = paperSizes_[i].width();
+                    break;
+                }
+            }
+        }
+    }
 
-	paperSizeReq_("LAYOUT_SIZE")=size;
-	paperSizeReq_("LAYOUT_SIZE")=orien;
-	paperSizeReq_("CUSTOM_HEIGHT")=h;
-	paperSizeReq_("CUSTOM_WIDTH")=w;
-	
-	setPaperSize(h,w);
+    paperSizeReq_("LAYOUT_SIZE")=size;
+    paperSizeReq_("LAYOUT_SIZE")=orien;
+    paperSizeReq_("CUSTOM_HEIGHT")=h;
+    paperSizeReq_("CUSTOM_WIDTH")=w;
 
-	cout << "h = " << h << " w = " << w << std::endl;
-	*/
+    setPaperSize(h,w);
+
+    cout << "h = " << h << " w = " << w << std::endl;
+    */
 }
 
 void ViewEditor::savePaperSize(Request& r)
@@ -343,7 +343,7 @@ PageView* ViewEditor::pageView(IconObject* o)
 
 void ViewEditor::loadPages(IconObject* o, const Request& r)
 {
-    //Clear the view
+    // Clear the view
 
     std::vector<IconObjectH> sub = o->subObjects("PAGES", r);
 
@@ -352,10 +352,10 @@ void ViewEditor::loadPages(IconObject* o, const Request& r)
 
         pageReq.print();
 
-        double top            = pageReq("TOP");
-        double left           = pageReq("LEFT");
-        double right          = pageReq("RIGHT");
-        double bottom         = pageReq("BOTTOM");
+        double top = pageReq("TOP");
+        double left = pageReq("LEFT");
+        double right = pageReq("RIGHT");
+        double bottom = pageReq("BOTTOM");
         MvQPageItem* pageItem = view_->addPage(left, top, right - left, bottom - top);
 
         std::vector<IconObjectH> viewVec = itPage->subObjects("VIEW", pageReq);
@@ -372,34 +372,34 @@ void ViewEditor::loadSubPages(MvQPageItem* p, IconObject* o, const Request& r)
     // Old style
 
     /*int rows = r("ROWS");
-	int cols = r("COLUMNS");
+    int cols = r("COLUMNS");
 
-	if(rows * cols > 1)
-	{
-		double height = 1.0 / rows;pageItem
-		double width  = 1.0 / cols;
-		double x = 0;
+    if(rows * cols > 1)
+    {
+        double height = 1.0 / rows;pageItem
+        double width  = 1.0 / cols;
+        double x = 0;
 
-		for(int i = 0; i < cols; i++) 
-		{
-			double y = 0;
-			for(int j = 0; j < rows; j++)
-			{
-				PaperRectangle* s = PaperNewPage(
-					paper_,
-					y, 
-					x, 
-					(j == rows - 1) ? 1.0 : y + height, 
-					(i == cols - 1) ? 1.0 : x + width
-					);
+        for(int i = 0; i < cols; i++)
+        {
+            double y = 0;
+            for(int j = 0; j < rows; j++)
+            {
+                PaperRectangle* s = PaperNewPage(
+                    paper_,
+                    y,
+                    x,
+                    (j == rows - 1) ? 1.0 : y + height,
+                    (i == cols - 1) ? 1.0 : x + width
+                    );
 
-				s->next = pages;
-				pages = s;
-				y += height;
-			}
-			x +=  width;
-		}
-	}*/
+                s->next = pages;
+                pages = s;
+                y += height;
+            }
+            x +=  width;
+        }
+    }*/
 
     // New Style
     std::vector<IconObjectH> sub = o->subObjects("SUB_PAGES", r);
@@ -408,9 +408,9 @@ void ViewEditor::loadSubPages(MvQPageItem* p, IconObject* o, const Request& r)
 
         subR.print();
 
-        double top    = subR("TOP");
-        double left   = subR("LEFT");
-        double right  = subR("RIGHT");
+        double top = subR("TOP");
+        double left = subR("LEFT");
+        double right = subR("RIGHT");
         double bottom = subR("BOTTOM");
 
         p->addSubPaperRectInPageCoords(left, top, right - left, bottom - top);
@@ -437,7 +437,7 @@ void ViewEditor::savePages(IconObject* o, Request& r)
 
         pageReq.print();
 
-        IconObjectH page      = IconFactory::create(pageFolder, pageReq, 0, 0);
+        IconObjectH page = IconFactory::create(pageFolder, pageReq, 0, 0);
         FolderH subPageFolder = page->embeddedFolder("Sub Pages", true);
         pages.push_back(page);
 
@@ -447,7 +447,7 @@ void ViewEditor::savePages(IconObject* o, Request& r)
             Request subReq("PLOT_SUBPAGE");
             saveRectToRequest(subRect, subReq);
             subReq.print();
-            subpages.push_back(IconFactory::create(subPageFolder, subReq, 0, 0));
+            subpages.emplace_back(IconFactory::create(subPageFolder, subReq, 0, 0));
         }
 
         page->setSubObjects("SUB_PAGES", subpages, pageReq);
@@ -467,15 +467,15 @@ void ViewEditor::savePages(IconObject* o, Request& r)
 
 void ViewEditor::saveRectToRequest(QRectF rect, Request& r)
 {
-    double top    = rect.y();
-    double left   = rect.x();
+    double top = rect.y();
+    double left = rect.x();
     double bottom = rect.bottomLeft().y();
-    double right  = rect.topRight().x();
+    double right = rect.topRight().x();
 
-    r("TOP")    = top;
-    r("LEFT")   = left;
+    r("TOP") = top;
+    r("LEFT") = left;
     r("BOTTOM") = bottom;
-    r("RIGHT")  = right;
+    r("RIGHT") = right;
 }
 
 IconObject* ViewEditor::defaultView()
@@ -490,24 +490,24 @@ void ViewEditor::updateButtonStatus(int /*selected*/)
     return;
 
     /*if(selected ==0)
-	{
-	  	joinAc->setEnabled(false);
-		splitAc->setEnabled(false);
-  		deleteAc->setEnabled(false);
-		expandAc->setEnabled(false);
-	}
-	
-	else
-	{
-		splitAc->setEnabled(true);
-  		deleteAc->setEnabled(true);
-		expandAc->setEnabled(true);
-		
-		if(selected > 1)
-		  	joinAc->setEnabled(true);
-		else
-		  	joinAc->setEnabled(false);
-	}*/
+    {
+        joinAc->setEnabled(false);
+        splitAc->setEnabled(false);
+        deleteAc->setEnabled(false);
+        expandAc->setEnabled(false);
+    }
+
+    else
+    {
+        splitAc->setEnabled(true);
+        deleteAc->setEnabled(true);
+        expandAc->setEnabled(true);
+
+        if(selected > 1)
+            joinAc->setEnabled(true);
+        else
+            joinAc->setEnabled(false);
+    }*/
 }
 
 
@@ -611,7 +611,7 @@ void ViewEditor::readSettings(QSettings& settings)
     if (!v.isNull())
         gridAc_->setChecked(v.toBool());
 
-    v           = settings.value("grid_x");
+    v = settings.value("grid_x");
     QVariant v1 = settings.value("grid_y");
 
     if (!v.isNull() && !v1.isNull()) {
@@ -650,7 +650,7 @@ void ViewEditor::writeSettings(QSettings& settings)
 
 PaperSizeHandler::PaperSizeHandler() :
     orientation_("Landscape"),
-    current_(0)
+    current_(nullptr)
 {
     if (std_.size() == 0) {
         std_.push_back(new PaperSize("A4", 21, 29.7, "PORTRAIT"));
@@ -670,7 +670,7 @@ void PaperSizeHandler::set(const Request& r)
     double h = r("CUSTOM_HEIGHT");
     double w = r("CUSTOM_WIDTH");
 
-    const char* size  = r("LAYOUT_SIZE");
+    const char* size = r("LAYOUT_SIZE");
     const char* orien = r("LAYOUT_ORIENTATION");
 
     std::string sizeStr = "A4";
@@ -685,7 +685,7 @@ void PaperSizeHandler::set(const Request& r)
     for (auto& i : std_) {
         if (i->name() == sizeStr && i->orientation() == orientation_) {
             current_ = i;
-            found    = true;
+            found = true;
             break;
         }
     }
@@ -705,7 +705,7 @@ void PaperSizeHandler::set(const std::string& sizeStr, const std::string& orien,
     for (auto& i : std_) {
         if (i->name() == sizeStr && i->orientation() == orien) {
             current_ = i;
-            found    = true;
+            found = true;
             break;
         }
     }
@@ -719,8 +719,8 @@ void PaperSizeHandler::set(const std::string& sizeStr, const std::string& orien,
 
 void PaperSizeHandler::save(Request& r)
 {
-    r("LAYOUT_SIZE")   = current_->name().c_str();
-    r("CUSTOM_WIDTH")  = current_->width();
+    r("LAYOUT_SIZE") = current_->name().c_str();
+    r("CUSTOM_WIDTH") = current_->width();
     r("CUSTOM_HEIGHT") = current_->height();
 
     if (current_ != custom_) {
@@ -757,7 +757,7 @@ GridSnapHandler::GridSnapHandler()
     float v[] = {1, 2, 4, 5, 10, 12, 5, 20, 25, 50};
     vals_.assign(v, v + sizeof(v) / sizeof(v[0]));
 
-    //vals_ << 1 << 2 << 4 << 5 << 10 << 12.5 << 20 << 25 << 50;
+    // vals_ << 1 << 2 << 4 << 5 << 10 << 12.5 << 20 << 25 << 50;
     xIndex_ = 3;
     yIndex_ = 3;
 }
@@ -811,14 +811,14 @@ MvQPaperSizeWidget::MvQPaperSizeWidget(PaperSizeHandler* paper, QWidget* parent)
 
     int row = 0;
 
-    //Size
-    label   = new QLabel(tr("&Size:"));
+    // Size
+    label = new QLabel(tr("&Size:"));
     sizeCb_ = new QComboBox;
     label->setBuddy(sizeCb_);
 
     std::set<std::string> nameSet;
     for (auto it : paper_->stdSizes()) {
-        //We do not allow duplicated names
+        // We do not allow duplicated names
         if (nameSet.find(it->name()) == nameSet.end()) {
             sizeCb_->addItem(QString::fromStdString(it->name()));
             sizeCb_->setItemData(sizeCb_->count() - 1, QString::fromStdString(it->name()));
@@ -833,9 +833,9 @@ MvQPaperSizeWidget::MvQPaperSizeWidget(PaperSizeHandler* paper, QWidget* parent)
     grid->addWidget(sizeCb_, row, 1);
     row++;
 
-    //orientation
+    // orientation
     oriLabel_ = new QLabel(tr("&Orientation:"));
-    oriCb_    = new QComboBox;
+    oriCb_ = new QComboBox;
     oriLabel_->setBuddy(oriCb_);
 
     oriCb_->addItem(tr("Portrait"));
@@ -848,18 +848,18 @@ MvQPaperSizeWidget::MvQPaperSizeWidget(PaperSizeHandler* paper, QWidget* parent)
     grid->addWidget(oriCb_, row, 1);
     row++;
 
-    //width
+    // width
     widthLabel_ = new QLabel(tr("&Width:"));
-    widthEdit_  = new QLineEdit;
+    widthEdit_ = new QLineEdit;
     widthLabel_->setBuddy(widthEdit_);
 
     grid->addWidget(widthLabel_, row, 0);
     grid->addWidget(widthEdit_, row, 1);
     row++;
 
-    //height
+    // height
     heightLabel_ = new QLabel(tr("&Height:"));
-    heightEdit_  = new QLineEdit;
+    heightEdit_ = new QLineEdit;
     heightLabel_->setBuddy(heightEdit_);
 
     grid->addWidget(heightLabel_, row, 0);
@@ -870,7 +870,7 @@ MvQPaperSizeWidget::MvQPaperSizeWidget(PaperSizeHandler* paper, QWidget* parent)
     // Init
     //----------------------------------
 
-    //Size
+    // Size
     if (paper_->isCustom()) {
         sizeCb_->setCurrentIndex(sizeCb_->count() - 1);
     }
@@ -883,20 +883,20 @@ MvQPaperSizeWidget::MvQPaperSizeWidget(PaperSizeHandler* paper, QWidget* parent)
         }
     }
 
-    //Orientation
+    // Orientation
     if (paper_->orientation() == "PORTRAIT")
         oriCb_->setCurrentIndex(0);
     else
         oriCb_->setCurrentIndex(1);
 
-    //Width and height
+    // Width and height
     widthEdit_->setText(QString::number(paper_->width()));
     heightEdit_->setText(QString::number(paper_->height()));
 
-    //State
+    // State
     updateState();
 
-    //Combo box signals
+    // Combo box signals
     connect(sizeCb_, SIGNAL(currentIndexChanged(int)),
             this, SLOT(slotSize(int)));
 }
@@ -905,7 +905,7 @@ void MvQPaperSizeWidget::updateState()
 {
     int index = sizeCb_->currentIndex();
 
-    //A4, A3, ...
+    // A4, A3, ...
     if (sizeCb_->itemData(index).toString() != "CUSTOM") {
         oriLabel_->setEnabled(true);
         oriCb_->setEnabled(true);
@@ -932,7 +932,7 @@ void MvQPaperSizeWidget::slotSize(int)
 void MvQPaperSizeWidget::accept()
 {
     int sizeIndex = sizeCb_->currentIndex();
-    int oriIndex  = oriCb_->currentIndex();
+    int oriIndex = oriCb_->currentIndex();
 
     if (sizeIndex >= 0 && sizeIndex < sizeCb_->count() &&
         oriIndex >= 0 && oriIndex < oriCb_->count()) {
@@ -962,17 +962,17 @@ MvQGridSnapWidget::MvQGridSnapWidget(GridSnapHandler* snap, QWidget* parent) :
 
     int row = 0;
 
-    //x
+    // x
     label = new QLabel(tr("&X grid step:"), this);
-    xCb_  = new QComboBox(this);
+    xCb_ = new QComboBox(this);
     label->setBuddy(xCb_);
     grid->addWidget(label, row, 0);
     grid->addWidget(xCb_, row, 1);
     row++;
 
-    //y
+    // y
     label = new QLabel(tr("&Y grid step:"), this);
-    yCb_  = new QComboBox(this);
+    yCb_ = new QComboBox(this);
     label->setBuddy(yCb_);
     grid->addWidget(label, row, 0);
     grid->addWidget(yCb_, row, 1);
@@ -1033,10 +1033,10 @@ MvQPageSetupDialog::MvQPageSetupDialog(PaperSizeHandler* paperH, GridSnapHandler
     connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
     connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
 
-    //Try to find the optimal dialog width
+    // Try to find the optimal dialog width
     QFont font;
     QFontMetrics fm(font);
-    //setMinimumWidth(fm.width(tr("Orientation:  landscape"))+100);
+    // setMinimumWidth(fm.width(tr("Orientation:  landscape"))+100);
 
     vb->addWidget(buttonBox);
 }
@@ -1071,7 +1071,7 @@ MvQSplitDialog::MvQSplitDialog(QWidget* parent) :
     auto* vb = new QVBoxLayout;
     setLayout(vb);
 
-    //Mode selector
+    // Mode selector
     auto* modeFrame = new QFrame(this);
     modeFrame->setFrameShape(QFrame::StyledPanel);
 
@@ -1081,7 +1081,7 @@ MvQSplitDialog::MvQSplitDialog(QWidget* parent) :
     vb->addSpacing(4);
 
     auto* label = new QLabel(tr("Selection mode:"));
-    modeCb_     = new QComboBox(this);
+    modeCb_ = new QComboBox(this);
     modeCb_->addItem(tr("Manual"));
     modeCb_->addItem(tr("Graphical"));
     hb->addWidget(label);
@@ -1095,21 +1095,21 @@ MvQSplitDialog::MvQSplitDialog(QWidget* parent) :
     // Manual mode
     //---------------------------
 
-    auto* w       = new QWidget(this);
+    auto* w = new QWidget(this);
     auto* mLayout = new QVBoxLayout();
     w->setLayout(mLayout);
     auto* mgLayout = new QGridLayout();
     mLayout->addLayout(mgLayout);
     mLayout->addStretch(1);
 
-    //rows
+    // rows
     label = new QLabel(tr("Number of rows:"), this);
     mgLayout->addWidget(label, 0, 0);
     rowSpin_ = new QSpinBox(this);
     rowSpin_->setRange(1, maxRow_);
     mgLayout->addWidget(rowSpin_, 0, 1);
 
-    //columns
+    // columns
     label = new QLabel(tr("Number of columns:"), this);
     mgLayout->addWidget(label, 1, 0);
     colSpin_ = new QSpinBox(this);
@@ -1122,7 +1122,7 @@ MvQSplitDialog::MvQSplitDialog(QWidget* parent) :
     // Graphical mode
     //---------------------------
 
-    w             = new QWidget(this);
+    w = new QWidget(this);
     auto* gLayout = new QVBoxLayout;
     w->setLayout(gLayout);
 
@@ -1135,15 +1135,15 @@ MvQSplitDialog::MvQSplitDialog(QWidget* parent) :
 
     stacked_->addWidget(w);
 
-    //Initialise combo and stacked
-    //The default is the graphical mode
+    // Initialise combo and stacked
+    // The default is the graphical mode
     modeCb_->setCurrentIndex(1);
     stacked_->setCurrentIndex(1);
     updateLabel();
 
-    //Signals and slots
+    // Signals and slots
 
-    //Connect the combobox and the stacked widget to change the mode
+    // Connect the combobox and the stacked widget to change the mode
     connect(modeCb_, SIGNAL(currentIndexChanged(int)),
             this, SLOT(slotChangeMode(int)));
 
@@ -1162,17 +1162,17 @@ MvQSplitDialog::MvQSplitDialog(QWidget* parent) :
     connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
     connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
 
-    //Try to find the optimal dialog width
+    // Try to find the optimal dialog width
     QFont font;
     QFontMetrics fm(font);
     setMinimumWidth(MvQ::textWidth(fm, tr("Columns")) + 100);
 
     vb->addWidget(buttonBox);
 
-    //Read in the settings
+    // Read in the settings
     readSettings();
 
-    //This will properly initialise everything
+    // This will properly initialise everything
     slotChangeMode(modeCb_->currentIndex());
 }
 
@@ -1220,10 +1220,10 @@ void MvQSplitDialog::slotColumnChanged(int column)
     column_ = column - 1;
 }
 
-//From the grid selector
+// From the grid selector
 void MvQSplitDialog::slotSelectionChanged(int row, int column)
 {
-    row_    = row;
+    row_ = row;
     column_ = column;
     updateLabel();
 }
@@ -1237,7 +1237,7 @@ void MvQSplitDialog::writeSettings()
 {
     QSettings settings(MVQ_QSETTINGS_DEFAULT_ARGS "MV4-Desktop-SplitDialog");
 
-    //We have to clear it so that should not remember all the previous values
+    // We have to clear it so that should not remember all the previous values
     settings.clear();
 
     settings.beginGroup("main");
@@ -1301,8 +1301,8 @@ MvQGridSelector::MvQGridSelector(int row, int column, int rowNum, int colNum, QW
     dy_(5)
 {
     selectedColour_ = QColor(151, 193, 219);
-    rectColour_     = QColor(210, 210, 210);
-    frameColour_    = rectColour_.darker(120);
+    rectColour_ = QColor(210, 210, 210);
+    frameColour_ = rectColour_.darker(120);
 
     setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum));
     setMinimumSize(QSize(128, 128));
@@ -1312,16 +1312,16 @@ MvQGridSelector::MvQGridSelector(int row, int column, int rowNum, int colNum, QW
 
 void MvQGridSelector::setGridSize(int row, int col)
 {
-    rowNum_    = row;
+    rowNum_ = row;
     columnNum_ = col;
-    row_       = 0;
-    column_    = 0;
+    row_ = 0;
+    column_ = 0;
     update();
 }
 
 void MvQGridSelector::setSelection(int row, int col)
 {
-    row_    = row;
+    row_ = row;
     column_ = col;
 
     if (row_ >= rowNum_) {
@@ -1340,8 +1340,8 @@ void MvQGridSelector::resizeEvent(QResizeEvent* /*event*/)
 {
     int w = width();
     int h = height();
-    //gridSize_=(w<h)?w:h;
-    //cellSize_=gridSize_/cellsPerRow_;
+    // gridSize_=(w<h)?w:h;
+    // cellSize_=gridSize_/cellsPerRow_;
     dx_ = (w - 2 * offset_) / columnNum_;
     dy_ = (h - 2 * offset_) / rowNum_;
 }
@@ -1375,7 +1375,7 @@ bool MvQGridSelector::select(QPoint pos)
     if (row >= 0 && row < rowNum_ &&
         col >= 0 && col < columnNum_ &&
         (row != row_ || col != column_)) {
-        row_    = row;
+        row_ = row;
         column_ = col;
         emit changed(row_, column_);
         return true;
