@@ -26,8 +26,8 @@
 #include <unistd.h>
 #include <sys/types.h>
 #include <dirent.h>
-#include <errno.h>
-#include <assert.h>
+#include <cerrno>
+#include <cassert>
 
 //#define FLEXPART_CHK(str) if(!(str)) return false
 #define FLEXPART_CHK(str) ({if(!(str)) {setError(13); return false;} })
@@ -43,12 +43,10 @@ class FlexpartRun : public Base
 {
 public:
     FlexpartRun() :
-        Base("FLEXPART_RUN"),
-        forward_(true),
-        receptorNum_(0) { initIds(); }
-    void serve(MvRequest&, MvRequest&);
+        Base("FLEXPART_RUN") { initIds(); }
+    void serve(MvRequest&, MvRequest&) override;
 
-protected:
+private:
     void initIds();
     std::string getReleaseDate(const std::string&, const std::string&);
     bool generatePathnamesFile(const std::string&, MvRequest&, const std::string&, const std::string&);
@@ -68,13 +66,13 @@ protected:
     std::map<std::string, std::string> relLevelUnitsIds_;
     std::map<std::string, std::string> domainFillIds_;
     std::string runDate_;
-    bool forward_;
-    int receptorNum_;
+    bool forward_{true};
+    int receptorNum_{0};
 };
 
 void FlexpartRun::initIds()
 {
-    directionIds_["FORWARD"]  = "1";
+    directionIds_["FORWARD"] = "1";
     directionIds_["BACKWARD"] = "-1";
 
 #if 0
@@ -85,11 +83,11 @@ void FlexpartRun::initIds()
 	outputIds_["CONCENTRATION AND PLUME"]="5";
 #endif
 
-    particleDumpIds_["NO"]        = "0";
+    particleDumpIds_["NO"] = "0";
     particleDumpIds_["AT_OUTPUT"] = "1";
-    particleDumpIds_["AT_END"]    = "2";
+    particleDumpIds_["AT_END"] = "2";
 
-    onOffIds_["ON"]  = "1";
+    onOffIds_["ON"] = "1";
     onOffIds_["OFF"] = "0";
 
     sourceUnitsIds_["MASS"] = "1";
@@ -98,7 +96,7 @@ void FlexpartRun::initIds()
     receptorUnitsIds_["MASS"] = "1";
     receptorUnitsIds_["MIXR"] = "2";
 
-    writeInitIds_["NO"]   = "0";
+    writeInitIds_["NO"] = "0";
     writeInitIds_["MASS"] = "1";
     writeInitIds_["MIXR"] = "2";
 
@@ -106,8 +104,8 @@ void FlexpartRun::initIds()
     relLevelUnitsIds_["ASL"] = "2";
     relLevelUnitsIds_["HPA"] = "3";
 
-    domainFillIds_["NO"]        = "0";
-    domainFillIds_["FULL"]      = "1";
+    domainFillIds_["NO"] = "0";
+    domainFillIds_["FULL"] = "1";
     domainFillIds_["O3_TRACER"] = "2";
 }
 
@@ -132,9 +130,9 @@ bool FlexpartRun::generatePathnamesFile(const std::string& fPathnames, MvRequest
 
     MvRequest dataR = in("INPUT_DATA");
 
-    //No icon is specified
+    // No icon is specified
     if (!dataR) {
-        //These can be relative paths
+        // These can be relative paths
         FLEXPART_CHK(in.getPath("INPUT_PATH", inPath, false));
         FLEXPART_CHK(in.getValue("AVAILABLE_FILE_PATH", fAvailable, true));
 
@@ -153,12 +151,12 @@ bool FlexpartRun::generatePathnamesFile(const std::string& fPathnames, MvRequest
             return false;
         }
 
-        //These must be absolute paths
+        // These must be absolute paths
         FLEXPART_CHK(dataR.getValue("INPUT_DATA_PATH", inPath));
         FLEXPART_CHK(dataR.getValue("AVAILABLE_FILE_PATH", fAvailable));
     }
 
-    //Pathnames file
+    // Pathnames file
     std::ofstream out(fPathnames.c_str());
     out << optionsPath << "/" << std::endl;
     out << outPath << "/" << std::endl;
@@ -249,7 +247,7 @@ bool FlexpartRun::generateCommandFile(const std::string& fCmd, MvRequest& in)
     parName = "OUTPUT_TRAJECTORY";
     FLEXPART_CHK(in.getValueId(parName, str, onOffIds_, true));
 
-    //Forward run
+    // Forward run
     if (!bwd) {
         if (outFieldType == "RTIME") {
             marslog(LOG_EROR, "OUTPUT_FIELD_TYPE cannot be set to %s for forward simulations!", outFieldType.c_str());
@@ -257,7 +255,7 @@ bool FlexpartRun::generateCommandFile(const std::string& fCmd, MvRequest& in)
             return false;
         }
 
-        //no trajecory
+        // no trajecory
         if (str == "0" || str.empty()) {
             if (outFieldType == "CONC")
                 outFieldId = "1";
@@ -272,7 +270,7 @@ bool FlexpartRun::generateCommandFile(const std::string& fCmd, MvRequest& in)
             }
         }
 
-        //has trajectory
+        // has trajectory
         else if (str == "1") {
             if (outFieldType == "NONE")
                 outFieldId = "4";
@@ -286,7 +284,7 @@ bool FlexpartRun::generateCommandFile(const std::string& fCmd, MvRequest& in)
         }
     }
 
-    //backward
+    // backward
     else {
         if (outFieldType != "RTIME" && outFieldType != "NONE") {
             marslog(LOG_EROR, "OUTPUT_FIELD_TYPE cannot be set to %s for backward simulations!", outFieldType.c_str());
@@ -294,7 +292,7 @@ bool FlexpartRun::generateCommandFile(const std::string& fCmd, MvRequest& in)
             return false;
         }
 
-        //no trajecory
+        // no trajecory
         if (str == "0" || str.empty()) {
             if (outFieldType == "RTIME")
                 outFieldId = "1";
@@ -305,7 +303,7 @@ bool FlexpartRun::generateCommandFile(const std::string& fCmd, MvRequest& in)
             }
         }
 
-        //has trajectory
+        // has trajectory
         else if (str == "1") {
             if (outFieldType == "NONE")
                 outFieldId = "4";
@@ -345,11 +343,11 @@ bool FlexpartRun::generateCommandFile(const std::string& fCmd, MvRequest& in)
     else
         out << "1" << std::endl;
 
-    //parName="AGE_SPECTRA";
-    //FLEXPART_CHK(in.getValueId(parName,str,onOffIds_));
-    //out << str << std::endl;
+    // parName="AGE_SPECTRA";
+    // FLEXPART_CHK(in.getValueId(parName,str,onOffIds_));
+    // out << str << std::endl;
 
-    //Cont simulation with dumped particle data
+    // Cont simulation with dumped particle data
     out << "0" << std::endl;
 
     parName = "OUTPUT_FOR_EACH_RELEASE";
@@ -382,8 +380,8 @@ bool FlexpartRun::generateCommandFile(const std::string& fCmd, MvRequest& in)
     out << str << std::endl;
 
     parName = "NESTED_OUTPUT";
-    //FLEXPART_CHK(metview::getParamValueId(str,in,"FLEXPART_NESTED_OUTPUT",onOffIds_));
-    //out << str << std::endl;
+    // FLEXPART_CHK(metview::getParamValueId(str,in,"FLEXPART_NESTED_OUTPUT",onOffIds_));
+    // out << str << std::endl;
     out << "0" << std::endl;
 
     parName = "SENSITIVITY";
@@ -413,7 +411,7 @@ bool FlexpartRun::generateReleasesFile(const std::string& fRelease, MvRequest& i
 *** HEADER ***\n\
 *** HEADER ***\n";
 
-    //Species
+    // Species
     std::vector<std::string> sp;
     FLEXPART_CHK(in.getValue("RELEASE_SPECIES", sp));
 
@@ -423,17 +421,17 @@ bool FlexpartRun::generateReleasesFile(const std::string& fRelease, MvRequest& i
     }
     out << "===================================================================" << std::endl;
 
-    //Loop through the releases
+    // Loop through the releases
 
     MvRequest rel = in("RELEASES");
     do {
-        MvRequest rs         = rel.justOneRequest();
+        MvRequest rs = rel.justOneRequest();
         const char* iconType = rs.getVerb();
         std::string iconName;
         if (const char* icnam = rs("_NAME"))
             iconName = std::string(icnam);
 
-        //If no icon is specified
+        // If no icon is specified
         if (!iconType || strcmp(iconType, "FLEXPART_RELEASE") != 0) {
             marslog(LOG_EROR, "No FLEXPART_RELEASE icon is specified!");
             setError(13);
@@ -536,7 +534,7 @@ bool FlexpartRun::generateOutGridFile(const std::string& fGrid, MvRequest& in)
 *** HEADER ***\n\
 *** HEADER ***\n\n";
 
-    //std::string west,south,name,nx,ny,dx,dy,dz;
+    // std::string west,south,name,nx,ny,dx,dy,dz;
 
     parName = "OUTPUT_AREA";
     std::vector<std::string> area;
@@ -586,15 +584,15 @@ bool FlexpartRun::generateOutGridFile(const std::string& fGrid, MvRequest& in)
         return false;
     }
 
-    double dval;
-    std::vector<double> levL;  //we need to set a limit!
+    double dval = 0.;
+    std::vector<double> levL;  // we need to set a limit!
     for (int i = 0; i < cnt && i < 200; i++) {
         in.getValue(dval, "OUTPUT_LEVELS", i);
         levL.push_back(dval);
     }
 
-    float fVal;
-    int iVal;
+    float fVal = 0.;
+    int iVal = 0;
 
     out << std::fixed;
 
@@ -701,11 +699,11 @@ bool FlexpartRun::generateReceptorsFile(const std::string& fRec, MvRequest& in)
 
     std::map<std::string, std::vector<std::string> > vals;
     std::vector<std::string> parLst;
-    parLst.push_back("RECEPTOR_NAMES");
-    parLst.push_back("RECEPTOR_LATITUDES");
-    parLst.push_back("RECEPTOR_LONGITUDES");
+    parLst.emplace_back("RECEPTOR_NAMES");
+    parLst.emplace_back("RECEPTOR_LATITUDES");
+    parLst.emplace_back("RECEPTOR_LONGITUDES");
 
-    for (auto s : parLst) {
+    for (const auto& s : parLst) {
         FLEXPART_CHK(in.getValue(s, vals[s]));
     }
 
@@ -764,22 +762,22 @@ void FlexpartRun::serve(MvRequest& in, MvRequest& out)
     std::cout << "--------------FlexpartRun::serve()--------------" << std::endl;
     in.print();
 
-    //Find out flexpart script paths
+    // Find out flexpart script paths
     std::string flexpartScript;
     std::string ppScript;
 
     char* mvbin = getenv("METVIEW_BIN");
-    if (mvbin == 0) {
+    if (mvbin == nullptr) {
         marslog(LOG_EROR, "No METVIEW_BIN env variable is defined. Cannot locate script mv_flexpart_run!");
         setError(13);
         return;
     }
     else {
         flexpartScript = std::string(mvbin) + "/mv_flexpart_run";
-        ppScript       = std::string(mvbin) + "/mv_flexpart_pp";
+        ppScript = std::string(mvbin) + "/mv_flexpart_pp";
     }
 
-    //Result path
+    // Result path
     std::string resPath;
     std::string errTxt;
     if (!in.getPath("OUTPUT_PATH", resPath, false)) {
@@ -787,7 +785,7 @@ void FlexpartRun::serve(MvRequest& in, MvRequest& out)
         return;
     }
 
-    //Create  tmp dir for the flexpart run
+    // Create  tmp dir for the flexpart run
     std::string tmpPath;
     if (!metview::createWorkDir("flexpart", tmpPath, errTxt)) {
         marslog(LOG_EROR, "%s", errTxt.c_str());
@@ -795,59 +793,59 @@ void FlexpartRun::serve(MvRequest& in, MvRequest& out)
         return;
     }
 
-    //Genarate pathnames  file
-    std::string fPathnames  = tmpPath + "/pathnames";
+    // Genarate pathnames  file
+    std::string fPathnames = tmpPath + "/pathnames";
     std::string optionsPath = tmpPath;
-    std::string outPath     = tmpPath;
+    std::string outPath = tmpPath;
     if (!generatePathnamesFile(fPathnames, in, optionsPath, outPath)) {
         return;
     }
 
-    //Generate COMMAND file
+    // Generate COMMAND file
     std::string fCmd = tmpPath + "/COMMAND";
     if (!generateCommandFile(fCmd, in)) {
         return;
     }
 
-    //Generate OUTGRID file
+    // Generate OUTGRID file
     std::string fGrid = tmpPath + "/OUTGRID";
     if (!generateOutGridFile(fGrid, in)) {
         return;
     }
 
-    //Generate RELEASES file
+    // Generate RELEASES file
     std::string fRelease = tmpPath + "/RELEASES";
     if (!generateReleasesFile(fRelease, in)) {
         return;
     }
 
-    //Generate AGECLASSES file
+    // Generate AGECLASSES file
     std::string fAge = tmpPath + "/AGECLASSES";
     if (!generateAgeClassesFile(fAge, in)) {
         return;
     }
 
-    //Generate RECEPTORS file
+    // Generate RECEPTORS file
     std::string fReceptors = tmpPath + "/RECEPTORS";
     if (!generateReceptorsFile(fReceptors, in)) {
         return;
     }
 
-    //Flexpart exe
+    // Flexpart exe
     std::string exe;
     if (!in.getPathAndReplace("USER_EXE_PATH", exe, "USE_MV_FLEXPART_EXE", "_UNDEF_")) {
         setError(13);
         return;
     }
 
-    //The resources directory
+    // The resources directory
     std::string resourcePath;
     if (!in.getPathAndReplace("USER_RESOURCES_PATH", resourcePath, "USE_MV_FLEXPART_RESOURCES", "_UNDEF_")) {
         setError(13);
         return;
     }
 
-    //The species directory
+    // The species directory
     std::string speciesPath;
     if (!in.getPathAndReplace("USER_SPECIES_PATH", speciesPath, "USE_MV_FLEXPART_SPECIES", "_UNDEF_")) {
         setError(13);
@@ -860,26 +858,26 @@ void FlexpartRun::serve(MvRequest& in, MvRequest& out)
 
     std::string flexpartLogFileName = "log.txt";
 
-    //Run the flexpart script
+    // Run the flexpart script
     std::string cmd = flexpartScript + " \"" + tmpPath + "\" \"" + flexpartLogFileName + "\" \"" + exe + "\" \"" +
                       resourcePath + "\" \"" + speciesPath + "\"";
 
-    //marslog(LOG_INFO,"Execute command: %s",cmd.c_str());
+    // marslog(LOG_INFO,"Execute command: %s",cmd.c_str());
     std::cout << "Execute command: " << cmd << std::endl;
 
-    //Flexpart ouput goes into the stdout and into this file
+    // Flexpart ouput goes into the stdout and into this file
     std::string flexpartLogFile = tmpPath + "/" + flexpartLogFileName;
 
-    //The maximum number of lines we dump from the end of the log
+    // The maximum number of lines we dump from the end of the log
     int maxLogLineNum = 1000;
 
-    //Run the shell script
+    // Run the shell script
     int ret = system(cmd.c_str());
 
-    //Log messages
+    // Log messages
 
-    //If the script failed read log file and
-    //write it into LOG_EROR
+    // If the script failed read log file and
+    // write it into LOG_EROR
     if (ret == -1 || WEXITSTATUS(ret) != 0) {
         if (WEXITSTATUS(ret) == 255) {
             marslog(LOG_WARN, "Warnings generated during FLEXPART run!");
@@ -913,17 +911,17 @@ void FlexpartRun::serve(MvRequest& in, MvRequest& out)
     if (!forward_)
         forwardStr = "0";
 
-    //Run the posproc script
+    // Run the posproc script
     cmd = ppScript + " \"" + tmpPath + "\" \"" + flexpartLogFileName + "\" \"" + ppLogFileName + "\" \"" + resPath +
           "\" \"" + forwardStr + +"\" \"" + std::to_string(receptorNum_) + "\"";
 
-    //marslog(LOG_INFO,"Execute command: %s",cmd.c_str());
+    // marslog(LOG_INFO,"Execute command: %s",cmd.c_str());
     std::cout << "Execute command: " << cmd << std::endl;
 
     ret = system(cmd.c_str());
 
-    //If the script failed read log file and
-    //write it into LOG_EROR
+    // If the script failed read log file and
+    // write it into LOG_EROR
     if (ret == -1 || WEXITSTATUS(ret) != 0) {
         std::string ppLogFile = tmpPath + "/" + ppLogFileName;
 
