@@ -109,7 +109,7 @@ void MvFlexpartGrid::convert()
             // Wet/dry deposition
             if (forward_) {
                 // Wet deposition
-                levType = "sfc";
+                levType = "surface";
                 paramId = 20198;
 
                 dataSize = fieldSize_;
@@ -118,7 +118,7 @@ void MvFlexpartGrid::convert()
                 writeField(data, outPattern_ + "wet.grib", paramId, levType, 0., step, specPoint, spec, ac);
 
                 // Dry deposition
-                levType = "sfc";
+                levType = "surface";
                 paramId = 20197;
 
                 dataSize = fieldSize_;
