@@ -285,6 +285,11 @@ MvQGribDumpPanel::MvQGribDumpPanel(QWidget* parent) :
 
     mvDumpLayout->addWidget(mvDumpTree_, 1);
 
+    mvDumpTree_->setContextMenuPolicy(Qt::ActionsContextMenu);
+
+    // Add actions to dump tree
+    addCopyToClipboardAction(mvDumpTree_, "namespace");
+
     //---------------------------------
     // Std dump
     //--------------------------------
@@ -329,6 +334,8 @@ MvQGribDumpPanel::MvQGribDumpPanel(QWidget* parent) :
     stdDumpTree_->setAlternatingRowColors(true);
     stdDumpTree_->setAllColumnsShowFocus(true);
     stdDumpTree_->setDragDropMode(QAbstractItemView::DragOnly);
+    stdDumpTree_->setContextMenuPolicy(Qt::ActionsContextMenu);
+    addCopyToClipboardAction(stdDumpTree_, "std");
     stdDumpStacked_->addWidget(stdDumpTree_);
 
     stdDumpBrowser_ = new PlainTextWidget(this);
@@ -389,6 +396,8 @@ MvQGribDumpPanel::MvQGribDumpPanel(QWidget* parent) :
     wmoDumpTree_->setAllColumnsShowFocus(true);
     wmoDumpTree_->setDragDropMode(QAbstractItemView::DragOnly);
     wmoDumpTree_->setColumnToDrag(1);
+    wmoDumpTree_->setContextMenuPolicy(Qt::ActionsContextMenu);
+    addCopyToClipboardAction(wmoDumpTree_, "wmo");
 
     wmoDumpStacked_->addWidget(wmoDumpTree_);
 
@@ -493,6 +502,141 @@ MvQGribDumpPanel::MvQGribDumpPanel(QWidget* parent) :
 
     // dumpStacked_->addWidget(w);
 
+    //---------------------------------
+    // PL dump
+    //--------------------------------
+
+    w = new QWidget(this);
+    auto* plLayout = new QVBoxLayout(w);
+    plLayout->setContentsMargins(0, 2, 0, 0);
+    plLayout->setSpacing(0);
+    dumpTab_->addTab(w, tr("PL"));
+    dumpTab_->setTabToolTip(dumpTab_->count()-1, tr("Show details related to the <b>pl</b> array"));
+    Q_ASSERT(static_cast<int>(PlTabIndex) == dumpTab_->count() - 1);
+    dumpTab_->tabBar()->setTabData(dumpTab_->count() - 1, "pl");
+
+    wp = new QWidget(this);
+    auto* plControlLayout = new QHBoxLayout(wp);
+    plControlLayout->setContentsMargins(2, 2, 0, 2);
+    plLayout->addWidget(wp);
+
+//    auto* pvRawTreeTb = new QToolButton(this);
+//    pvRawTreeTb->setCheckable(true);
+//    pvRawTreeTb->setText(tr("Array"));
+
+//    auto* pvTreeTb = new QToolButton(this);
+//    pvTreeTb->setCheckable(true);
+//    pvTreeTb->setText(tr("Levels"));
+
+//    pvGroup_ = new QButtonGroup(this);
+//    pvGroup_->addButton(pvRawTreeTb, 0);
+//    pvGroup_->addButton(pvTreeTb, 1);
+
+//    pvControlLayout->addWidget(pvRawTreeTb);
+//    pvControlLayout->addWidget(pvTreeTb);
+//    pvControlLayout->addSpacing(10);
+
+    plInfoLabel_ = new QLabel(this);
+    plInfoLabel_->setMargin(4);
+    plInfoLabel_->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
+    plControlLayout->addWidget(plInfoLabel_);
+    plControlLayout->addStretch(1);
+
+    // Stacked
+//    pvStacked_ = new QStackedWidget(this);
+//    pvLayout->addWidget(pvStacked_);
+
+    plTree_ = new MvQTreeView(this, true);
+    plModel_ = new MvQGribPlDumpModel(this);
+    plTree_->setModel(plModel_);
+    plTree_->setObjectName("plTree");
+    plTree_->setAlternatingRowColors(true);
+    plTree_->setAllColumnsShowFocus(true);
+    plTree_->setDragDropMode(QAbstractItemView::DragOnly);
+    plTree_->setColumnToDrag(1);
+    plTree_->setContextMenuPolicy(Qt::ActionsContextMenu);
+    addCopyToClipboardAction(plTree_, "pl");
+
+    plLayout->addWidget(plTree_);
+
+//    pvStacked_->addWidget(pvRawTree_);
+//    pvStacked_->addWidget(pvTree_);
+
+//    connect(pvGroup_, SIGNAL(buttonClicked(QAbstractButton*)),
+//            this, SLOT(slotPvGroupClicked(QAbstractButton*)));
+
+
+    //---------------------------------
+    // PV dump
+    //--------------------------------
+
+    w = new QWidget(this);
+    auto* pvLayout = new QVBoxLayout(w);
+    pvLayout->setContentsMargins(0, 2, 0, 0);
+    pvLayout->setSpacing(0);
+    dumpTab_->addTab(w, tr("PV"));
+    dumpTab_->setTabToolTip(dumpTab_->count()-1, tr("Show details related to the <b>pv</b> array"));
+    Q_ASSERT(static_cast<int>(PvTabIndex) == dumpTab_->count() - 1);
+    dumpTab_->tabBar()->setTabData(dumpTab_->count() - 1, "pv");
+
+    wp = new QWidget(this);
+    auto* pvControlLayout = new QHBoxLayout(wp);
+    pvControlLayout->setContentsMargins(2, 2, 0, 2);
+    pvLayout->addWidget(wp);
+
+    auto* pvRawTreeTb = new QToolButton(this);
+    pvRawTreeTb->setCheckable(true);
+    pvRawTreeTb->setText(tr("Array"));
+
+    auto* pvTreeTb = new QToolButton(this);
+    pvTreeTb->setCheckable(true);
+    pvTreeTb->setText(tr("Levels"));
+
+    pvGroup_ = new QButtonGroup(this);
+    pvGroup_->addButton(pvRawTreeTb, 0);
+    pvGroup_->addButton(pvTreeTb, 1);
+
+    pvControlLayout->addWidget(pvRawTreeTb);
+    pvControlLayout->addWidget(pvTreeTb);
+    pvControlLayout->addSpacing(10);
+
+    pvInfoLabel_ = new QLabel(this);
+    pvInfoLabel_->setMargin(4);
+    pvInfoLabel_->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
+    pvControlLayout->addWidget(pvInfoLabel_);
+    pvControlLayout->addStretch(1);
+
+    // Stacked
+    pvStacked_ = new QStackedWidget(this);
+    pvLayout->addWidget(pvStacked_);
+
+    pvRawTree_ = new MvQTreeView(this, true);
+    pvRawModel_ = new MvQGribArrayDumpModel(this, "pv");
+    pvRawTree_->setModel(pvRawModel_);
+    pvRawTree_->setObjectName("pvRawTree");
+    pvRawTree_->setAlternatingRowColors(true);
+    pvRawTree_->setAllColumnsShowFocus(true);
+    pvRawTree_->setDragDropMode(QAbstractItemView::DragOnly);
+    pvRawTree_->setColumnToDrag(1);
+    pvRawTree_->setContextMenuPolicy(Qt::ActionsContextMenu);
+    addCopyToClipboardAction(pvRawTree_, "pvRaw");
+
+    pvTree_ = new MvQTreeView(this, true);
+    pvModel_ = new MvQGribPvDumpModel(this);
+    pvTree_->setModel(pvModel_);
+    pvTree_->setObjectName("pvTree");
+    pvTree_->setAlternatingRowColors(true);
+    pvTree_->setAllColumnsShowFocus(true);
+    pvTree_->setDragDropMode(QAbstractItemView::DragOnly);
+    pvTree_->setColumnToDrag(1);
+    pvTree_->setContextMenuPolicy(Qt::ActionsContextMenu);
+    addCopyToClipboardAction(pvTree_, "pv");
+
+    pvStacked_->addWidget(pvRawTree_);
+    pvStacked_->addWidget(pvTree_);
+
+    connect(pvGroup_, SIGNAL(buttonClicked(QAbstractButton*)),
+            this, SLOT(slotPvGroupClicked(QAbstractButton*)));
 
     //----------------------------------------
     // Init
@@ -534,6 +678,8 @@ MvQGribDumpPanel::MvQGribDumpPanel(QWidget* parent) :
     valueDumpTree_->setColumnWidth(0, MvQ::textWidth(fm, "10000000 "));
     valueDumpTree_->setColumnWidth(1, MvQ::textWidth(fm, "Latitude  "));
     valueDumpTree_->setColumnWidth(1, MvQ::textWidth(fm, "Longitude  "));
+
+    pvGroup_->button(1)->setChecked(true);
 }
 
 MvQGribDumpPanel::~MvQGribDumpPanel()
@@ -547,6 +693,23 @@ void MvQGribDumpPanel::init(GribMetaData* data)
     data_ = data;
 }
 
+void MvQGribDumpPanel::addCopyToClipboardAction(QTreeView* tree, QString dataId)
+{
+    // Add actions to dump tree
+    auto* acCopyDumpKey = new QAction(this);
+    acCopyDumpKey->setText(tr("&Copy item"));
+    acCopyDumpKey->setShortcut(QKeySequence(tr("Ctrl+C")));
+    tree->addAction(acCopyDumpKey);
+
+    Q_ASSERT(trees_.find(dataId) == trees_.end());
+    trees_[dataId] = tree;
+    acCopyDumpKey->setData(dataId);
+
+    connect(acCopyDumpKey, SIGNAL(triggered()),
+            this, SLOT(slotCopyDumpKey()));
+
+}
+
 void MvQGribDumpPanel::loadDumps(int msgCnt)
 {
     Q_ASSERT(data_);
@@ -590,26 +753,33 @@ void MvQGribDumpPanel::loadDumps(int msgCnt)
     stdDumpLoaded_ = false;
     tableDumpLoaded_ = false;
     valueDumpLoaded_ = false;
+    pvDumpLoaded_ = false;
 
     // Generate and read grib dumps
     switch (dumpTab_->currentIndex()) {
-        case NamespaceTabIndex:
-            loadMvDump();
-            break;
-        case StdTabIndex:
-            loadStdDump();
-            break;
-        case WmoTabIndex:
-            loadWmoDump();
-            break;
-        case TableTabIndex:
-            loadTableDump();
-            break;
-        case ValueTabIndex:
-            loadValueDump();
-            break;
-        default:
-            break;
+    case NamespaceTabIndex:
+        loadMvDump();
+        break;
+    case StdTabIndex:
+        loadStdDump();
+        break;
+    case WmoTabIndex:
+        loadWmoDump();
+        break;
+    case TableTabIndex:
+        loadTableDump();
+        break;
+    case ValueTabIndex:
+        loadValueDump();
+        break;
+    case PlTabIndex:
+        loadPlDump();
+        break;
+    case PvTabIndex:
+        loadPvDump();
+        break;
+    default:
+        break;
     }
 }
 
@@ -620,6 +790,8 @@ void MvQGribDumpPanel::clearDumps()
     clearStdDump();
     clearTableDump();
     clearValueDump();
+    clearPlDump();
+    clearPvDump();
 }
 
 void MvQGribDumpPanel::loadMvDump()
@@ -849,6 +1021,92 @@ void MvQGribDumpPanel::clearValueDump()
     valueDumpMessageLabel_->hide();
 }
 
+
+void MvQGribDumpPanel::loadPvDump()
+{
+    Q_ASSERT(currentMsg_ >= 0);
+
+    if (pvDumpLoaded_ || !messageCanBeDecoded_)
+        return;
+
+    StatusMsgHandler::instance()->task("Loading PV dump");
+
+    auto* dumpPv = new GribPvDump();
+    if (dumpPv->read(data_->fileName(), data_->unfilteredMessageCnt(currentMsg_))) {
+        pvRawModel_->setDumpData(dumpPv->values());
+        pvModel_->setDumpData(dumpPv);
+        StatusMsgHandler::instance()->done();
+        auto subCol = MvQTheme::subText();
+        auto bold = MvQTheme::boldFileInfoTitle();
+        QString t = MvQ::formatText("Number of model levels: ", subCol, bold) +
+                QString::number(dumpPv->levelNum());
+        pvInfoLabel_->setText(t);
+    }
+    else {
+        delete dumpPv;
+        pvRawModel_->clear();
+        pvModel_->clear();
+        StatusMsgHandler::instance()->clear();
+        pvInfoLabel_->setText("No <b>pv array</b> is available in the current message.");
+    }
+
+    pvDumpLoaded_ = true;
+}
+
+void MvQGribDumpPanel::clearPvDump()
+{
+    if (!pvDumpLoaded_)
+        return;
+
+    pvInfoLabel_->clear();
+    pvRawModel_->clear();
+    pvModel_->clear();
+}
+
+
+void MvQGribDumpPanel::loadPlDump()
+{
+    Q_ASSERT(currentMsg_ >= 0);
+
+    if (plDumpLoaded_ || !messageCanBeDecoded_)
+        return;
+
+    StatusMsgHandler::instance()->task("Loading PL dump");
+
+    auto* dumpPl = new GribPlDump();
+    if (dumpPl->read(data_->fileName(), data_->unfilteredMessageCnt(currentMsg_))) {
+        plModel_->setDumpData(dumpPl);
+        StatusMsgHandler::instance()->done();
+
+        auto subCol = MvQTheme::subText();
+        auto bold = MvQTheme::boldFileInfoTitle();
+        QString t = MvQ::formatText("gridType: ", subCol, bold) + QString::fromStdString(dumpPl->gridType());
+        t += MvQ::formatText(" N: ", subCol, bold) +  QString::number(dumpPl->N());
+        if (dumpPl->gridType() == "reduced_gg") {
+             t += MvQ::formatText(" octahedral: ", subCol, bold) + ((dumpPl->isOctahedral())?"1":"0");
+        }
+        plInfoLabel_->setText(t);
+    }
+    else {
+        delete dumpPl;
+        plModel_->clear();
+        StatusMsgHandler::instance()->clear();
+        plInfoLabel_->setText("No <b>pl array</b> is available in the current message.");
+    }
+
+    plDumpLoaded_ = true;
+}
+
+void MvQGribDumpPanel::clearPlDump()
+{
+    if (!plDumpLoaded_)
+        return;
+
+    plInfoLabel_->clear();
+    plModel_->clear();
+}
+
+
 void MvQGribDumpPanel::slotStdGroupClicked(QAbstractButton*)
 {
     if (stdGroup_->checkedId() != -1) {
@@ -863,6 +1121,13 @@ void MvQGribDumpPanel::slotWmoGroupClicked(QAbstractButton*)
     }
 }
 
+void MvQGribDumpPanel::slotPvGroupClicked(QAbstractButton*)
+{
+    if (pvGroup_->checkedId() != -1) {
+        pvStacked_->setCurrentIndex(pvGroup_->checkedId());
+    }
+}
+
 void MvQGribDumpPanel::slotCurrentDumpChanged(int /*index*/)
 {
     if (!data_)
@@ -885,6 +1150,12 @@ void MvQGribDumpPanel::slotCurrentDumpChanged(int /*index*/)
         case ValueTabIndex:
             loadValueDump();
             break;
+        case PlTabIndex:
+            loadPlDump();
+            break;
+        case PvTabIndex:
+            loadPvDump();
+            break;
         default:
             break;
     }
@@ -941,6 +1212,27 @@ void GribExaminer::slotMessageSpinChanged(int value)
 }
 #endif
 
+
+void MvQGribDumpPanel::slotCopyDumpKey()
+{
+    auto ac = qobject_cast<QAction*>(sender());
+    if (ac != nullptr) {
+        auto it = trees_.find(ac->data().toString());
+        if (it != trees_.end()) {
+            auto tree = it->second;
+            if (tree != nullptr) {
+                QModelIndex index = tree->currentIndex();
+                if (index.isValid()) {
+                    QString name = index.data().toString();
+                    if (!name.isEmpty()) {
+                        MvQ::toClipboard(name);
+                    }
+                }
+            }
+        }
+    }
+}
+
 void MvQGribDumpPanel::writeSettings(QSettings& settings)
 {
     settings.beginGroup("dump");
@@ -957,6 +1249,12 @@ void MvQGribDumpPanel::writeSettings(QSettings& settings)
 
     MvQ::saveTreeColumnWidth(settings, "valueTreeColumnWidth", valueDumpTree_);
 
+    settings.setValue("pv", pvGroup_->checkedId());
+    MvQ::saveTreeColumnWidth(settings, "pvRawTreeColumnWidth", pvRawTree_);
+    MvQ::saveTreeColumnWidth(settings, "pvTreeColumnWidth", pvTree_);
+
+    MvQ::saveTreeColumnWidth(settings, "plTreeColumnWidth", plTree_);
+
     settings.endGroup();
 }
 
@@ -977,6 +1275,12 @@ void MvQGribDumpPanel::readSettings(QSettings& settings)
 
     MvQ::initTreeColumnWidth(settings, "valueTreeColumnWidth", valueDumpTree_);
 
+    MvQ::initButtonGroup(settings, "pv", pvGroup_);
+    MvQ::initTreeColumnWidth(settings, "pvRawTreeColumnWidth", pvRawTree_);
+    MvQ::initTreeColumnWidth(settings, "pvTreeColumnWidth", pvTree_);
+
+    MvQ::initTreeColumnWidth(settings, "plTreeColumnWidth", plTree_);
+
     settings.endGroup();
 }
 
