@@ -24,11 +24,15 @@ class QStackedWidget;
 class QTabWidget;
 class QTextBrowser;
 class QTextEdit;
+class QTreeView;
 
 class MvQGribMvDumpModel;
 class MvQGribWmoDumpModel;
 class MvQGribStdDumpModel;
 class MvQGribValueDumpModel;
+class MvQGribArrayDumpModel;
+class MvQGribPlDumpModel;
+class MvQGribPvDumpModel;
 class MvQTextEditSearchLine;
 class MvQTreeExpandState;
 class MvQTreeView;
@@ -58,13 +62,19 @@ protected slots:
     void slotMvDumpFilter(QString txt);
     void slotStdGroupClicked(QAbstractButton*);
     void slotWmoGroupClicked(QAbstractButton*);
+    void slotPvGroupClicked(QAbstractButton*);
+    void slotCopyDumpKey();
 
 private:
+    void addCopyToClipboardAction(QTreeView*, QString);
+
     void loadMvDump();
     void loadWmoDump();
     void loadStdDump();
     void loadTableDump();
     void loadValueDump();
+    void loadPlDump();
+    void loadPvDump();
 
     void clearDumps();
     void clearMvDump();
@@ -72,6 +82,8 @@ private:
     void clearStdDump();
     void clearTableDump();
     void clearValueDump();
+    void clearPlDump();
+    void clearPvDump();
 
     enum DumpTabIndex
     {
@@ -79,7 +91,9 @@ private:
         StdTabIndex = 1,
         WmoTabIndex = 2,
         TableTabIndex = 3,
-        ValueTabIndex
+        ValueTabIndex = 4,
+        PlTabIndex = 5,
+        PvTabIndex = 6
     };
 
     int currentMsg_;  // starts at 0
@@ -127,8 +141,26 @@ private:
     QSortFilterProxyModel* valueDumpSortModel_;
     bool valueDumpLoaded_{false};
 
+//    QStackedWidget* plStacked_{nullptr};
+//    QButtonGroup* plGroup_{nullptr};
+    MvQTreeView* plTree_{nullptr};
+    MvQGribPlDumpModel* plModel_{nullptr};
+    QLabel* plInfoLabel_{nullptr};
+    bool plDumpLoaded_{false};
+
+    QStackedWidget* pvStacked_{nullptr};
+    QButtonGroup* pvGroup_{nullptr};
+    MvQTreeView* pvRawTree_{nullptr};
+    MvQGribArrayDumpModel* pvRawModel_{nullptr};
+    MvQTreeView* pvTree_{nullptr};
+    MvQGribPvDumpModel* pvModel_{nullptr};
+    QLabel* pvInfoLabel_{nullptr};
+    bool pvDumpLoaded_{false};
+
     bool ignoreValueRowSpinChangeSignal_{false};
     bool fileInfoLabelNeedsUpdating_{true};
+
+    std::map<QString, QTreeView*> trees_;
 };
 
 class MvQGribMainPanel : public QWidget
