@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef GRIBVECTORS_H
-#define GRIBVECTORS_H
+#pragma once
 
 /************************************
   Application GribVectors
@@ -29,5 +28,3 @@ public:
 
     void serve(MvRequest&, MvRequest&);
 };
-
-#endif
