@@ -14,6 +14,8 @@
 //  Tested: reading a png file and plotting it in Import View - OK!
 
 
+#pragma once
+
 #include <string>
 #include "Metview.h"
 #include "value.h"
@@ -22,12 +24,12 @@
 class CPngJpeg : public Content
 {
 public:
-    CPngJpeg(const char* fileName, const string& kind);
+    CPngJpeg(const char* fileName, const std::string& kind);
 
     virtual void ToRequest(request*&);
     virtual void Print();
 
 private:
-    string fileName_;
-    string kind_;
+    std::string fileName_;
+    std::string kind_;
 };
