@@ -21,6 +21,7 @@ class CObject;
 class Step : public Node
 {
 public:
+    using Node::Node;
     Context* Owner() { return (Context*)Node::Owner(); }
     Step* Next() { return (Step*)Node::Next(); }
     virtual Step* Execute(void) { return Next(); }
@@ -77,7 +78,7 @@ public:
 
     void AddType(vtype t);
     void DeprecatedMessage(bool, const char*, const char*);
-    Value ToString(void);
+    Value ToString(void) override;
 
     virtual int ValidArguments(int, Value*);
     virtual Value Execute(int, Value*)
@@ -90,7 +91,7 @@ public:
         return info;
     }
 
-    virtual void Print(void);
+    void Print(void) override;
 
     //===============================================================
     void* operator new(size_t s)
@@ -102,6 +103,10 @@ public:
     {
         fast_delete(p, permanent_mem);
     }
+
+    virtual bool isRequestFunction() const {return false;}
+    virtual bool isUserFunction() const {return false;}
+    void accept(NodeVisitor *v) override {v->visit(this);}
 };
 
 class Variable : public Node
@@ -177,7 +182,8 @@ public:
     Function* FindHandler(const char* name, int arity, Value* arg);
     Value* GetParameters(int count);
     static void EmptyStack();
-
+    bool isLibraryFunction(const char* name);
+    void print_tree();
 
 public:
     static int Trace(void) { return trace; }
@@ -195,7 +201,6 @@ public:
     static bool IsMacro() { return !strcmp(BaseLanguage(), "macro"); }
     static bool IsPython() { return !strcmp(BaseLanguage(), "python"); }
 
-
     Context* FindContext(const char* name);
     static const char* FallBackHandler(const char* name);
     int HasHandler(const char* nam, int arity = 0, Value* arg = nullptr)
@@ -325,8 +330,8 @@ class PlotterFunction : public Function
 {
     static char* plotter;
     static boolean setbyuser;
-    virtual int ValidArguments(int arity, Value* arg);
-    virtual Value Execute(int arity, Value* arg);
+    int ValidArguments(int arity, Value* arg) override;
+    Value Execute(int arity, Value* arg) override;
 
 public:
     PlotterFunction(const char* n);
