@@ -20,12 +20,13 @@
 #include "script.h"
 #include "cbufr.h"
 #include "codb.h"
+#include "compile.h"
 
 class PythonScript : public Script
 {
 public:
     PythonScript() :
-        Script("PythonScript")
+        Script("PythonScript", new ScriptCompiler)
     {
         Current = this;
         Step* s = new Step;
@@ -90,7 +91,7 @@ Value* local_copy_of_value(const Value& v)
 void p_init()
 {
     // printf("Metview::p_init called from Python\n");
-    progName = "Python";
+    progName = (char*)"Python";
     argv[0] = progName;
     mp_init(1, argv);
 }
