@@ -7,7 +7,10 @@
 
  ***************************** LICENSE END *************************************/
 
+#include <cassert>
+
 #include "script.h"
+#include "compile.h"
 #include "Cached.h"
 #include "MvRequest.h"
 
@@ -19,6 +22,7 @@ MvRequest Script::PlotReq;           // Plot request
 char* Script::macropath = 0;
 char* Script::macroMainPath = 0;
 
+#if 0
 extern "C" {
 
 int parse_macro(void);
@@ -28,6 +32,13 @@ void zzerror(char* msg)
     Script::Compiled->CompileError(msg, zzlineno + 1);
 }
 }
+#endif
+
+
+void Compiler::compileError(char* msg, int lineNum)
+{
+    Script::Compiled->CompileError(msg, lineNum);
+}
 
 void Script::PutMessage(int /*code*/, const char* msg)
 {
@@ -52,18 +63,33 @@ void Script::PutExtendedMessage(int /*code*/, const char* msg)
 
 void Script::CompileError(const char* msg, int line)
 {
+    compileErrors_.emplace_back("Line " + std::to_string(line) + ": " + std::string(msg));
     marslog(LOG_EROR, "Line %d: %s", line, msg);
     SetError(1);
 }
 
-Script::Script(const char* name) :
-    Context(name)
+Script::Script(const char* name, Compiler* compiler) :
+    Context(name), compiler_(compiler)
 {
+    if (compiler_ != nullptr) {
+        compiler_->setScript(this);
+    }
     runmode = 0;
     Linkage::Install(this);
     SetRunMode("batch");
 }
 
+int Script::Compile(const char* filename)
+{
+    if (compiler_ == nullptr) {
+        marslog(LOG_EROR, "Script: compiler_ cannot be nullptr!");
+        SetError(1);
+        return 1;
+    }
+    return compiler_->compile(filename);
+}
+
+#if 0
 int Script::Compile(const char* filename)
 {
     extern FILE* zzin;
@@ -107,9 +133,11 @@ int Script::Compile(const char* filename)
 
     return GetError();
 }
+#endif
 
 Script::~Script()
 {
+    delete compiler_;
     EmptyStack();
     strfree(runmode);
     ASync::Disconnect();
@@ -144,8 +172,8 @@ void Batch::BatchError(int err, void* data)
     }
 }
 
-Batch::Batch(const char* name) :
-    Script(name)
+Batch::Batch(const char* name,  Compiler* compiler) :
+    Script(name, compiler)
 {
     install_exit_proc(BatchError, this);
 
