@@ -546,6 +546,15 @@ void ASync::AvoidDuplication(Content* c)
                             g2->refcnt++;
                             g1->refcnt--;
                             f1->file = g2;
+                            // if no one is pointing to g1 we need to delete the object
+                            // without removing the file from disk. Not deleting g1 will
+                            // result in a memory leak. See: METV-3389
+                            if (g1->refcnt <= 0) {
+                                // we need to pretend g1 is not temporary. Otherwise
+                                // free_gribfile() would delete the file from disk!
+                                g1->temp = 0;
+                                free_gribfile(g1);
+                            }
                             break;  // don't need to search fs1 any further
                         }
                     }
