@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef PlainTextHelper_H
-#define PlainTextHelper_H
+#pragma once
 
 // --------------------------------------------------
 // class MagMLHelper
@@ -29,6 +28,3 @@ public:
     bool isAutoLicenceTextAllowed() { return false; }
     bool isHelpAvailableForFunction(QString /*function*/) { return false; }
 };
-
-
-#endif
