@@ -69,7 +69,7 @@ MvQWmsDimensionGuiItem::MvQWmsDimensionGuiItem(MvQOgcDimension* dim, QString tex
     row_ = parentRow;
     parentLayout->addWidget(label_, row_, 0);
 
-    //Expand
+    // Expand
     expandTb_ = new QToolButton();
     QIcon ic;
     ic.addPixmap(QPixmap(":/OgcClient/expand_left.svg"), QIcon::Normal, QIcon::On);
@@ -78,33 +78,33 @@ MvQWmsDimensionGuiItem::MvQWmsDimensionGuiItem(MvQOgcDimension* dim, QString tex
     expandTb_->setMaximumSize(QSize(16, 16));
     expandTb_->setCheckable(true);
     expandTb_->setChecked(false);
-    //expandTb_->setAutoRaise(true);
+    // expandTb_->setAutoRaise(true);
     expandTb_->setToolTip(tr("View value list"));
     parentLayout->addWidget(expandTb_, row_, 1);
 
-    //LinEdit
+    // LinEdit
     lineEdit_ = new QLineEdit();
     lineEdit_->setText(text);
 #if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
     lineEdit_->setClearButtonEnabled(true);
 #endif
-    //nameLabel_->setBuddy(lineEdit_);
+    // nameLabel_->setBuddy(lineEdit_);
 
     parentLayout->addWidget(lineEdit_, row_, 2);
 
-    //Get values
-    //QStringList values_=dim->displayValues();
+    // Get values
+    // QStringList values_=dim->displayValues();
     QStringList values_ = dim->values();
 
     list_ = new QListWidget();
     list_->setVisible(false);
 
-    //Populate the list
+    // Populate the list
 
     foreach (QString str, values_) {
         new QListWidgetItem(str, list_);
-        //item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
-        //item->setCheckState(Qt::Unchecked);
+        // item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
+        // item->setCheckState(Qt::Unchecked);
     }
 
     parentLayout->addWidget(list_, row_ + 1, 2);
@@ -116,7 +116,7 @@ MvQWmsDimensionGuiItem::MvQWmsDimensionGuiItem(MvQOgcDimension* dim, QString tex
             this, SLOT(slotAddItem(QListWidgetItem*)));
 
     /*connect(list_,SIGNAL(itemPressed(QListWidgetItem*)),
-		this,SLOT(slotAddItem(QListWidgetItem*)));*/
+        this,SLOT(slotAddItem(QListWidgetItem*)));*/
 
     connect(list_, SIGNAL(itemChanged(QListWidgetItem*)),
             this, SLOT(slotListItemChanged(QListWidgetItem*)));
@@ -173,9 +173,9 @@ void MvQWmsDimensionGuiItem::slotListItemChanged(QListWidgetItem* item)
         text += item->data(Qt::DisplayRole).toString();
     }
     else {
-        QString itemText     = item->data(Qt::DisplayRole).toString();
+        QString itemText = item->data(Qt::DisplayRole).toString();
         QStringList textList = text.split("/");
-        int itemIndex        = textList.indexOf(itemText);
+        int itemIndex = textList.indexOf(itemText);
 
         QString newText;
         for (int i = 0; i < textList.count(); i++) {
@@ -195,8 +195,8 @@ void MvQWmsDimensionGuiItem::slotListItemChanged(QListWidgetItem* item)
 void MvQWmsDimensionGuiItem::addValue(QString value)
 {
     new QListWidgetItem(value, list_);
-    //item->setFlags(Qt::ItemIsSelectable |Qt::ItemIsEnabled);
-    //item->setCheckState(Qt::Unchecked);
+    // item->setFlags(Qt::ItemIsSelectable |Qt::ItemIsEnabled);
+    // item->setCheckState(Qt::Unchecked);
 }
 
 QString MvQWmsDimensionGuiItem::currentValue()
@@ -214,14 +214,14 @@ QString MvQWmsDimensionGuiItem::currentValue()
 MvQWmsClientEditor::MvQWmsClientEditor(MvQWmsUiClient* client, QWidget* parent) :
     MvQMainWindow(parent)
 {
-    //Window setup
+    // Window setup
     QString iconName;
     QStringList lst = client->iconFile().split("/");
     if (lst.count() > 0) {
         iconName = lst.last();
     }
 
-    //Initial size
+    // Initial size
     setInitialSize(1100, 800);
 
     setAttribute(Qt::WA_DeleteOnClose);
@@ -230,18 +230,18 @@ MvQWmsClientEditor::MvQWmsClientEditor(MvQWmsUiClient* client, QWidget* parent)
 
     client_ = client;
 
-    //ClientModeMap
-    clientModeMap_["Plain"]       = MvQWmsUiClient::BasicMode;
+    // ClientModeMap
+    clientModeMap_["Plain"] = MvQWmsUiClient::BasicMode;
     clientModeMap_["Interactive"] = MvQWmsUiClient::AdvancedMode;
 
-    //Main layout
+    // Main layout
     mainLayout_ = new QVBoxLayout;
     mainLayout_->setContentsMargins(1, 1, 1, 1);
     auto* w = new QWidget(this);
     w->setLayout(mainLayout_);
     setCentralWidget(w);
 
-    //Main splitter
+    // Main splitter
     mainSplitter_ = new QSplitter(this);
     mainSplitter_->setOrientation(Qt::Vertical);
     mainSplitter_->setOpaqueResize(false);
@@ -255,15 +255,15 @@ MvQWmsClientEditor::MvQWmsClientEditor(MvQWmsUiClient* client, QWidget* parent)
     requestSplitter_->setOpaqueResize(false);
     mainSplitter_->addWidget(requestSplitter_);
 
-    //Request left layout
-    layerPanel_             = new QWidget(this);
+    // Request left layout
+    layerPanel_ = new QWidget(this);
     auto* requestLeftLayout = new QVBoxLayout;
     requestLeftLayout->setContentsMargins(1, 1, 1, 1);
     requestLeftLayout->setSpacing(1);
     layerPanel_->setLayout(requestLeftLayout);
     requestSplitter_->addWidget(layerPanel_);
 
-    //Request right layout
+    // Request right layout
     layerInfoTab_ = new QTabWidget(this);
     requestSplitter_->addWidget(layerInfoTab_);
 
@@ -283,11 +283,11 @@ MvQWmsClientEditor::MvQWmsClientEditor(MvQWmsUiClient* client, QWidget* parent)
     // Bottom part with buttons
     //---------------------------------------
 
-    //Buttons
+    // Buttons
     auto* hb = new QHBoxLayout;
     mainLayout_->addLayout(hb);
 
-    auto* labelMode  = new QLabel(tr("Mode:"), this);
+    auto* labelMode = new QLabel(tr("Mode:"), this);
     clientModeCombo_ = new QComboBox(this);
     clientModeCombo_->addItem("Plain");
     clientModeCombo_->addItem("Interactive");
@@ -308,8 +308,8 @@ MvQWmsClientEditor::MvQWmsClientEditor(MvQWmsUiClient* client, QWidget* parent)
 
     buttonBox_ = new QDialogButtonBox(this);
 
-    savePb_   = buttonBox_->addButton(QDialogButtonBox::Save);
-    okPb_     = buttonBox_->addButton(QDialogButtonBox::Ok);
+    savePb_ = buttonBox_->addButton(QDialogButtonBox::Save);
+    okPb_ = buttonBox_->addButton(QDialogButtonBox::Ok);
     cancelPb_ = buttonBox_->addButton(QDialogButtonBox::Cancel);
 
     savePb_->setDefault(true);
@@ -328,7 +328,7 @@ MvQWmsClientEditor::MvQWmsClientEditor(MvQWmsUiClient* client, QWidget* parent)
     //-------------------
 
     loadProgress_ = new QProgressBar(this);
-    //loadProgress_->setRange(0,0);
+    // loadProgress_->setRange(0,0);
     statusBar()->addPermanentWidget(loadProgress_);
     loadProgress_->hide();
 
@@ -342,7 +342,7 @@ MvQWmsClientEditor::MvQWmsClientEditor(MvQWmsUiClient* client, QWidget* parent)
     // Init
     //-------------
 
-    //actions
+    // actions
     setupFileActions();
     setupViewActions();
     setupSettingsActions();
@@ -356,7 +356,7 @@ MvQWmsClientEditor::MvQWmsClientEditor(MvQWmsUiClient* client, QWidget* parent)
         insertToolBarBreak(tb);
     }
 
-    //Request panel
+    // Request panel
     setupLayerPanel(requestLeftLayout);
     setupLayerInfoTab();
 
@@ -371,8 +371,8 @@ MvQWmsClientEditor::MvQWmsClientEditor(MvQWmsUiClient* client, QWidget* parent)
     connect(client_, SIGNAL(clientResetDone()),
             this, SLOT(slotClientReset()));
 
-    //Initialise the current mode --> call loadGetCapabilities
-    //This must come last!!!
+    // Initialise the current mode --> call loadGetCapabilities
+    // This must come last!!!
     initClientMode();
 
     //
@@ -392,7 +392,7 @@ void MvQWmsClientEditor::setupFileActions()
     actionImport->setText(tr("&Import"));
     actionImport->setToolTip(tr("Import request"));
 
-    //Define routines
+    // Define routines
     connect(actionImport, SIGNAL(activated()),
             this, SLOT(slotImportRequest()));
 
@@ -418,10 +418,10 @@ void MvQWmsClientEditor::setupViewActions()
     icon2.addPixmap(QPixmap(QString::fromUtf8(":/examiner/log.svg")), QIcon::Normal, QIcon::Off);
     actionLog_->setIcon(icon2);
 
-    //logPanel connects up logAction  and manages it
+    // logPanel connects up logAction  and manages it
     logPanel_->setViewAction(actionLog_);
 
-    //Log is hidden by default!!!
+    // Log is hidden by default!!!
     actionLog_->setChecked(false);
 
     auto* actionSeparator = new QAction(this);
@@ -448,14 +448,14 @@ void MvQWmsClientEditor::setupViewActions()
     urlCombo_ = new QComboBox(this);
     urlCombo_->setEditable(true);
     urlCombo_->setMinimumContentsLength(20);
-    //urlCombo_->setMaxCount(20);
+    // urlCombo_->setMaxCount(20);
     QSizePolicy p = urlCombo_->sizePolicy();
     urlCombo_->setSizePolicy(QSizePolicy::Expanding, p.verticalPolicy());
     urlCombo_->setInsertPolicy(QComboBox::InsertAtTop);
     urlCombo_->setMaximumWidth(700);
     advancedModeOnlyWidgets_ << urlCombo_;
 
-    //Server version combo
+    // Server version combo
     auto* labelVersion = new QLabel(tr(" Version:"), this);
     advancedModeOnlyWidgets_ << labelVersion;
     versionCombo_ = new QComboBox(this);
@@ -472,7 +472,7 @@ void MvQWmsClientEditor::setupViewActions()
 
     //---> Init
 
-    //Init  url and version combos
+    // Init  url and version combos
     if (!client_->url().isEmpty()) {
         urlCombo_->insertItem(0, client_->url());
         urlCombo_->setCurrentIndex(0);
@@ -511,21 +511,19 @@ void MvQWmsClientEditor::setupSettingsActions()
     //--------------------
 
     auto* labelFormat = new QLabel(tr("Format:"), this);
-    formatCombo_      = new QComboBox(this);
+    formatCombo_ = new QComboBox(this);
     formatCombo_->setSizeAdjustPolicy(QComboBox::AdjustToContents);
 
-    //Extra getcap
+    // Extra getcap
     auto* labelGetCap = new QLabel(tr(" Extra getCap param:"), this);
-    extraGetCapEdit_  = new QLineEdit("", this);
+    extraGetCapEdit_ = new QLineEdit("", this);
 
-    //Extra getmap
+    // Extra getmap
     auto* labelGetMap = new QLabel(tr(" Extra getMap param:"), this);
-    extraGetMapEdit_  = new QLineEdit("", this);
+    extraGetMapEdit_ = new QLineEdit("", this);
 
-    QString mName = "Format";
-
-    //Put this toolbar into another line!!!
-    //addToolBarBreak(Qt::TopToolBarArea);
+    // Put this toolbar into another line!!!
+    // addToolBarBreak(Qt::TopToolBarArea);
 
     MvQMainWindow::MenuType menuType = MvQMainWindow::SettingsMenu;
 
@@ -536,7 +534,7 @@ void MvQWmsClientEditor::setupSettingsActions()
     menuItems_[menuType].push_back(new MvQMenuItem(labelGetMap, MvQMenuItem::ToolBarTarget));
     menuItems_[menuType].push_back(new MvQMenuItem(extraGetMapEdit_, MvQMenuItem::ToolBarTarget));
 
-    //These are independent from getCapabilities
+    // These are independent from getCapabilities
     initExtraParEdit();
 
     connect(formatCombo_, SIGNAL(activated(QString)),
@@ -552,12 +550,12 @@ void MvQWmsClientEditor::setupSettingsActions()
 
 void MvQWmsClientEditor::setupLayerPanel(QVBoxLayout* layout)
 {
-    QLabel* label;
+    QLabel* label = nullptr;
     int row = 0;
 
     layerParamRowNum_ = 0;
 
-    //Tab
+    // Tab
     layerTab_ = new QTabWidget(this);
     layout->addWidget(layerTab_);
 
@@ -569,7 +567,7 @@ void MvQWmsClientEditor::setupLayerPanel(QVBoxLayout* layout)
     layerTree_->setAlternatingRowColors(true);
     layerTree_->setUniformRowHeights(true);
 
-    //layerSplitter_->addWidget(layerTree_);
+    // layerSplitter_->addWidget(layerTree_);
 
     layerModel_ = new MvQOgcTreeModel(this);
     layerTree_->setModel(layerModel_);
@@ -589,7 +587,7 @@ void MvQWmsClientEditor::setupLayerPanel(QVBoxLayout* layout)
     auto* scroll = new QScrollArea(this);
     layerTab_->addTab(scroll, tr("Layer settings"));
 
-    auto* w    = new QWidget(this);
+    auto* w = new QWidget(this);
     layerGrid_ = new QGridLayout;
     layerGrid_->setSizeConstraint(QLayout::SetMinAndMaxSize);
     w->setLayout(layerGrid_);
@@ -597,7 +595,7 @@ void MvQWmsClientEditor::setupLayerPanel(QVBoxLayout* layout)
     scroll->setWidgetResizable(true);
     scroll->setWidget(w);
 
-    label       = new QLabel("Styles:", this);
+    label = new QLabel("Styles:", this);
     styleCombo_ = new QComboBox(this);
     layerGrid_->addWidget(label, row, 0);
     layerGrid_->addWidget(styleCombo_, row, 2);
@@ -612,8 +610,8 @@ void MvQWmsClientEditor::setupLayerPanel(QVBoxLayout* layout)
 
     layerParamRowNum_ = row;
 
-    //layerGrid_->setColumnStretch(1,1);
-    //layerGrid_->setRowStretch(row,1);
+    // layerGrid_->setColumnStretch(1,1);
+    // layerGrid_->setRowStretch(row,1);
 
     connect(crsCombo_, SIGNAL(activated(QString)),
             this, SLOT(slotSelectCrs(QString)));
@@ -622,7 +620,7 @@ void MvQWmsClientEditor::setupLayerPanel(QVBoxLayout* layout)
             this, SLOT(slotSelectStyle(int)));
 
 
-    //Preview pb
+    // Preview pb
     previewPb_ = new QPushButton(tr("Generate preview"), this);
     layout->addWidget(previewPb_);
 
@@ -632,13 +630,13 @@ void MvQWmsClientEditor::setupLayerPanel(QVBoxLayout* layout)
 
 void MvQWmsClientEditor::setupLayerInfoTab()
 {
-    QLabel* label;
-    QWidget* w;
+    QLabel* label = nullptr;
+    QWidget* w = nullptr;
 
     //--------------------------
     // Layer preview tab
     //--------------------------
-    w                  = new QWidget(this);
+    w = new QWidget(this);
     auto previewLayout = new QVBoxLayout(w);
     previewLayout->setContentsMargins(0, 2, 0, 0);
     previewLayout->setSpacing(0);
@@ -670,7 +668,7 @@ void MvQWmsClientEditor::setupLayerInfoTab()
     reqSplitter_ = new QSplitter(this);
     layerInfoTab_->addTab(reqSplitter_, tr("GetMap request"));
 
-    reqEditPanel_       = new QWidget(this);
+    reqEditPanel_ = new QWidget(this);
     auto* reqEditLayout = new QVBoxLayout;
     reqEditPanel_->setLayout(reqEditLayout);
     reqSplitter_->addWidget(reqEditPanel_);
@@ -689,7 +687,7 @@ void MvQWmsClientEditor::setupLayerInfoTab()
     // --> Request display
     //---------------------------------------
 
-    w                  = new QWidget(this);
+    w = new QWidget(this);
     auto mapInfoLayout = new QVBoxLayout;
     mapInfoLayout->setContentsMargins(0, 2, 0, 0);
     mapInfoLayout->setSpacing(0);
@@ -704,8 +702,8 @@ void MvQWmsClientEditor::setupLayerInfoTab()
     getMapInfoSplit_ = new QTextBrowser(this);
     getMapInfoSplit_->setReadOnly(true);
     getMapInfoSplit_->document()->setDefaultStyleSheet(MvQTheme::htmlTableCss());
-    //getMapInfoSplit_->setLineWrapMode(QTextEdit::NoWrap);
-    //reqSplitter_->addWidget(reqGrid_);
+    // getMapInfoSplit_->setLineWrapMode(QTextEdit::NoWrap);
+    // reqSplitter_->addWidget(reqGrid_);
     mapInfoLayout->addWidget(getMapInfoSplit_, 1);
 
     new DocHighlighter(getMapInfoSplit_->document(), "getMap");
@@ -727,20 +725,20 @@ void MvQWmsClientEditor::setupLayerInfoTab()
 
     plainPreviewLabel_ = new QLabel(this);
     plainPreviewLabel_->setFrameStyle(QFrame::Box | QFrame::Plain);
-    //plainPreviewLabel_->setFixedSize(QSize(256,128));
+    // plainPreviewLabel_->setFixedSize(QSize(256,128));
     plainPreviewLabel_->setFixedWidth(260);
     plainPreviewLabel_->setMinimumHeight(128);
     plainPreviewLabel_->setAutoFillBackground(true);
 
     QPalette pal = plainPreviewLabel_->palette();
-    //QColor col=pal.color(QPalette::Window).lighter(120);
+    // QColor col=pal.color(QPalette::Window).lighter(120);
     pal.setColor(QPalette::Window, Qt::white);
     plainPreviewLabel_->setPalette(pal);
 
     plainPreLayout->addWidget(plainPreviewLabel_);
 
     plainPreviewPb_ = new QPushButton(tr("Generate preview"), this);
-    //plainPreLayout->addWidget(plainPreviewPb_);
+    // plainPreLayout->addWidget(plainPreviewPb_);
     reqEditLayout->addWidget(plainPreviewPb_);
 
     plainPreviewPanel_->hide();
@@ -774,7 +772,7 @@ void MvQWmsClientEditor::setupLayerInfoTab()
     // Service meta-data  tab
     //--------------------------
 
-    w                  = new QWidget(this);
+    w = new QWidget(this);
     auto serviceLayout = new QVBoxLayout;
     serviceLayout->setContentsMargins(0, 2, 0, 0);
     serviceLayout->setSpacing(0);
@@ -793,16 +791,16 @@ void MvQWmsClientEditor::setupReqEditPanel()
     if (reqEditSa_->widget())
         return;
 
-    auto* w       = new QWidget(this);
+    auto* w = new QWidget(this);
     auto* reqGrid = new QGridLayout;
     reqGrid->setSizeConstraint(QLayout::SetMinAndMaxSize);
     w->setLayout(reqGrid);
 
     reqEditSa_->setWidget(w);
 
-    QLabel* label;
-    QLineEdit* le;
-    QTextEdit* te;
+    QLabel* label = nullptr;
+    QLineEdit* le = nullptr;
+    QTextEdit* te = nullptr;
     auto* sigMapper = new QSignalMapper(this);
     QStringList labelText, key;
 
@@ -827,9 +825,9 @@ void MvQWmsClientEditor::setupReqEditPanel()
 
     int row = 0;
     for (int i = 0; i < labelText.count(); i++) {
-        label          = new QLabel(labelText[i], this);
+        label = new QLabel(labelText[i], this);
         reqLe_[key[i]] = new QLineEdit(this);
-        le             = reqLe_[key[i]];
+        le = reqLe_[key[i]];
 
         reqGrid->addWidget(label, row, 0);
         reqGrid->addWidget(le, row, 1);
@@ -847,9 +845,9 @@ void MvQWmsClientEditor::setupReqEditPanel()
     key << tr("mv_key_tdim") << tr("mv_key_otherdim");
 
     for (int i = 0; i < labelText.count(); i++) {
-        label          = new QLabel(labelText[i], this);
+        label = new QLabel(labelText[i], this);
         reqTe_[key[i]] = new QTextEdit(this);
-        te             = reqTe_[key[i]];
+        te = reqTe_[key[i]];
 
         reqGrid->addWidget(label, row, 0);
         reqGrid->addWidget(te, row, 1);
@@ -898,7 +896,7 @@ void MvQWmsClientEditor::clearServerDependentData()
 void MvQWmsClientEditor::clearLayerDependentData()
 {
     layerModel_->dataIsAboutToChange();
-    layerModel_->setRootNode(0);
+    layerModel_->setRootNode(nullptr);
 
     styleCombo_->clear();
     crsCombo_->clear();
@@ -908,12 +906,12 @@ void MvQWmsClientEditor::clearLayerDependentData()
 
 void MvQWmsClientEditor::clearDimension()
 {
-    int row = layerParamRowNum_;  //layerGrid_->rowCount();
-    row     = row - 1;
+    int row = layerParamRowNum_;  // layerGrid_->rowCount();
+    row = row - 1;
 
-    //Remove previous dimension widgets from the grid
+    // Remove previous dimension widgets from the grid
     for (int i = 0; i < dimensionNum_; i++) {
-        QWidget* w;
+        QWidget* w = nullptr;
 
         w = layerGrid_->itemAtPosition(row, 2)->widget();
         layerGrid_->removeWidget(w);
@@ -958,7 +956,7 @@ void MvQWmsClientEditor::initFormatCombo()
     }
 
     QString cv = client_->formatCurrentDisplayValue();
-    int index  = -1;
+    int index = -1;
     if (!cv.isEmpty()) {
         index = values.indexOf(cv);
     }
@@ -992,7 +990,7 @@ void MvQWmsClientEditor::setupLayerList()
 
     layerTree_->setCurrentIndex(layerModel_->indexFromNode(client_->layer()->currentNode()));
 
-    //Try to expand the first child of the root node
+    // Try to expand the first child of the root node
     if (layerModel_->rowCount(QModelIndex()) > 0) {
         QModelIndex index = layerModel_->index(0, 0, QModelIndex());
         layerTree_->expand(index);
@@ -1004,7 +1002,7 @@ void MvQWmsClientEditor::initStyleCombo()
     styleCombo_->clear();
 
     QStringList values = client_->styleDisplayValues();
-    QStringList desc   = client_->styleDescriptions();
+    QStringList desc = client_->styleDescriptions();
 
     int i = 0;
     foreach (QString str, values) {
@@ -1040,7 +1038,7 @@ void MvQWmsClientEditor::initCrsCombo()
     }
 
     QString cv = client_->crsCurrentDisplayValue();
-    int index  = -1;
+    int index = -1;
 
     if (!cv.isEmpty()) {
         index = values.indexOf(cv);
@@ -1070,7 +1068,7 @@ void MvQWmsClientEditor::setupDimension()
 
     foreach (MvQOgcDimension* dim, client_->dimension()) {
         QString name = dim->displayName();
-        dim_[name]   = new MvQWmsDimensionGuiItem(dim, dim->currentValues(), layerGrid_, layerParamRowNum_);
+        dim_[name] = new MvQWmsDimensionGuiItem(dim, dim->currentValues(), layerGrid_, layerParamRowNum_);
 
         connect(dim_[name], SIGNAL(textChanged(MvQOgcDimension*, QString)),
                 this, SLOT(slotDimensionChanged(MvQOgcDimension*, QString)));
@@ -1087,7 +1085,7 @@ void MvQWmsClientEditor::setupDimension()
 //
 //------------------------------------------
 /*!
-  Replaces the URL combobox's curret text with the given url and runs getCapabilities.   
+  Replaces the URL combobox's curret text with the given url and runs getCapabilities.
 */
 void MvQWmsClientEditor::slotSelectUrl(const QString& url)
 {
@@ -1098,12 +1096,12 @@ void MvQWmsClientEditor::slotSelectUrl(const QString& url)
 /*!
   Removes duplicates from the URL combobox and trims down
   the its size to a predefined number. This method should be called
-  whenever a new item is inserted into the combo box.   
+  whenever a new item is inserted into the combo box.
 */
 
 void MvQWmsClientEditor::checkUrlComboItems()
 {
-    //Duplicates are removed first!
+    // Duplicates are removed first!
     QMap<QString, int> cntMap;
     for (int i = 0; i < urlCombo_->count(); i++) {
         QString s = urlCombo_->itemText(i);
@@ -1115,16 +1113,16 @@ void MvQWmsClientEditor::checkUrlComboItems()
         }
     }
 
-    //qDebug() << cntMap;
+    // qDebug() << cntMap;
 
     foreach (QString s, cntMap.keys()) {
         int itemCnt = cntMap[s];
         if (itemCnt > 1) {
             for (int i = urlCombo_->count() - 1; i >= 0 && itemCnt > 1; i--) {
                 if (urlCombo_->itemText(i) == s) {
-                    //qDebug() << "remove" << i << urlCombo_->currentIndex() <<  urlCombo_->itemText(i) <<  urlCombo_->currentText();
+                    // qDebug() << "remove" << i << urlCombo_->currentIndex() <<  urlCombo_->itemText(i) <<  urlCombo_->currentText();
                     urlCombo_->removeItem(i);
-                    //qDebug() << urlCombo_->currentText();
+                    // qDebug() << urlCombo_->currentText();
                     itemCnt--;
                 }
             }
@@ -1132,10 +1130,10 @@ void MvQWmsClientEditor::checkUrlComboItems()
     }
 
 
-    //for(int i=0; i < urlCombo_->count(); i++)
+    // for(int i=0; i < urlCombo_->count(); i++)
     //	qDebug() << "after" << urlCombo_->itemText(i);
 
-    //Trim down the combo size to maxCount
+    // Trim down the combo size to maxCount
     int maxCount = 25;
     for (int i = urlCombo_->count() - 1; i > maxCount; i--) {
         urlCombo_->removeItem(i);
@@ -1152,8 +1150,8 @@ void MvQWmsClientEditor::slotSelectVersion(const QString& version)
 
 void MvQWmsClientEditor::slotRunGetCapabilities()
 {
-    //Check if the  URL combobox's current text was
-    //inserted into URL combobox.
+    // Check if the  URL combobox's current text was
+    // inserted into URL combobox.
     client_->setUrl(urlCombo_->currentText(), versionCombo_->currentText());
 
     clearServerDependentData();
@@ -1164,7 +1162,7 @@ void MvQWmsClientEditor::slotRunGetCapabilities()
     }
 
     layerModel_->dataIsAboutToChange();
-    layerModel_->setRootNode(0);
+    layerModel_->setRootNode(nullptr);
 
     requestSplitter_->setEnabled(false);
 
@@ -1202,25 +1200,25 @@ void MvQWmsClientEditor::slotGetCapabilityLoaded()
 
     loadFinished();
 
-    //slotPreviewLoaded(QString());
+    // slotPreviewLoaded(QString());
 
 
     getCapInfo_->editor()->setPlainText(client_->getCapabilityDoc());
     slotUpdateServiceInfo();
-    //serviceInfo_->setPlainText(client_->serviceTitle());
+    // serviceInfo_->setPlainText(client_->serviceTitle());
 
-    //loadFinished();
+    // loadFinished();
 
     slotUpdateLayerInfo();
     loadStarted();
     client_->downloadLogo();
 
     if (urlCombo_->findText(urlCombo_->currentText()) == -1) {
-        //for(int i=0; i < urlCombo_->count(); i++)
+        // for(int i=0; i < urlCombo_->count(); i++)
         //	qDebug() << urlCombo_->itemText(i)
 
         // urlCombo_->currentText();
-        disconnect(urlCombo_, SIGNAL(activated(QString)), 0, 0);
+        disconnect(urlCombo_, SIGNAL(activated(QString)), nullptr, nullptr);
         urlCombo_->insertItem(0, urlCombo_->currentText());
         urlCombo_->setCurrentIndex(0);
         connect(urlCombo_, SIGNAL(activated(QString)),
@@ -1228,7 +1226,7 @@ void MvQWmsClientEditor::slotGetCapabilityLoaded()
         // urlCombo_->currentText();
 
         checkUrlComboItems();
-        //qDebug() << urlCombo_->currentText();
+        // qDebug() << urlCombo_->currentText();
     }
     else {
         checkUrlComboItems();
@@ -1245,7 +1243,7 @@ void MvQWmsClientEditor::slotSelectLayer(const QModelIndex& index)
     initCrsCombo();
     setupDimension();
 
-    //slotPreviewLoaded(QString());
+    // slotPreviewLoaded(QString());
 
     slotUpdateLayerInfo();
     loadStarted();
@@ -1339,14 +1337,14 @@ void MvQWmsClientEditor::slotUpdateLayerInfo()
     s += "<tr><td class=\"first\">Style</td><td>" + styleCombo_->currentText() + "</td></tr>";
 
     /*s+="<tr><td class=\"first\">Dimensions</td>";
-	QMapIterator<QString,MvQWmsDimensionGuiItem*> it(dim_);
-	s+="<td>";
-	while (it.hasNext()) 
-	{
-    		it.next();
-		s+=it.key() + " = " + it.value()->currentValue() + "<br>";		
-	}
-	s+="</td></tr>";*/
+    QMapIterator<QString,MvQWmsDimensionGuiItem*> it(dim_);
+    s+="<td>";
+    while (it.hasNext())
+    {
+            it.next();
+        s+=it.key() + " = " + it.value()->currentValue() + "<br>";
+    }
+    s+="</td></tr>";*/
 
     s += "<tr><td class=\"first\">Preview</td>";
     s += "<td class=\"image\" align=center>Preview not loaded</td></tr>";
@@ -1434,7 +1432,6 @@ void MvQWmsClientEditor::slotSetGetMapInfo(QString req, QStringList reqSplit)
 {
     QString s;
     if (!req.isEmpty()) {
-        QString getMaps;
         s = "<table><tbody>";
         s += "<tr><th class=\"first\">Frame</th><th>Request</th></tr>";
 
@@ -1484,7 +1481,7 @@ void MvQWmsClientEditor::slotClientReset()
     else {
         initExtraParEdit();
 
-        //Init  url
+        // Init  url
         if (client_->url().isEmpty() || urlCombo_->itemText(0) != client_->url()) {
             urlCombo_->insertItem(0, client_->url());
             urlCombo_->setCurrentIndex(0);
@@ -1497,7 +1494,7 @@ void MvQWmsClientEditor::slotClientReset()
 void MvQWmsClientEditor::initClientMode()
 {
     if (client_->clientMode() == MvQWmsUiClient::BasicMode) {
-        //Toolbar  + menubar  + log
+        // Toolbar  + menubar  + log
         actionCapability_->setEnabled(false);
         actionStopLoad_->setEnabled(false);
 
@@ -1508,7 +1505,7 @@ void MvQWmsClientEditor::initClientMode()
         logPanel_->clearLog();
         StatusMsgHandler::instance()->clear();
 
-        //Layer tabs
+        // Layer tabs
         layerPanel_->hide();
         clearLayerDependentData();
 
@@ -1522,7 +1519,7 @@ void MvQWmsClientEditor::initClientMode()
         plainPreviewPanel_->show();
 
 
-        //This build the scrollarea and the request editors
+        // This build the scrollarea and the request editors
         setupReqEditPanel();
 
         MvQGetMapRequest* req = client_->getMapRequest();
@@ -1561,14 +1558,14 @@ void MvQWmsClientEditor::initClientMode()
 
         initExtraParEdit();
 
-        //Init  url
+        // Init  url
         if (client_->url().isEmpty() || urlCombo_->itemText(0) != client_->url()) {
             urlCombo_->insertItem(0, client_->url());
         }
         urlCombo_->setCurrentIndex(0);
 
-        //Run getCapapabilities
-        //This will init most of the GUIs
+        // Run getCapapabilities
+        // This will init most of the GUIs
         slotRunGetCapabilities();
     }
 }
@@ -1590,7 +1587,7 @@ void MvQWmsClientEditor::slotClientModeChanged(QString mode)
 void MvQWmsClientEditor::loadStarted()
 {
     /*loadLabel_->show();
-	loadLabel_->movie()->start();*/
+    loadLabel_->movie()->start();*/
 
     loadProgress_->setRange(0, 0);
     loadProgress_->show();
@@ -1654,7 +1651,7 @@ void MvQWmsClientEditor::writeSettings()
         settings.setValue("state", saveState());
         settings.setValue("mainSplitter", mainSplitter_->saveState());
         settings.setValue("requestSplitter", requestSplitter_->saveState());
-        //settings.setValue("layerSplitter",layerSplitter_->saveState());
+        // settings.setValue("layerSplitter",layerSplitter_->saveState());
         settings.setValue("layerTabIndex", layerTab_->currentIndex());
         settings.setValue("layerInfoTabIndex", layerInfoTab_->currentIndex());
 
@@ -1695,7 +1692,7 @@ void MvQWmsClientEditor::readSettings()
         mainSplitter_->restoreState(settings.value("mainSplitter").toByteArray());
         requestSplitter_->restoreState(settings.value("requestSplitter").toByteArray());
 
-        //Init tabs
+        // Init tabs
         int ival = settings.value("layerInfoTabIndex").toInt();
         layerInfoTab_->setCurrentIndex(ival);
 
@@ -1705,7 +1702,7 @@ void MvQWmsClientEditor::readSettings()
         getCapInfo_->readSettings(settings, "getCapInfo");
 
         QStringList lst(settings.value("urlCombo").toStringList());
-        //lst.remove(client_->url())
+        // lst.remove(client_->url())
         urlCombo_->addItems(lst);
 
         if (client_->url().isEmpty())
@@ -1720,7 +1717,7 @@ void MvQWmsClientEditor::readSettings()
     settings.beginGroup("mainWindow");
 
     if (settings.value("actionLogStatus").isNull()) {
-        //Hidden by default
+        // Hidden by default
         actionLog_->setChecked(false);
     }
     else {
