@@ -51,7 +51,7 @@ class MvQWmsDimensionGuiItem : public QObject
     Q_OBJECT
 public:
     MvQWmsDimensionGuiItem(MvQOgcDimension*, QString, QGridLayout*, int);
-    ~MvQWmsDimensionGuiItem();
+    ~MvQWmsDimensionGuiItem() override;
     QString currentValue();
     void addValue(QString);
 
@@ -81,12 +81,12 @@ class MvQWmsClientEditor : public MvQMainWindow
     Q_OBJECT
 
 public:
-    MvQWmsClientEditor(MvQWmsUiClient*, QWidget* w = 0);
-    ~MvQWmsClientEditor();
+    MvQWmsClientEditor(MvQWmsUiClient*, QWidget* w = nullptr);
+    ~MvQWmsClientEditor() override;
 
 public slots:
     void slotClientModeChanged(QString);
-    //void slotSaveInfo();
+    // void slotSaveInfo();
     void slotSelectUrl(const QString&);
     void slotSelectVersion(const QString&);
     void slotRunGetCapabilities();
@@ -142,56 +142,57 @@ protected:
     void writeSettings();
     void readSettings();
 
-    MvQWmsUiClient* client_;
+private:
+    MvQWmsUiClient* client_{nullptr};
 
-    QVBoxLayout* mainLayout_;
-    QSplitter* mainSplitter_;
-    QSplitter* requestSplitter_;
+    QVBoxLayout* mainLayout_{nullptr};
+    QSplitter* mainSplitter_{nullptr};
+    QSplitter* requestSplitter_{nullptr};
 
-    //QCheckBox* openCb_;
+    // QCheckBox* openCb_;
 
-    QLabel* loadLabel_;
-    QLabel* statusMessageLabel_;
+    QLabel* loadLabel_{nullptr};
+    QLabel* statusMessageLabel_{nullptr};
     QList<QWidget*> advancedModeOnlyWidgets_;
 
     MvQMainWindow::MenuItemMap menuItems_;
-    QAction* actionCapability_;
-    QAction* actionStopLoad_;
-    QAction* actionLog_;
-    QComboBox* urlCombo_;
-    QComboBox* versionCombo_;
-    QComboBox* clientModeCombo_;
+    QAction* actionCapability_{nullptr};
+    QAction* actionStopLoad_{nullptr};
+    QAction* actionLog_{nullptr};
+    QComboBox* urlCombo_{nullptr};
+    QComboBox* versionCombo_{nullptr};
+    QComboBox* clientModeCombo_{nullptr};
     QMap<QString, MvQWmsUiClient::ClientMode> clientModeMap_;
 
-    QComboBox* formatCombo_;
-    QLineEdit* extraGetCapEdit_;
-    QLineEdit* extraGetMapEdit_;
+    QComboBox* formatCombo_{nullptr};
+    QLineEdit* extraGetCapEdit_{nullptr};
+    QLineEdit* extraGetMapEdit_{nullptr};
 
-    QTabWidget* layerTab_;
-    QWidget* layerPanel_;
-    QGridLayout* layerGrid_;
-    QHBoxLayout* layerLayout_;
-    MvQTreeView* layerTree_;
-    MvQOgcTreeModel* layerModel_;
-    QComboBox* crsCombo_;
-    QComboBox* styleCombo_;
-    QPushButton* previewPb_;
-    int dimensionNum_;
-    int layerParamRowNum_;
+    QTabWidget* layerTab_{nullptr};
+    QWidget* layerPanel_{nullptr};
+    QGridLayout* layerGrid_{nullptr};
+    QHBoxLayout* layerLayout_{nullptr};
+    MvQTreeView* layerTree_{nullptr};
+    MvQOgcTreeModel* layerModel_{nullptr};
+    QComboBox* crsCombo_{nullptr};
+    QComboBox* styleCombo_{nullptr};
+    QPushButton* previewPb_{nullptr};
+    int dimensionNum_{0};
+    int layerParamRowNum_{0};
     QMap<QString, MvQWmsDimensionGuiItem*> dim_;
-    QLabel* crsLabel_;
+    QLabel* crsLabel_{nullptr};
 
-    QTabWidget* layerInfoTab_;
-    PlainTextWidget* getCapInfo_;
-    QTextBrowser* serviceInfo_;
-    QTextBrowser* layerPreview_;
-    QTextBrowser* getMapInfoSplit_;
+    QTabWidget* layerInfoTab_{nullptr};
+    PlainTextWidget* getCapInfo_{nullptr};
+    QTextBrowser* serviceInfo_{nullptr};
+    QTextBrowser* layerPreview_{nullptr};
+    QTextBrowser* getMapInfoSplit_{nullptr};
     //    MvQHighlighter* highlighterSplit_;
-    QPushButton* plainPreviewPb_;
-    QLabel* plainPreviewLabel_;
-    QWidget* plainPreviewPanel_;
+    QPushButton* plainPreviewPb_{nullptr};
+    QLabel* plainPreviewLabel_{nullptr};
+    QWidget* plainPreviewPanel_{nullptr};
 
-    MvQLogPanel* logPanel_;
+    MvQLogPanel* logPanel_{nullptr};
 
 #ifdef UI_TODO
     MvQTextEditSearchLine* getCapSearch_;
@@ -199,16 +200,16 @@ protected:
 
     //    MvQWmsGetCapHighlighter* highlighterGetCap_;
 
-    QProgressBar* loadProgress_;
+    QProgressBar* loadProgress_{nullptr};
 
     QMap<QString, QLineEdit*> reqLe_;
     QMap<QString, QTextEdit*> reqTe_;
-    QSplitter* reqSplitter_;
-    QWidget* reqEditPanel_;
-    QScrollArea* reqEditSa_;
+    QSplitter* reqSplitter_{nullptr};
+    QWidget* reqEditPanel_{nullptr};
+    QScrollArea* reqEditSa_{nullptr};
 
-    QDialogButtonBox* buttonBox_;
-    QPushButton* savePb_;
-    QPushButton* okPb_;
-    QPushButton* cancelPb_;
+    QDialogButtonBox* buttonBox_{nullptr};
+    QPushButton* savePb_{nullptr};
+    QPushButton* okPb_{nullptr};
+    QPushButton* cancelPb_{nullptr};
 };
