@@ -23,14 +23,6 @@ const int XWIND_POS = 1010;     // x wind position
 //_____________________________________________________________________________
 
 MvThermoDataBase::MvThermoDataBase(MvField& fieldToken, const ThermoParams& pars) :
-    lnspFlag_(false),
-    counter_(0),
-    tCount_(0),
-    dCount_(0),
-    uCount_(0),
-    vCount_(0),
-    pCount_(0),
-    nTIME_STR_(17),
     currField_(fieldToken),
     pars_(&pars)
 {
@@ -52,7 +44,7 @@ void MvThermoDataBase::initialiseDataMemory()
 void MvThermoDataBase::readOneSetOfFields(MvFieldSetIterator& iter)
 {
     const double cBIGDOUBLE = 3.4E35;
-    const double oneMinute  = 1.0 / 24.0;
+    const double oneMinute = 1.0 / 24.0;
 
     // Get time key info
     this->generateTimeKey();
@@ -110,10 +102,10 @@ bool MvThermoDataBase::generate(MvNetCDF& netcdf)
 
     // Get netcdf variables
     // tCount_ and dCount_ should have the same value
-    long size      = tCount_;
-    MvNcVar* time  = netcdf.getVariable(sTIME);
-    MvNcVar* temp  = netcdf.getVariable(sTEMP);
-    MvNcVar* dew   = netcdf.getVariable(sDEWPOINT);
+    long size = tCount_;
+    MvNcVar* time = netcdf.getVariable(sTIME);
+    MvNcVar* temp = netcdf.getVariable(sTEMP);
+    MvNcVar* dew = netcdf.getVariable(sDEWPOINT);
     MvNcVar* press = netcdf.getVariable(sPRESSURE);
     if (!time || !temp || !dew || !press)
         throw MvException("Thermo-> ERROR accessing netCDF variables");
@@ -221,7 +213,7 @@ MvThermoDataBase::getValueFromCurrentField()
 void MvThermoDataBase::collectValue(double val)
 {
     // Get param and level
-    int par   = currField_.parameter();
+    int par = currField_.parameter();
     int level = this->getLevel();
 
     // Save param and level values
@@ -256,9 +248,9 @@ void MvThermoDataBase::collectValue(double val)
 void MvThermoDataBase::rescaleValues()
 {
     for (int i = 0; i < tCount_; i++) {
-        T_[i]  = T_[i] - K2C;
+        T_[i] = T_[i] - K2C;
         TD_[i] = TD_[i] - K2C;
-        P_[i]  = P_[i] / 100.;
+        P_[i] = P_[i] / 100.;
     }
 
     // Re-scale pressure related to the wind
@@ -365,7 +357,7 @@ MvThermoDataBase::formulaPrintName()
     std::string name = pars_->dewPointFormulaType_;
     for (char& it : name) {
         char cc = it;
-        it      = (cc == '_') ? ' ' : tolower(cc);
+        it = (cc == '_') ? ' ' : tolower(cc);
     }
 
     return name;
@@ -377,7 +369,7 @@ MvThermoDataBase::title(MvNetCDF& netcdf)
     // Get first time information
     std::string sdate = timeKey_.substr(0, 8);
     std::string stime = timeKey_.substr(8, 4);
-    int istep         = atoi(timeKey_.substr(12, 4).c_str());
+    int istep = atoi(timeKey_.substr(12, 4).c_str());
 
     // Create title
     char title[200];
@@ -393,9 +385,9 @@ MvThermoDataBase::title(MvNetCDF& netcdf)
             // Coordinates used may not be the same as the input ones
             MvNcAtt* tmpatt = netcdf.getAttribute("Coordinates");
             std::string str = tmpatt->as_string(0);
-            int ipos        = str.find('/');
-            float lat       = atof(str.substr(0, ipos).c_str());
-            float lon       = atof(str.substr(ipos + 1).c_str());
+            int ipos = str.find('/');
+            float lat = atof(str.substr(0, ipos).c_str());
+            float lon = atof(str.substr(ipos + 1).c_str());
             sprintf(title, "%s %s step %d [nearest: %.2f,%.2f] %s",
                     sdate.c_str(), stime.c_str(), istep, lat, lon,
                     this->formulaPrintName().c_str());
@@ -433,7 +425,7 @@ void MvThermoDataHalfLevels::computeLevelsTd()
 void MvThermoDataHalfLevels::processPressure(double val)
 {
     lnspFlag_ = true;
-    LNSP_     = val;
+    LNSP_ = val;
 }
 
 
@@ -454,7 +446,7 @@ void MvThermoDataFullLevels::computeLevelsTd()
 void MvThermoDataFullLevels::processPressure(double val)
 {
     lnspFlag_ = true;
-    LNSP_     = val;
+    LNSP_ = val;
 }
 
 //==============================================================
@@ -481,7 +473,7 @@ void MvThermoDataPressureLevels::processPressure(double)
 void MvThermoDataPressureLevels::rescaleValues()
 {
     for (int i = 0; i < tCount_; i++) {
-        T_[i]  = T_[i] - K2C;
+        T_[i] = T_[i] - K2C;
         TD_[i] = TD_[i] - K2C;
     }
 }
@@ -498,7 +490,7 @@ MvThermoDataUkmoNDLevels::MvThermoDataUkmoNDLevels(MvField& fieldToken, const Th
 void MvThermoDataUkmoNDLevels::collectValue(double val)
 {
     // Get param and level
-    int par   = currField_.parameter();
+    int par = currField_.parameter();
     int level = this->getLevel();
 
     // Save param and level values
@@ -555,7 +547,7 @@ void MvThermoDataUkmoNDLevels::computeLevelsTd()
 void MvThermoDataUkmoNDLevels::rescaleValues()
 {
     for (int i = 0; i < tCount_; i++) {
-        T_[i]  = T_[i] - K2C;
+        T_[i] = T_[i] - K2C;
         TD_[i] = TD_[i] - K2C;
     }
 }
