@@ -10,7 +10,7 @@
 #include <iostream>
 #include <string>
 
-#include <stdio.h>
+#include <cstdio>
 
 #include "grib_api.h"
 
@@ -32,36 +32,35 @@ int main(int argc, char** argv)
 
 int toVapor(const std::string& fgrib, const std::string& fvapor)
 {
-    FILE* fp;
-    FILE* fpOut;
+    FILE* fp = nullptr;
+    FILE* fpOut = nullptr;
     grib_handle* gh = nullptr;
-    int err         = 0;
+    int err = 0;
 
-    double* value   = nullptr;
+    double* value = nullptr;
     float* valueOut = nullptr;
-    size_t valNum   = 0;
+    size_t valNum = 0;
 
     const int MAX_VAL_LEN = 64;
-    size_t vlen;
+    size_t vlen = 0;
     char cval[MAX_VAL_LEN];
 
-    //Open grib file for reading
+    // Open grib file for reading
     fp = fopen(fgrib.c_str(), "r");
     if (!fp) {
         std::cout << "Cannot open grib file: " << fgrib << std::endl;
         return 1;
     }
 
-
-    //Open output file
+    // Open output file
     fpOut = fopen(fvapor.c_str(), "w+");
     if (!fpOut) {
         std::cout << "Cannot open output file: " << fvapor << std::endl;
+        fclose(fp);
         return 1;
     }
 
-
-    //Get messages form the file
+    // Get messages form the file
     int cnt = 0;
     while ((gh = grib_handle_new_from_file(nullptr, fp, &err)) != nullptr) {
         if (!gh) {
@@ -69,7 +68,7 @@ int toVapor(const std::string& fgrib, const std::string& fvapor)
             return 1;
         }
 
-        //Grid type
+        // Grid type
         std::string gridType;
         vlen = MAX_VAL_LEN;
         if (grib_get_string(gh, "gridType", cval, &vlen) == GRIB_SUCCESS) {
@@ -84,8 +83,8 @@ int toVapor(const std::string& fgrib, const std::string& fvapor)
         GRIB_CHECK(grib_get_string(gh, "shortName", cval, &vlen), nullptr);
         std::string shortName(cval);
 
-        //Get grid dimensions
-        long nx, ny;
+        // Get grid dimensions
+        long nx = 0, ny = 0;
         std::cout << "message: " << cnt << std::endl;
 
         GRIB_CHECK(grib_get_long(gh, "Ni", &nx), nullptr);
@@ -93,16 +92,16 @@ int toVapor(const std::string& fgrib, const std::string& fvapor)
 
         std::cout << nx << " " << ny << std::endl;
 
-        //Allocate array for values
-        size_t num;
+        // Allocate array for values
+        size_t num = 0;
         grib_get_size(gh, "values", &num);
         if (num != static_cast<size_t>(nx * ny)) {
             std::cout << "No values found" << std::endl;
             return 1;
         }
         else if (valNum == 0) {
-            valNum   = num;
-            value    = new double[num];
+            valNum = num;
+            value = new double[num];
             valueOut = new float[num];
         }
         else if (num != valNum) {
@@ -110,7 +109,7 @@ int toVapor(const std::string& fgrib, const std::string& fvapor)
             return 1;
         }
 
-        //Read values
+        // Read values
         if (grib_get_double_array(gh, "values", value, &valNum) != 0) {
             delete[] value;
             delete[] valueOut;
@@ -118,14 +117,14 @@ int toVapor(const std::string& fgrib, const std::string& fvapor)
             return 1;
         }
 
-        //Check if data should be rearranged
-        long iScan, jScan;
-        long jOrder;
+        // Check if data should be rearranged
+        long iScan = 0, jScan = 0;
+        long jOrder = 0;
 
-        //GRIB_CHECK(grib_get_double(gh,"latitudeOfFirstGridPointInDegrees",&lat1),0);
-        //GRIB_CHECK(grib_get_double(gh,"longitudeOfFirstGridPointInDegrees",&lon1),0);
-        //GRIB_CHECK(grib_get_double(gh,"latitudeOfLastGridPointInDegrees",&lat2),0);
-        //GRIB_CHECK(grib_get_double(gh,"longitudeOfLastGridPointInDegrees",&lon2),0);
+        // GRIB_CHECK(grib_get_double(gh,"latitudeOfFirstGridPointInDegrees",&lat1),0);
+        // GRIB_CHECK(grib_get_double(gh,"longitudeOfFirstGridPointInDegrees",&lon1),0);
+        // GRIB_CHECK(grib_get_double(gh,"latitudeOfLastGridPointInDegrees",&lat2),0);
+        // GRIB_CHECK(grib_get_double(gh,"longitudeOfLastGridPointInDegrees",&lon2),0);
 
         GRIB_CHECK(grib_get_long(gh, "iScansPositively", &iScan), nullptr);
         GRIB_CHECK(grib_get_long(gh, "jScansPositively", &jScan), nullptr);
@@ -133,7 +132,7 @@ int toVapor(const std::string& fgrib, const std::string& fvapor)
 
         std::cout << "nx=" << nx << " ny=" << ny << " iScan=" << iScan << " jScan=" << jScan << " jOrder=" << jOrder << std::endl;
 
-        //i-direction scan
+        // i-direction scan
         if (jOrder == 0) {
             if (iScan == 1 && jScan == 0) {
                 for (unsigned int j = 0; j < ny; j++)
@@ -165,7 +164,7 @@ int toVapor(const std::string& fgrib, const std::string& fvapor)
                 valueOut[i] /= 9.81;
 
 
-        //Write out fields
+        // Write out fields
         fwrite(valueOut, 4, valNum, fpOut);
 
         grib_handle_delete(gh);
