@@ -14,9 +14,11 @@
 
 
 #ifdef MAGICS
-namespace magics {
+namespace magics
+{
 #else
-namespace metview {
+namespace metview
+{
 #endif
 
 
@@ -41,5 +43,4 @@ bool TSortable::operator<=(const TSortable& aDateObject) const
 {
     return (bool)(*this < aDateObject || *this == aDateObject);
 }
-
 }
