@@ -32,7 +32,7 @@ class MvKey;
 class MvKeyValue
 {
 public:
-    MvKeyValue() {}
+    MvKeyValue() = default;
     MvKeyValue(const std::string& key, MvVariant::Type type) :
         key_(key),
         value_(type) {}
@@ -60,7 +60,7 @@ class MvBufrValueItem
     friend class MvBufrValueGroup;
 
 public:
-    MvBufrValueItem() {}
+    MvBufrValueItem() = default;
     MvBufrValueItem(const MvKeyValue& value, bool valueTypeKnown, const std::vector<MvKeyConditionDefinition>& coordCondDefs = std::vector<MvKeyConditionDefinition>());
     MvBufrValueItem(const MvKeyValue& value, const MvKeyConditionDefinition& condDef, bool valueTypeKnown, const std::vector<MvKeyConditionDefinition>& coordCondDefs = std::vector<MvKeyConditionDefinition>());
     ~MvBufrValueItem();
@@ -100,7 +100,7 @@ protected:
 class MvBufrValueGroup
 {
 public:
-    MvBufrValueGroup() {}
+    MvBufrValueGroup() = default;
     ~MvBufrValueGroup();
 
     static long longMissingValue_;
@@ -142,11 +142,11 @@ public:
     MvBufrConditionGroup() :
         allMatch_(true) {}
 
-    virtual void add(const MvBufrValueItem&);
+    void add(const MvBufrValueItem&) override;
     bool match() const { return allMatch_; }
-    void checkCurrentKey(MvObs*);
+    void checkCurrentKey(MvObs*) override;
     void checkConditions(MvObs*);
-    void reset();
+    void reset() override;
     bool valuesDiffer(const MvBufrConditionGroup& o) const;
 
 protected:
@@ -158,14 +158,14 @@ protected:
 class MvBufrStandardGroup : public MvBufrValueGroup
 {
 public:
-    MvBufrStandardGroup() {}
+    MvBufrStandardGroup() = default;
     void checkCurrentKey(MvObs*);
 };
 
 class BufrFilterEngineObserver
 {
 public:
-    BufrFilterEngineObserver() {}
+    BufrFilterEngineObserver() = default;
     virtual void notifyBufrFilterProgress(int) = 0;
 };
 
@@ -204,7 +204,7 @@ protected:
     bool evalMsgRdbType(MvEccBufrMessage* msg) const;
 
     bool enabled_;
-    std::vector<int> messageNumber_;  //starts at 1
+    std::vector<int> messageNumber_;  // starts at 1
     std::vector<int> editionNumber_;
     std::vector<int> originatingCentre_;
     std::vector<std::string> originatingCentreStr_;
@@ -233,7 +233,7 @@ public:
     const std::string& value(const std::string& key, bool mustExist = true) const;
     void values(const std::string& key, std::vector<std::string>& valueVec, const std::string& separator = "/") const;
     bool isExtractedDefined() const;
-    void run(const BufrFilterDef& def, const std::string& resFileName, MvKeyProfile* result,
+    void run(const BufrFilterDef& def, const std::string& resFileName, MvKeyProfile* resProf,
              int totalMsgNum, const std::vector<MvEccBufrMessage*>&);
 
     void runWithBufrData(const BufrFilterDef& def, const std::string& resFileName, MvKeyProfile* resProf,
@@ -247,8 +247,8 @@ public:
     void toCsv(const std::string& fName);
 
 protected:
-    //NR_returnObs  /**< - return the next available subset (from this or the next BUFR msg */
-    //NR_returnMsg  /**< - return the first subset from the next BUFR message */
+    // NR_returnObs  /**< - return the next available subset (from this or the next BUFR msg */
+    // NR_returnMsg  /**< - return the first subset from the next BUFR message */
 
     enum CollectMode
     {
