@@ -25,10 +25,10 @@ MvAbstractApplication::MvAbstractApplication(const char* name)
     MvLog::registerApp(this);
 }
 
-void MvAbstractApplication::toLog(const std::string& msg, MvLogLevel level, bool popup)
+void MvAbstractApplication::toLog(const std::string& msg, const std::string& details, MvLogLevel level, bool popup)
 {
-    abcApp_->writeToLog(msg, level);
-    abcApp_->writeToUiLog(msg, level, popup);
+    abcApp_->writeToLog(msg + details, level);
+    abcApp_->writeToUiLog(msg, details, level, popup);
 }
 
 void MvAbstractApplication::abortWithPopup(const std::string& text)
