@@ -22,12 +22,12 @@ public:
     virtual ~MvAbstractApplication() = default;
 
     static const std::string& name() { return name_; }
-    static void toLog(const std::string& msg, MvLogLevel level, bool popup);
+    static void toLog(const std::string& msg, const std::string& details, MvLogLevel level, bool popup);
     static void abortWithPopup(const std::string& text);
 
 protected:
     virtual void writeToLog(const std::string& msg, MvLogLevel level) = 0;
-    virtual void writeToUiLog(const std::string& msg, MvLogLevel level, bool popup) = 0;
+    virtual void writeToUiLog(const std::string& msg, const std::string& details, MvLogLevel level, bool popup) = 0;
     virtual void exitWithError() = 0;
 
 private:
