@@ -12,14 +12,17 @@
 #include <vector>
 
 #ifdef MAGICS
-namespace magics {
+namespace magics
+{
 #else
-namespace metview {
+namespace metview
+{
 #endif
 
 class MvBufrEdition;
 
-class MvBufrElementTable {
+class MvBufrElementTable
+{
 public:
     const std::string& keyName(int);  // const;
     bool buildElementTable();
