@@ -9,6 +9,8 @@
 
 #pragma once
 
+#include <memory>
+
 enum class MvLogLevel
 {
     INFO,
@@ -17,3 +19,9 @@ enum class MvLogLevel
     DBG
 };
 class MvApplication;
+
+namespace metview
+{
+class StatsCompute;
+using StatsComputePtr = std::shared_ptr<StatsCompute>;
+}  // namespace metview
