@@ -741,8 +741,9 @@ void MvGeoPoints::resizeValueColumns()
     if ((nValCols()) > 0 && (nValCols() != values_.size()))
         values_.resize(nValCols());
 
-    for (auto& value : values_)
+    for (auto& value : values_) {
         value.resize(count_);
+    }
 }
 
 
@@ -977,7 +978,7 @@ void MvGeoPoints::ensureNColsHasStnIds()
 
 
 //_____________________________________________________________________
-bool MvGeoPoints::load(std::ifstream& f, const size_t nmax)
+bool MvGeoPoints::load(std::ifstream& f, const size_t nmax, bool inGptSet)
 {
     char line[10240];
     size_t n = 0;
@@ -986,9 +987,22 @@ bool MvGeoPoints::load(std::ifstream& f, const size_t nmax)
 
 
     if (nmax == 0) {
+        int numHashGeo = 0;
         //-- first count the lines
-        while (f.getline(line, sizeof(line)))
+        while (f.getline(line, sizeof(line))) {
             numPts++;
+            // in we're in a geopointset, we only want to scan to the next #GEO
+            if (inGptSet) {
+                if (strncmp(line, "#GEO", 4) == 0) {
+                    if (strncmp(line, "#GEOPOINTSET", 12) != 0) {
+                        numHashGeo++;
+                        if (numHashGeo == 2) {
+                            break;
+                        }
+                    }
+                }
+            }
+        }
     }
     else
         numPts = nmax;
@@ -1193,6 +1207,11 @@ bool MvGeoPoints::load(std::ifstream& f, const size_t nmax)
             }
             else if (!strncmp(line, "#GEO", 4))  // start of new geopoints file
             {
+                // rewind to just before the #GEO and break the loop
+                // this is so that parsing of geopointset files is more
+                // consistent between the first and the rest of the embedded
+                // geopoints files
+                f.seekg(-5, f.cur);
                 break;
             }
         }
