@@ -77,6 +77,9 @@ struct File
 public:
     File(const char* name, const char* mode) { f_ = fopen(name, mode); }
     ~File() { close(); }
+    File(const File&) = delete;
+    File& operator=(const File&) = delete;
+
     void close()
     {
         if (f_)
@@ -100,7 +103,7 @@ static eFileType SearchMarsParserBreakers(const char* fileName)
     if (!f.f_)
         return eMissingFile;  //-- missing file
 
-    bool isBinary      = false;
+    bool isBinary = false;
     bool isNumbersOnly = true;
     const int CHECKLEN = 4000;  //-- may be a huge PostScript file
                                 //-- => check beginning only is ok
@@ -148,10 +151,10 @@ static const char* isWeatherSymbolJson(const File& f)
         "WS_MARKER", "WS_SHAPE", "WS_SHEARLINE", "WS_STORM", "WS_TEXT", "WS_TROPICALWAVE",
         "WS_TROUGH", "WS_WARMFRONT", "WS_WMOSYMBOL",
         "WS_COLLECTION"};
-    static char startBraceCh    = '{';
-    static std::string quoteCh  = "\"";
+    static char startBraceCh = '{';
+    static std::string quoteCh = "\"";
     static std::string classStr = "\"class_ws\":";
-    static std::string conv     = "metview-ws";
+    static std::string conv = "metview-ws";
     if (!f.f_)
         return nullptr;
 
@@ -199,9 +202,9 @@ static const char* isWeatherSymbolJson(const File& f)
     return nullptr;
 }
 
-//inline static bool scan_file_extension(const char* file, int length, const char* ext)
+// inline static bool scan_file_extension(const char* file, int length, const char* ext)
 //{
-//    int ext_length = strlen(ext);
+//     int ext_length = strlen(ext);
 
 //    return (length >= ext_length && !strcasecmp(&file[length - ext_length], ext));
 //}
@@ -212,7 +215,7 @@ static bool get_file_extension(const char* file, std::string& suffix1,
     std::string fn(file);
     auto pos = fn.find_last_of(".");
     if (pos != 0 && pos != std::string::npos && pos + 1 != fn.size()) {
-        suffix1   = fn.substr(pos);
+        suffix1 = fn.substr(pos);
         auto pos2 = fn.find_last_of(".", pos - 1);
         if (pos != 0 && pos2 != std::string::npos && pos2 + 1 != pos) {
             suffix2 = fn.substr(pos2);
@@ -238,7 +241,7 @@ static bool scanDirForOdb(const char* dir)
     while ((dirp = readdir(dp)) != nullptr) {
         std::string name(dirp->d_name);
 
-        //std::cout << "dir: " << name;
+        // std::cout << "dir: " << name;
         if ((pos = name.find(".sch")) != std::string::npos &&
             name.size() >= 5 && pos > 0 && pos + 4 == name.size()) {
             retval = true;
@@ -263,8 +266,12 @@ static bool scanDirForOdb(const char* dir)
 // store the suffix based mappings in hash tables
 static std::unordered_map<std::string, const char*> doubleSuffixMap = {
     {".tar.gz", "TAR_GZ"},
-    {".tar.bz", "TAR_BZ"},
+    {".tar.gzip", "TAR_GZ"},
+    {".tar.bz", "TAR_BZ2"},
     {".tar.bz2", "TAR_BZ2"},
+    {".tar.bzip2", "TAR_BZ2"},
+    {".tar.z", "TAR_Z"},
+    {".tar.Z", "TAR_Z"},
     {".geo.json", "GEOJSON"}};
 
 static std::unordered_map<std::string, const char*> singleSuffixMap = {
@@ -289,13 +296,25 @@ static std::unordered_map<std::string, const char*> singleSuffixMap = {
     {".geojson", "GEOJSON"},
     {".jpg", "JPEG"},
     {".jpeg", "JPEG"},
-    {".py", "PYTHON"}};
+    {".py", "PYTHON"},
+    {".tgz", "TAR_GZ"},
+    {".tbz", "TAR_BZ2"},
+    {".tbz2", "TAR_BZ2"},
+    {".tz", "TAR_Z"},
+    {".gz", "GZ"},
+    {".gzip", "GZ"},
+    {".bz", "BZ2"},
+    {".bz2", "BZ2"},
+    {".bzip2", "BZ2"},
+    {".z", "Z"},
+    {".Z", "Z"},
+    {".zip", "ZIP"}};
 
 static const char* scan_file(const char* file)
 {
-    static const int cMAXSHIFT        = 8;  //-- search tolerance for word "GRIB" or "BUFR"
-    static const int cMINREAD         = 4;  //-- need to be able to read at least this much
-//    static const std::string cGEOJSON = ".geojson";
+    static const int cMAXSHIFT = 8;  //-- search tolerance for word "GRIB" or "BUFR"
+    static const int cMINREAD = 4;   //-- need to be able to read at least this much
+                                     //    static const std::string cGEOJSON = ".geojson";
     static const char* cGEOJSON = "GEOJSON";
 
     File f(file, "r");
@@ -305,7 +324,7 @@ static const char* scan_file(const char* file)
 
     // Determine type by the suffixes
     std::string suffix1, suffix2;
-    bool geojsonBySuffix=false;
+    bool geojsonBySuffix = false;
     if (get_file_extension(file, suffix1, suffix2)) {
         if (!suffix2.empty()) {
             metview::toLower(suffix2);
@@ -334,7 +353,8 @@ static const char* scan_file(const char* file)
         auto ws = isWeatherSymbolJson(f);
         if (ws) {
             return ws;
-        } else {
+        }
+        else {
             return cGEOJSON;
         }
     }
@@ -438,12 +458,6 @@ static const char* scan_file(const char* file)
         else if (strncmp(buf.ch, "<magics", 7) == 0) {
             return "MAGML";
         }
-        else if (strncmp(buf.ch, "#obstat scatter", 15) == 0) {
-            return "OBSTAT_SCATTER";
-        }
-        else if (strncmp(buf.ch, "#obstat", 7) == 0) {
-            return "OBSTAT_CURVE";
-        }
     }
 
     rewind(f.f_);
@@ -463,10 +477,10 @@ static const char* scan_file(const char* file)
     char asciiBuf[400];
     memset(&asciiBuf[0], '\0', 400);
     fread(&asciiBuf[0], 1, 311, f.f_);
-    //Flextra output files
+    // Flextra output files
     if (strstr(asciiBuf, "FLEXTRA MODEL OUTPUT") != 0) {
         return "FLEXTRA_FILE";
-        //IFS namelist file
+        // IFS namelist file
     }
     else if (strstr(asciiBuf, "&NAM") != 0 || strstr(asciiBuf, "&NAE") != 0 ||
              strstr(asciiBuf, "&NEM") != 0) {
@@ -494,9 +508,9 @@ static const char* scan_file(const char* file)
         }
     }
 
-    //We have to do this check at this point, after
-    //FLEXTRA was checked! FLEXTRA v5 generates ASCII files
-    //with some rubbish in them and we identify them as BINARY files!!
+    // We have to do this check at this point, after
+    // FLEXTRA was checked! FLEXTRA v5 generates ASCII files
+    // with some rubbish in them and we identify them as BINARY files!!
     if (fileType == eBinaryFile)
         return "BINARY";
 
@@ -574,8 +588,8 @@ std::string MvOdbType(const char* file, bool scanBeforeCheck)
         }
     }
 
-    //At this point type has to be ODB_DB
-    //We check if it is a file or directory
+    // At this point type has to be ODB_DB
+    // We check if it is a file or directory
 
     struct stat buf;
 
@@ -609,19 +623,19 @@ const char* MvNetcdfType(const char* file, bool checkStatus)
             return "NOTE";
     }
 
-    //F	NcFile nc(file);
+    // F	NcFile nc(file);
     MvNetCDF nc(std::string(file), NC_NOWRITE);
     if (!nc.isValid()) {
         return "BINARY";
     }
 
-    //Check for SCM input data
-    int n = nc.getNumberOfAttributes();  //Fnum_atts();
+    // Check for SCM input data
+    int n = nc.getNumberOfAttributes();  // Fnum_atts();
     for (int i = 0; i < n; i++) {
-        //F NcAtt* att=nc.get_att(i);
+        // F NcAtt* att=nc.get_att(i);
         MvNcAtt* att = nc.getAttribute(i);
         if (att != nullptr && att->name() != nullptr &&
-            strcmp(att->name(), "dataID") == 0 && att->getNumberOfValues() > 0)  //F num_vals()
+            strcmp(att->name(), "dataID") == 0 && att->getNumberOfValues() > 0)  // F num_vals()
         {
             auto vStr = att->as_string(0);
             if (!vStr.empty()) {
@@ -636,8 +650,8 @@ const char* MvNetcdfType(const char* file, bool checkStatus)
                 }
             }
         }
-        //F		if(att != nullptr)
-        //F			delete att;
+        // F		if(att != nullptr)
+        // F			delete att;
     }
 
     return "NETCDF";
