@@ -71,10 +71,13 @@ const std::string& MvVariant::toString() const
         try {
             if (type_ == IntType || type_ == LongType) {
                 strVal_ = std::to_string(longVal_);
-            } else if (type_ == DoubleType || type_ == FloatType) {
+            }
+            else if (type_ == DoubleType || type_ == FloatType) {
                 strVal_ = std::to_string(doubleVal_);
             }
-        } catch (...) {}
+        }
+        catch (...) {
+        }
     }
     return strVal_;
 }
@@ -168,7 +171,7 @@ std::vector<MvVariant> MvVariant::makeVector(const std::vector<int>& v)
 {
     std::vector<MvVariant> vv;
     for (int i : v)
-        vv.push_back(MvVariant(i));
+        vv.emplace_back(i);
     return vv;
 }
 
@@ -176,7 +179,7 @@ std::vector<MvVariant> MvVariant::makeVector(const std::vector<long>& v)
 {
     std::vector<MvVariant> vv;
     for (long i : v)
-        vv.push_back(MvVariant(i));
+        vv.emplace_back(i);
     return vv;
 }
 
@@ -184,7 +187,7 @@ std::vector<MvVariant> MvVariant::makeVector(const std::vector<float>& v)
 {
     std::vector<MvVariant> vv;
     for (float i : v)
-        vv.push_back(MvVariant(i));
+        vv.emplace_back(i);
     return vv;
 }
 
@@ -193,7 +196,7 @@ std::vector<MvVariant> MvVariant::makeVector(const std::vector<double>& v)
 {
     std::vector<MvVariant> vv;
     for (double i : v)
-        vv.push_back(MvVariant(i));
+        vv.emplace_back(i);
     return vv;
 }
 
@@ -201,6 +204,6 @@ std::vector<MvVariant> MvVariant::makeVector(const std::vector<std::string>& v)
 {
     std::vector<MvVariant> vv;
     for (const auto& i : v)
-        vv.push_back(MvVariant(i));
+        vv.emplace_back(i);
     return vv;
 }
