@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvVisTool_DEFINED
-#define MvVisTool_DEFINED
+#pragma once
 #include <Metview.h>
 
 //! \brief (semi-obsolete class)
@@ -43,5 +42,3 @@ public:
 
     void SetID(const char*);
 };
-
-#endif
