@@ -8,7 +8,7 @@
 
 #pragma once
 
-#include <stdio.h>
+#include <cstdio>
 #include <math.h>
 #include <gdefines.h>
 
@@ -24,6 +24,8 @@ public:
     }
     //		Normal constructor.
 
+    Point(double x, double y) :
+        _x(static_cast<float>(x)), _y(static_cast<float>(y)) {}
     Point(const Point& p)
     {
         _x = p._x;
@@ -31,7 +33,7 @@ public:
     }
     //		Copy initializer.
 
-    ~Point() {}
+    ~Point() = default;
     //		Empty destructor.
 
     void init(float v, float u)
@@ -110,12 +112,12 @@ public:
 
     Point operator+(Point& p)
     {
-        return Point(_x + p._x, _y + p._y);
+        return {_x + p._x, _y + p._y};
     }
 
     Point operator-(Point& p)
     {
-        return Point(_x - p._x, _y - p._y);
+        return {_x - p._x, _y - p._y};
     }
 
     Point pmax(const Point& p) const;
