@@ -10,12 +10,9 @@
 // File Tokenizer.h
 // Manuel Fuentes - ECMWF Jan 97
 
-#ifndef Tokenizer_H
-#define Tokenizer_H
+#pragma once
 
 #include <string>
-using std::string;
-
 #include <set>
 #include <vector>
 
@@ -57,5 +54,3 @@ private:
 };
 
 inline void destroy(Tokenizer**) {}
-
-#endif
