@@ -11,7 +11,7 @@ class DateEditWidget : public QWidget
     Q_OBJECT
 
 public:
-    DateEditWidget(QWidget* parent = 0);
+    DateEditWidget(QWidget* parent = nullptr);
 
 protected Q_SLOTS:
     void slotClear();
