@@ -15,8 +15,7 @@
 #include <QToolButton>
 
 MvQArrowSpinWidget::MvQArrowSpinWidget(QWidget* parent) :
-    QWidget(parent),
-    broadcast_(true)
+    QWidget(parent)
 {
     auto* hb = new QHBoxLayout();
     hb->setContentsMargins(4, 0, 4, 0);
