@@ -24,7 +24,7 @@
 
 MvQComboLine::MvQComboLine(QStringList lst, QWidget* parent) :
     QWidget(parent),
-    validator_(0)
+    validator_(nullptr)
 {
     auto* layout = new QHBoxLayout(this);
     layout->setSpacing(0);
