@@ -14,7 +14,7 @@
 class MvQFileInfoLabel : public QLabel
 {
 public:
-    MvQFileInfoLabel(QWidget* parent = 0);
+    MvQFileInfoLabel(QWidget* parent = nullptr);
     void setTextLabel(QString);
     void setGribTextLabel(QString, int, bool, int, bool);
     void setBufrTextLabel(QString, int, bool, int, bool);
