@@ -21,7 +21,7 @@
 #include "MvQMethods.h"
 #include "MvQTheme.h"
 
-#include <math.h>
+#include <cmath>
 
 //====================================
 //  MvQNodetem
@@ -37,32 +37,32 @@ MvQNodeItem::MvQNodeItem(MvQProfileItem* prof, bool editable, float yPos) :
     setZValue(-1);
 
     if (editable_) {
-        idleBrush_  = MvQTheme::brush("scmview", "editable_curve");
+        idleBrush_ = MvQTheme::brush("scmview", "editable_curve");
         hoverBrush_ = MvQTheme::brush("scmview", "editable_curve_hover");
-        moveBrush_  = hoverBrush_;
-        brush_      = idleBrush_;
+        moveBrush_ = hoverBrush_;
+        brush_ = idleBrush_;
 
-        idlePen_  = QPen(Qt::NoPen);
+        idlePen_ = QPen(Qt::NoPen);
         hoverPen_ = pen_;
-        movePen_  = pen_;
-        pen_      = idlePen_;
+        movePen_ = pen_;
+        pen_ = idlePen_;
     }
     else {
-        idleBrush_  = MvQTheme::brush("scmview", "curve");
+        idleBrush_ = MvQTheme::brush("scmview", "curve");
         hoverBrush_ = MvQTheme::brush("scmview", "curve_hover");
-        moveBrush_  = hoverBrush_;
-        brush_      = idleBrush_;
+        moveBrush_ = hoverBrush_;
+        brush_ = idleBrush_;
 
-        idlePen_  = QPen(Qt::NoPen);
+        idlePen_ = QPen(Qt::NoPen);
         hoverPen_ = pen_;
-        movePen_  = pen_;
-        pen_      = idlePen_;
+        movePen_ = pen_;
+        pen_ = idlePen_;
     }
 
-    idleSize_  = 6;
-    moveSize_  = 10;
+    idleSize_ = 6;
+    moveSize_ = 10;
     hoverSize_ = 10;
-    size_      = idleSize_;
+    size_ = idleSize_;
 }
 
 MvQNodeItem::~MvQNodeItem() = default;
@@ -76,8 +76,8 @@ void MvQNodeItem::addEdge(MvQEdgeItem* edge)
 QRectF MvQNodeItem::boundingRect() const
 {
     qreal adjust = 2;
-    return QRectF(-size_ / 2. - adjust, -size_ / 2. - adjust,
-                  size_ + adjust, size_ + adjust);
+    return {-size_ / 2. - adjust, -size_ / 2. - adjust,
+            size_ + adjust, size_ + adjust};
 }
 
 void MvQNodeItem::paint(QPainter* painter, const QStyleOptionGraphicsItem* /*option*/, QWidget*)
@@ -97,7 +97,7 @@ QVariant MvQNodeItem::itemChange(GraphicsItemChange change, const QVariant& valu
         case ItemPositionHasChanged:
             foreach (MvQEdgeItem* edge, edges_)
                 edge->adjust();
-            //prof_->nodeMoved(this);
+            // prof_->nodeMoved(this);
             break;
         default:
             break;
@@ -109,45 +109,45 @@ QVariant MvQNodeItem::itemChange(GraphicsItemChange change, const QVariant& valu
 void MvQNodeItem::mousePressEvent(QGraphicsSceneMouseEvent* /*event*/)
 {
     if (editable_) {
-        pen_   = movePen_;
+        pen_ = movePen_;
         brush_ = moveBrush_;
 
         prepareGeometryChange();
         size_ = moveSize_;
     }
 
-    //QGraphicsItem::mousePressEvent(event);
+    // QGraphicsItem::mousePressEvent(event);
 }
 
 void MvQNodeItem::mouseReleaseEvent(QGraphicsSceneMouseEvent* /*event*/)
 {
     if (editable_) {
         prof_->nodeMoved(this);
-        pen_   = idlePen_;
+        pen_ = idlePen_;
         brush_ = idleBrush_;
 
         prepareGeometryChange();
         size_ = idleSize_;
     }
-    //QGraphicsItem::mouseReleaseEvent(event);
+    // QGraphicsItem::mouseReleaseEvent(event);
 }
 
 void MvQNodeItem::mouseMoveEvent(QGraphicsSceneMouseEvent* event)
 {
     if (editable_) {
-        //We keep the node on a fixed level!
+        // We keep the node on a fixed level!
         QPointF pp = mapToParent(event->pos());
         setPos(QPointF(pp.x(), yPos_));
-        pen_   = movePen_;
+        pen_ = movePen_;
         brush_ = moveBrush_;
         update();
     }
-    //QGraphicsItem::mouseMoveEvent(event);
+    // QGraphicsItem::mouseMoveEvent(event);
 }
 
 void MvQNodeItem::hoverEnterEvent(QGraphicsSceneHoverEvent* /*event*/)
 {
-    pen_   = hoverPen_;
+    pen_ = hoverPen_;
     brush_ = hoverBrush_;
 
     prepareGeometryChange();
@@ -156,7 +156,7 @@ void MvQNodeItem::hoverEnterEvent(QGraphicsSceneHoverEvent* /*event*/)
 
 void MvQNodeItem::hoverLeaveEvent(QGraphicsSceneHoverEvent* /*event*/)
 {
-    pen_   = idlePen_;
+    pen_ = idlePen_;
     brush_ = idleBrush_;
 
     prepareGeometryChange();
@@ -202,7 +202,7 @@ void MvQEdgeItem::adjust()
 
     if (length > qreal(6.)) {
         fromPoint_ = line.p1();
-        toPoint_   = line.p2();
+        toPoint_ = line.p2();
     }
     else {
         fromPoint_ = toPoint_ = line.p1();
@@ -212,10 +212,10 @@ void MvQEdgeItem::adjust()
 QRectF MvQEdgeItem::boundingRect() const
 {
     if (!fromNode_ || !toNode_)
-        return QRectF();
+        return {};
 
     qreal penWidth = 1;
-    qreal extra    = penWidth;
+    qreal extra = penWidth;
 
     return QRectF(fromPoint_, QSizeF(toPoint_.x() - fromPoint_.x(),
                                      toPoint_.y() - fromPoint_.y()))
@@ -278,8 +278,8 @@ MvQProfileItem::MvQProfileItem(MvQProfileView* view, MvProfileData* data, bool e
     adjustFrame();
 
     for (int i = 0; i < data_->count(); i++) {
-        float val  = data_->value(i);
-        float yp   = (i - firstIndex_) * yRatio_;
+        float val = data_->value(i);
+        float yp = (i - firstIndex_) * yRatio_;
         auto* node = new MvQNodeItem(this, editable, yp);
         node->setParentItem(this);
         node->setPos((val - frameXMin_) * xRatio_, yp);
@@ -322,7 +322,7 @@ void MvQProfileItem::setStep(int step)
 
 void MvQProfileItem::adjustFrame()
 {
-    //Min max
+    // Min max
     float valMin, valMax;
 
     if (presetMinMax_) {
@@ -338,7 +338,7 @@ void MvQProfileItem::adjustFrame()
             data_->valueRange(firstIndex_, lastIndex_, valMin, valMax);
     }
 
-    //Find a nice plot range
+    // Find a nice plot range
     float valRange = valMax - valMin;
 
     if (valMin < 0 && valMax > 0) {
@@ -350,8 +350,8 @@ void MvQProfileItem::adjustFrame()
 
     QFont font;
     QFontMetrics fm(font);
-    int twMax     = MvQ::textWidth(fm, QString::number(valMax));
-    int twMin     = MvQ::textWidth(fm, QString::number(valMin));
+    int twMax = MvQ::textWidth(fm, QString::number(valMax));
+    int twMin = MvQ::textWidth(fm, QString::number(valMin));
     int textWidth = (twMin < twMax) ? twMax : twMin;
 
     if (valRange > 0) {
@@ -373,21 +373,21 @@ void MvQProfileItem::adjustFrame()
         tickXStep_ = 1;
     }
 
-    //We need to ensure that tickXStep_ is greater than 0!!!
+    // We need to ensure that tickXStep_ is greater than 0!!!
     if (tickXStep_ <= 0)
         tickXStep_ = 1.;
 
-    tickXLabelStep_       = tickXStep_;
+    tickXLabelStep_ = tickXStep_;
     tickXLabelStepOffset_ = 0;
 
-    //Because tickXStep_ alwasy greater than 0 these two values will always be different!!!
+    // Because tickXStep_ alwasy greater than 0 these two values will always be different!!!
     frameXMin_ = static_cast<int>((valMin - tickXStep_ - tickXStep_ / 1000.) / tickXStep_) * tickXStep_;
     frameXMax_ = static_cast<int>((valMax + tickXStep_ + tickXStep_ / 1000.) / tickXStep_) * tickXStep_;
 
-    //So this division can always be made!!!
+    // So this division can always be made!!!
     xRatio_ = frameRect_.width() / (frameXMax_ - frameXMin_);
 
-    //Adjustment
+    // Adjustment
     if (xRatio_ * tickXStep_ < textWidth) {
         tickXLabelStep_ *= 2;
         int labelFactor = static_cast<int>(round(frameXMin_ / tickXStep_));
@@ -418,7 +418,7 @@ void MvQProfileItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*, Q
 
     painter->setPen(pen_);
 
-    //Title
+    // Title
     if (!subPlot_) {
         QRectF titleRect(frameRect_.width() / 2. - 150, frameRect_.top() - 70, 300, 40);
         QString editableText = (editable_ == true) ? "Editable" : "";
@@ -429,15 +429,15 @@ void MvQProfileItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*, Q
                               "\n" + editableText);
     }
     /*else
-	{
-	  	QRectF titleRect(frameRect_.width()/2.-150,frameRect_.top()-50,300,40);	
-		painter->drawText(titleRect,Qt::AlignCenter,
-			  "Parameter: " + QString::fromStdString(data_->name()) + 
-	                 " [" + QString::fromStdString(data_->units()) + "]");  
-	} */
+    {
+        QRectF titleRect(frameRect_.width()/2.-150,frameRect_.top()-50,300,40);
+        painter->drawText(titleRect,Qt::AlignCenter,
+              "Parameter: " + QString::fromStdString(data_->name()) +
+                     " [" + QString::fromStdString(data_->units()) + "]");
+    } */
 
 
-    //Render out of normal range
+    // Render out of normal range
     if (data_->isRangeSet()) {
         float valMin = data_->rangeMin();
         float valMax = data_->rangeMax();
@@ -447,45 +447,45 @@ void MvQProfileItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*, Q
             painter->fillRect(0, frameRect_.top(), xp, frameRect_.bottom(), outsideBrush_);
         }
         if (frameXMax_ > valMax) {
-            float xp  = (valMax - frameXMin_) * xRatio_;
+            float xp = (valMax - frameXMin_) * xRatio_;
             float xp1 = (frameXMax_ - frameXMin_) * xRatio_;
             painter->fillRect(xp, frameRect_.top(), xp1 - xp, frameRect_.bottom(), outsideBrush_);
         }
     }
 
-    //Dash pattern for the grid
-    //QVector<qreal> dashes;
-    //dashes << 1 << 8;
-    //gridPen.setDashPattern(dashes);
+    // Dash pattern for the grid
+    // QVector<qreal> dashes;
+    // dashes << 1 << 8;
+    // gridPen.setDashPattern(dashes);
 
-    //Lines
-    //X axis - top + bottom
+    // Lines
+    // X axis - top + bottom
     for (float xv = frameXMin_; xv <= frameXMax_; xv += tickXStep_) {
         float xp = (xv - frameXMin_) * xRatio_;
         painter->drawLine(xp, frameRect_.top(), xp, frameRect_.top() - 6.);
         painter->drawLine(xp, frameRect_.bottom(), xp, frameRect_.bottom() + 6.);
 
-        //grid
+        // grid
         if (firstIndex_ != lastIndex_ && xv != frameXMin_ && xv != frameXMax_) {
             painter->setPen(gridPen_);
             painter->drawLine(xp, frameRect_.top(), xp, frameRect_.bottom());
             painter->setPen(pen_);
         }
 
-        //text
-        //int xpText=xp-fm.width(QString::number(xv))/2;
-        //painter->drawText(QPointF(xpText,frameRect_.bottom()+10+fm.ascent()),QString::number(xv));
+        // text
+        // int xpText=xp-fm.width(QString::number(xv))/2;
+        // painter->drawText(QPointF(xpText,frameRect_.bottom()+10+fm.ascent()),QString::number(xv));
 
-        //if(!subPlot_)
+        // if(!subPlot_)
         //	painter->drawText(QPointF(xpText,frameRect_.top()-10-fm.descent()),QString::number(xv));
     }
 
-    //Text
-    //X axis - top + bottom
+    // Text
+    // X axis - top + bottom
     for (float xv = frameXMin_ + tickXLabelStepOffset_ * tickXStep_; xv <= frameXMax_; xv += tickXLabelStep_) {
         float xp = (xv - frameXMin_) * xRatio_;
 
-        //text
+        // text
         int xpText = xp - MvQ::textWidth(fm, QString::number(xv)) / 2;
         painter->drawText(QPointF(xpText, frameRect_.bottom() + 10 + fm.ascent()), QString::number(xv));
 
@@ -494,7 +494,7 @@ void MvQProfileItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*, Q
     }
 
 
-    float dy  = frameRect_.height() / (1 + lastIndex_ - firstIndex_);
+    float dy = frameRect_.height() / (1 + lastIndex_ - firstIndex_);
     int stepY = 10;
     if (dy > 15)
         stepY = 1;
@@ -508,7 +508,7 @@ void MvQProfileItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*, Q
     if (lastIndex_ - firstIndex_ + 1 < 6)
         stepY = 1;
 
-    //Right axis
+    // Right axis
     if (data_->auxLevelDefined()) {
         for (int i = lastIndex_; i >= firstIndex_; i -= stepY) {
             auto xv = static_cast<float>(floor(data_->auxLevel(i) / 100.));
@@ -517,12 +517,12 @@ void MvQProfileItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*, Q
             float yp = frameRect_.top() + (i - firstIndex_) * yRatio_;
             painter->drawLine(xp, yp, xp + 6., yp);
 
-            //Label
+            // Label
             int ypText = yp + fm.ascent() / 2;
             painter->drawText(QPointF(xp + 10, ypText), QString::number(xv));
         }
 
-        //Right axis title
+        // Right axis title
         painter->save();
         painter->translate(frameRect_.width() + 10 + MvQ::textWidth(fm, "1000") + 10 + fm.ascent(), frameRect_.center().y());
         painter->rotate(-90);
@@ -533,14 +533,14 @@ void MvQProfileItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*, Q
     }
 
     if (lastIndex_ != firstIndex_) {
-        //Left axis
+        // Left axis
         for (int i = lastIndex_; i >= firstIndex_; i -= stepY) {
             float xv = data_->level(i);
             float xp = 0;
             float yp = frameRect_.top() + (i - firstIndex_) * yRatio_;
             painter->drawLine(xp, yp, xp - 6., yp);
 
-            //grid
+            // grid
             painter->setPen(gridPen_);
             painter->drawLine(xp, yp, xp + frameRect_.width(), yp);
             painter->setPen(pen_);
@@ -552,7 +552,7 @@ void MvQProfileItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*, Q
         }
     }
 
-    //Left axis title
+    // Left axis title
     painter->save();
     painter->translate(-10 - MvQ::textWidth(fm, "100") - 10, frameRect_.center().y());
     painter->rotate(-90);
@@ -574,7 +574,7 @@ void MvQProfileItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*, Q
         painter->drawLine(xp, frameRect_.top(), xp, frameRect_.bottom());
     }
 
-    //Frame
+    // Frame
 
     if (firstIndex_ != lastIndex_)
         painter->drawRect(frameRect_);
@@ -592,7 +592,7 @@ bool MvQProfileItem::updateValue(const MvProfileChange& ch)
         float val = data_->value(index);
         nodes_.at(index)->setPos((val - frameXMin_) * xRatio_, frameRect_.top() + (index - firstIndex_) * yRatio_);
 
-        //See if the coordinate system needs to be adjusted to the data value range
+        // See if the coordinate system needs to be adjusted to the data value range
         if (val < frameXMin_ || val > frameXMax_)
             view_->adjustValueRange();
         else
@@ -618,12 +618,12 @@ void MvQProfileItem::nodeMoved(MvQNodeItem* node)
         float val = data_->value(index);
         if (fabs((val - frameXMin_) * xRatio_ - node->pos().x()) > 0.1) {
             float f = frameXMin_ + node->pos().x() / xRatio_;
-            //if(!data_->fitToRange(f))
+            // if(!data_->fitToRange(f))
             //{
             //	data_->setValue(index,f);
             //	nodes_.at(index)->setPos((f-frameXMin_)*xRatio_,(index-firstIndex_)*yRatio_);
-            //}
-            //else
+            // }
+            // else
             //{
             data_->setValue(index, f);
             //}
@@ -646,7 +646,7 @@ void MvQProfileItem::initFrame(QSize size)
         h = minYSize_;
 
     frameRect_ = QRectF(0, 0, w - 150, h - 120);
-    bRect_     = frameRect_.adjusted(-60, -80, 90, 30);
+    bRect_ = frameRect_.adjusted(-60, -80, 90, 30);
 }
 
 void MvQProfileItem::initFrame(QRectF r)
@@ -664,63 +664,63 @@ void MvQProfileItem::adjustData()
     if (data_) {
         for (int i = 0; i < data_->count(); i++) {
             float val = data_->value(i);
-            float yp  = frameRect_.top() + (i - firstIndex_) * yRatio_;
+            float yp = frameRect_.top() + (i - firstIndex_) * yRatio_;
 
             if (i < firstIndex_) {
-                if (nodes_.at(i)->scene() != 0) {
+                if (nodes_.at(i)->scene() != nullptr) {
                     scene()->removeItem(nodes_.at(i));
                     nodes_.at(i)->setVisible(false);
-                    //qDebug() << "remove node" << i << nodes_.at(i)->scene();
+                    // qDebug() << "remove node" << i << nodes_.at(i)->scene();
                 }
 
                 if (i < edges_.count() && edges_.at(i)->scene()) {
                     scene()->removeItem(edges_.at(i));
                     edges_.at(i)->setVisible(false);
-                    //qDebug() << "  remove edge " << i << edges_.at(i)->scene();
+                    // qDebug() << "  remove edge " << i << edges_.at(i)->scene();
                 }
 
                 if (i > 0 && edges_.at(i - 1)->scene()) {
                     scene()->removeItem(edges_.at(i - 1));
                     edges_.at(i - 1)->setVisible(false);
-                    //qDebug() << "  remove edge " << i-1 << edges_.at(i-1)->scene();
+                    // qDebug() << "  remove edge " << i-1 << edges_.at(i-1)->scene();
                 }
             }
             else if (i > lastIndex_) {
-                if (nodes_.at(i)->scene() != 0) {
+                if (nodes_.at(i)->scene() != nullptr) {
                     scene()->removeItem(nodes_.at(i));
                     nodes_.at(i)->setVisible(false);
-                    //qDebug() << "remove node" << i << nodes_.at(i)->scene();
+                    // qDebug() << "remove node" << i << nodes_.at(i)->scene();
                 }
 
                 if (i > 0 && edges_.at(i - 1)->scene()) {
                     scene()->removeItem(edges_.at(i - 1));
                     edges_.at(i - 1)->setVisible(false);
-                    //qDebug() << "  remove edge " << i-1 << edges_.at(i-1)->scene();
+                    // qDebug() << "  remove edge " << i-1 << edges_.at(i-1)->scene();
                 }
 
                 /*if(i < edges_.count() && edges_.at(i)->scene())
-				{	
-				  	scene()->removeItem(edges_.at(i));
-					edges_.at(i)->setVisible(false);
-					qDebug() << "  remove edge " << i << edges_.at(i)->scene(); 
-				}*/
+                {
+                    scene()->removeItem(edges_.at(i));
+                    edges_.at(i)->setVisible(false);
+                    qDebug() << "  remove edge " << i << edges_.at(i)->scene();
+                }*/
             }
-            else if (nodes_.at(i)->scene() == 0) {
-                //qDebug() << "add node" << i << nodes_.at(i)->scene();;
+            else if (nodes_.at(i)->scene() == nullptr) {
+                // qDebug() << "add node" << i << nodes_.at(i)->scene();;
 
                 nodes_.at(i)->setParentItem(this);
                 nodes_.at(i)->setVisible(true);
 
-                if (i < edges_.count() && !edges_.at(i)->scene() && nodes_.at(i + 1)->scene() != 0) {
+                if (i < edges_.count() && !edges_.at(i)->scene() && nodes_.at(i + 1)->scene() != nullptr) {
                     edges_.at(i)->setParentItem(this);
                     edges_.at(i)->setVisible(true);
-                    //qDebug() << "    add edge" << i << edges_.at(i)->scene();;
+                    // qDebug() << "    add edge" << i << edges_.at(i)->scene();;
                 }
 
-                if (i > 1 && !edges_.at(i - 1)->scene() && nodes_.at(i - 1)->scene() != 0) {
+                if (i > 1 && !edges_.at(i - 1)->scene() && nodes_.at(i - 1)->scene() != nullptr) {
                     edges_.at(i - 1)->setParentItem(this);
                     edges_.at(i - 1)->setVisible(true);
-                    //qDebug() << "    add edge" << i << edges_.at(i-1)->scene();;
+                    // qDebug() << "    add edge" << i << edges_.at(i-1)->scene();;
                 }
             }
 
@@ -752,7 +752,7 @@ void MvQProfileItem::adjustSize(QRectF r)
 void MvQProfileItem::setLevelRange(int firstIndex, int lastIndex)
 {
     firstIndex_ = firstIndex;
-    lastIndex_  = lastIndex;
+    lastIndex_ = lastIndex;
 
     if (firstIndex_ < 0 || firstIndex_ >= data_->count())
         firstIndex_ = 0;
@@ -821,11 +821,11 @@ void MvQProfileItem::valueRange(float& valMin, float& valMax)
 
 void MvQProfileItem::checkValueRange()
 {
-    //See if the coordinate system needs to be adjusted to the data value range
+    // See if the coordinate system needs to be adjusted to the data value range
     if (!presetMinMax_ && !data_->isRangeSet()) {
         float valMin, valMax;
         data_->valueRange(firstIndex_, lastIndex_, valMin, valMax);
-        valMax         = (fabs(valMax) > fabs(valMin)) ? fabs(valMax) : fabs(valMin);
+        valMax = (fabs(valMax) > fabs(valMin)) ? fabs(valMax) : fabs(valMin);
         float frameMax = (fabs(frameXMax_) > fabs(frameXMin_)) ? fabs(frameXMax_) : fabs(frameXMin_);
 
         if (valMax > 0.0000000001 && valMax < frameMax / 100.)
@@ -886,12 +886,12 @@ void MvQProfileView::setProfile(QList<MvProfileData*> profData, bool editable, i
         itemsToBeDeleted << item;
     }
     prof_.clear();
-    //profWeight_.clear();
+    // profWeight_.clear();
 
     QSize size = maximumViewportSize();
     size -= QSize(10, 10);
 
-    ///Min max
+    /// Min max
     bool setMinMax = false;
     float valMin = 999999, valMax = -9999999;
     if (profData.count() > 1) {
@@ -913,7 +913,7 @@ void MvQProfileView::setProfile(QList<MvProfileData*> profData, bool editable, i
         }
     }
 
-    //Create plot items
+    // Create plot items
     if (profData.count() > 0) {
         prof_ << new MvQProfileItem(this, profData[0], editable, 0, startIndex, endIndex, size,
                                     setMinMax, valMin, valMax);
@@ -972,7 +972,7 @@ void MvQProfileView::adjustSize()
     QSize size = maximumViewportSize();
     size -= QSize(10, 10);
 
-    //Needs to be improved
+    // Needs to be improved
     if (prof_.count() > 1) {
         int h = 0;
         for (int i = 1; i < prof_.count(); i++) {
@@ -1007,7 +1007,7 @@ void MvQProfileView::adjustSize()
         prof_[0]->adjustSize(size);
     }
 
-    //Set the scenerect
+    // Set the scenerect
     if (prof_.count() > 0) {
         QRectF bb = prof_[0]->boundingRect();
         for (int i = 1; i < prof_.count(); i++) {
