@@ -36,7 +36,7 @@
 
 MvQScmDataPanel::MvQScmDataPanel(QWidget* parent) :
     QWidget(parent),
-    model_(0),
+    model_(nullptr),
     master_(false)
 {
     auto* layout = new QVBoxLayout;
@@ -48,7 +48,7 @@ MvQScmDataPanel::MvQScmDataPanel(QWidget* parent) :
 
     view_ = new QTableView(this);
     view_->setObjectName("paramMlView");
-    //view_->setProperty("mvStyle", 3);
+    // view_->setProperty("mvStyle", 3);
     view_->setAlternatingRowColors(true);
     view_->setModel(filterModel_);
     layout->addWidget(view_);
@@ -103,7 +103,7 @@ void MvQScmDataPanel::slotParamSelected(int index)
 {
     if (index >= 0 && index < static_cast<int>(vars_.size())) {
         MvScmVar* var = vars_.at(index);
-        int step      = model_->step();
+        int step = model_->step();
 
         auto it = masterParams_.find(var);
         if (it != masterParams_.end()) {
@@ -130,7 +130,7 @@ bool MvQScmDataPanel::selectParam(MvScmVar* var)
     if (!var)
         return false;
 
-    int row             = 0;
+    int row = 0;
     QModelIndex current = view_->currentIndex();
     if (current.isValid())
         row = current.row();
@@ -180,9 +180,9 @@ void MvQScmDataPanel::reload()
 
 MvQScmProfileDataPanel::MvQScmProfileDataPanel(QWidget* parent) :
     MvQScmDataPanel(parent),
-    header_(0)
+    header_(nullptr)
 {
-    //Column tree
+    // Column tree
     model_ = new MvQScmProfileModel();
     filterModel_->setSourceModel(model_);
 
@@ -198,14 +198,14 @@ MvQScmProfileDataPanel::MvQScmProfileDataPanel(QWidget* parent) :
     connect(header_, SIGNAL(customContextMenuRequested(const QPoint&)),
             this, SLOT(slotHeaderContextMenu(const QPoint&)));
 
-    //Dymanic filter did not work somehow, so we need to update the filter model in this way
+    // Dymanic filter did not work somehow, so we need to update the filter model in this way
     filterModel_->setShowEditableOnly(filterModel_->showEditableOnly());
 }
 
 void MvQScmProfileDataPanel::init(const std::vector<MvScmVar*>& vars, int step, const std::vector<float>& levels, const std::string& levelName,
                                   const std::vector<MvScmVar*>& editableVars)
 {
-    vars_         = vars;
+    vars_ = vars;
     editableVars_ = editableVars;
     model_->setData(vars, step, levels, levelName);
     model_->setEditableVars(editableVars);
@@ -225,7 +225,7 @@ void MvQScmProfileDataPanel::slotHeaderContextMenu(const QPoint& position)
         return;
 
     QList<QAction*> actions;
-    QAction* action;
+    QAction* action = nullptr;
 
     action = new QAction(this);
     action->setObjectName(QString::fromUtf8("actionAssign"));
@@ -241,8 +241,8 @@ void MvQScmProfileDataPanel::slotHeaderContextMenu(const QPoint& position)
     actions << action;
 
     if (actions.count() > 0 &&
-        (action = QMenu::exec(actions, header_->mapToGlobal(position))) != 0) {
-        QString key   = action->data().toString();
+        (action = QMenu::exec(actions, header_->mapToGlobal(position))) != nullptr) {
+        QString key = action->data().toString();
         MvScmVar* var = vars_.at(section);
         if (key == "assign") {
             assignValue(var);
@@ -261,7 +261,7 @@ void MvQScmProfileDataPanel::slotHeaderContextMenu(const QPoint& position)
 void MvQScmProfileDataPanel::assignValue(MvScmVar* var)
 {
     bool ok;
-    double val = QInputDialog::getDouble(0,
+    double val = QInputDialog::getDouble(nullptr,
                                          tr("Assign value"),
                                          tr("New value:"),
                                          0., -10000000, 10000000, 10, &ok);
@@ -290,7 +290,7 @@ void MvQScmProfileDataPanel::assignValue(MvScmVar* var, double val)
 MvQScmSurfaceDataPanel::MvQScmSurfaceDataPanel(QWidget* parent) :
     MvQScmDataPanel(parent)
 {
-    //Column tree
+    // Column tree
     model_ = new MvQScmSurfaceModel();
     filterModel_->setSourceModel(model_);
 
@@ -302,7 +302,7 @@ MvQScmSurfaceDataPanel::MvQScmSurfaceDataPanel(QWidget* parent) :
     connect(header, SIGNAL(sectionClicked(int)),
             this, SLOT(slotParamSelected(int)));
 
-    //Dymanic filter did not work somehow, so we need to update the filter model in this way
+    // Dymanic filter did not work somehow, so we need to update the filter model in this way
     filterModel_->setShowEditableOnly(filterModel_->showEditableOnly());
 }
 
@@ -327,8 +327,8 @@ MvQScmTab::MvQScmTab(QWidget* parent) :
 
 MvQScmDataWidget::MvQScmDataWidget(QWidget* parent) :
     QWidget(parent),
-    data_(0),
-    masterPanel_(0)
+    data_(nullptr),
+    masterPanel_(nullptr)
 {
     //-----------------------
     // The main layout
@@ -364,7 +364,7 @@ void MvQScmDataWidget::clearPanels()
         delete panel.second;
     }
 
-    masterPanel_ = 0;
+    masterPanel_ = nullptr;
     tabToPanel_.clear();
     panelToTab_.clear();
 }
@@ -372,14 +372,14 @@ void MvQScmDataWidget::clearPanels()
 void MvQScmDataWidget::addPanelToTab(MvQScmDataPanel* panel, PanelType type, QString title)
 {
     tab_->addTab(panel, title);
-    int tabIndex          = tab_->count() - 1;
-    panelToTab_[type]     = tabIndex;
+    int tabIndex = tab_->count() - 1;
+    panelToTab_[type] = tabIndex;
     tabToPanel_[tabIndex] = type;
 }
 
 void MvQScmDataWidget::init(MvScm* data, QList<MvScmVar*> editVars)
 {
-    //Delete all the panels
+    // Delete all the panels
     clearPanels();
 
     if (data->stepNum() <= 0) {
@@ -389,7 +389,7 @@ void MvQScmDataWidget::init(MvScm* data, QList<MvScmVar*> editVars)
 
     data_ = data;
 
-    //Get editable variables
+    // Get editable variables
 #if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
     auto qv = editVars.toVector();
     std::vector<MvScmVar*> editVec(qv.begin(), qv.end());
@@ -398,25 +398,25 @@ void MvQScmDataWidget::init(MvScm* data, QList<MvScmVar*> editVars)
 #endif
 
     int step = 0;
-    MvQScmDataPanel* panel;
+    MvQScmDataPanel* panel = nullptr;
 
     //-------------------------
     // Model levels
     //-------------------------
 
-    //At the moment masterPanel_ has to be the model level panel !!!
+    // At the moment masterPanel_ has to be the model level panel !!!
 
     if (!data->modelLevelDim().isEmpty()) {
-        panel                  = new MvQScmProfileDataPanel(this);
+        panel = new MvQScmProfileDataPanel(this);
         panels_[ModelLevPanel] = panel;
 
-        //This will be the master panel
+        // This will be the master panel
         masterPanel_ = panel;
 
-        //Add to tab
+        // Add to tab
         addPanelToTab(panel, ModelLevPanel, tr("Model levels"));
 
-        //init
+        // init
         panel->init(data_->modelLevel(), step, data_->modelLevelDim().values(), data_->modelLevelDim().longName(), editVec);
     }
 
@@ -424,27 +424,27 @@ void MvQScmDataWidget::init(MvScm* data, QList<MvScmVar*> editVars)
     // Pressure levels
     //-------------------------
 
-    //if(!data->pressureLevelDim().isEmpty())
-    if (0) {
-        panel                     = new MvQScmProfileDataPanel(this);
+    // if(!data->pressureLevelDim().isEmpty())
+    if (false) {
+        panel = new MvQScmProfileDataPanel(this);
         panels_[PressureLevPanel] = panel;
 
-        //Add to tab
+        // Add to tab
         addPanelToTab(panel, PressureLevPanel, tr("Pressure levels"));
 
-        //init
+        // init
         panel->init(data_->pressureLevel(), step, data_->pressureLevelDim().values(), data_->pressureLevelDim().longName(), editVec);
     }
 
     //-------------------------
-    //Soil levels
+    // Soil levels
     //-------------------------
 
     if (!data->soilLevelDim().isEmpty()) {
-        panel                 = new MvQScmProfileDataPanel(this);
+        panel = new MvQScmProfileDataPanel(this);
         panels_[SoilLevPanel] = panel;
 
-        //Add to tab
+        // Add to tab
         addPanelToTab(panel, SoilLevPanel, tr("Soil levels"));
 
         panel->init(data_->soilLevel(), step, data_->soilLevelDim().values(), data_->soilLevelDim().longName(), editVec);
@@ -458,13 +458,13 @@ void MvQScmDataWidget::init(MvScm* data, QList<MvScmVar*> editVars)
     }
 
     //-------------------------
-    //Surface - always exists
+    // Surface - always exists
     //------------------------
 
-    panel                    = new MvQScmSurfaceDataPanel(this);
+    panel = new MvQScmSurfaceDataPanel(this);
     panels_[SurfaceLevPanel] = panel;
 
-    //Add to tab
+    // Add to tab
     addPanelToTab(panel, SurfaceLevPanel, tr("Surface and other 2D"));
 
     panel->init(data_->surfaceLevel(), step, editVec);
@@ -477,7 +477,7 @@ void MvQScmDataWidget::init(MvScm* data, QList<MvScmVar*> editVars)
     }
 
     //-----------------------------------
-    //Relaying signals from the panels
+    // Relaying signals from the panels
     //-----------------------------------
 
     for (auto& panel : panels_) {
@@ -491,7 +491,7 @@ void MvQScmDataWidget::init(MvScm* data, QList<MvScmVar*> editVars)
                 this, SIGNAL(stepChanged(int)));
     }
 
-    //Initial profile
+    // Initial profile
     if (masterPanel_) {
         //!!!!!!!!!!!!!!!!!!
         masterPanel_->slotParamSelected(data_->mlVarIndex(MvScm::TempML));
@@ -502,31 +502,31 @@ void MvQScmDataWidget::slotStepChanged(int value)
 {
     int step = value;
 
-    //Save and set steps
+    // Save and set steps
     for (auto& panel : panels_) {
         panel.second->setStep(step);
     }
 
-    //Update profile view
+    // Update profile view
 
     int actTab = tab_->currentIndex();
 
-    //Model levels
+    // Model levels
     if (panels_.find(ModelLevPanel) != panels_.end()) {
         panels_[ModelLevPanel]->reselectIndex(tabToPanel_[actTab] == ModelLevPanel || tabToPanel_[actTab] == PressureLevPanel);
     }
 
-    //Pressure
+    // Pressure
     if (panels_.find(PressureLevPanel) != panels_.end()) {
         panels_[PressureLevPanel]->reselectIndex(tabToPanel_[actTab] == PressureLevPanel);
     }
 
-    //Soil
+    // Soil
     if (panels_.find(SoilLevPanel) != panels_.end()) {
         panels_[SoilLevPanel]->reselectIndex(tabToPanel_[actTab] == SoilLevPanel);
     }
 
-    //Surf
+    // Surf
     panels_[SurfaceLevPanel]->reselectIndex(tabToPanel_[actTab] == SurfaceLevPanel);
 }
 
