@@ -24,9 +24,7 @@ MvQService::MvQService(const char* name) :
     saveToPool(false);  // interactive modules are not caching data (always true?)
 }
 
-MvQService::~MvQService()
-{
-}
+MvQService::~MvQService() = default;
 
 // The MARS event loop is not running in the forked MvService instances. Using this function
 // we are able to receive data from Event and process it accordingly.
