@@ -26,6 +26,6 @@ public:
 
 protected:
     void writeToLog(const std::string& msg, MvLogLevel level) override;
-    void writeToUiLog(const std::string& msg, MvLogLevel level, bool popup) override;
+    void writeToUiLog(const std::string& msg, const std::string& details, MvLogLevel level, bool popup) override;
     void exitWithError() override;
 };
