@@ -7,12 +7,10 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQSlider_H
-#define MvQSlider_H
+#pragma once
 
 #include <QSlider>
 
-using namespace std;
 
 class MvQSlider : public QSlider
 {
@@ -22,6 +20,3 @@ public:
 protected:
     void mousePressEvent(QMouseEvent* event);
 };
-
-
-#endif
