@@ -24,10 +24,10 @@ public:
     explicit MvQTreeViewDelegate(QTreeView* parent);
     void setStyleId(int id);
     void paint(QPainter* painter, const QStyleOptionViewItem& option,
-               const QModelIndex& index) const;
-    QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const;
+               const QModelIndex& index) const override;
+    QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const override;
 
-protected:
+private:
     void setColours();
 
     QPen textPen_;
@@ -52,7 +52,7 @@ class MvQTreeView : public QTreeView
 public:
     MvQTreeView(QWidget* parent = nullptr, bool useDelegate = false);
     void setStyleId(int);
-    void keyboardSearch(const QString&);
+    void keyboardSearch(const QString&) override;
     void setActvatedByKeyNavigation(bool b) { activatedByKeyNavigation_ = b; }
     void setColumnToDrag(int i) { columnToDrag_ = i; }
 
@@ -60,9 +60,9 @@ signals:
     void selectionChanged(const QModelIndex&);
 
 protected:
-    void keyReleaseEvent(QKeyEvent*);
-    void selectionChanged(const QItemSelection& selected, const QItemSelection& deselected);
-    void drawBranches(QPainter* painter, const QRect& rect, const QModelIndex& index) const;
+    void keyReleaseEvent(QKeyEvent*) override;
+    void selectionChanged(const QItemSelection& selected, const QItemSelection& deselected) override;
+    void drawBranches(QPainter* painter, const QRect& rect, const QModelIndex& index) const override;
 
     bool dragEnabled();
     bool dropEnabled();
