@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQWebViewSearchLine_H
-#define MvQWebViewSearchLine_H
+#pragma once
 
 class QWebView;
 
@@ -31,5 +30,3 @@ protected:
     QWebView* view_;
     QString txt_;
 };
-
-#endif
