@@ -54,10 +54,10 @@ EditLine* EditLineFactory::make(MvQProperty* prop, EditLineHeader* hdr)
         case MvQProperty::LabelGui:
             return new EditLabelLine(prop, grid_, hdr, parent_);
         default:
-            return 0;
+            return nullptr;
     }
 
-    return 0;
+    return nullptr;
 }
 
 
@@ -65,7 +65,7 @@ EditLineHeader::EditLineHeader(QString name, QGridLayout* grid, QWidget* parent)
     QWidget(parent),
     expanded_(true),
     needRepaint_(true),
-    groupProp_(0),
+    groupProp_(nullptr),
     title_(name)
 {
     Q_ASSERT(parent);
@@ -89,9 +89,9 @@ EditLineHeader::EditLineHeader(QString name, QGridLayout* grid, QWidget* parent)
     expandTb_->setProperty("lineEditHeader", "1");
 
     closeIcon_ = QPixmap(":/examiner/block_close.svg");
-    openIcon_  = QPixmap(":/examiner/block_open.svg");
+    openIcon_ = QPixmap(":/examiner/block_open.svg");
 
-    //by default everything is open
+    // by default everything is open
     expandTb_->setIcon(closeIcon_);
 
     connect(expandTb_, SIGNAL(clicked()),
@@ -115,7 +115,7 @@ EditLineHeader::EditLineHeader(QString name, QGridLayout* grid, QWidget* parent)
 
     QFont f;
     QFontMetrics fm(f);
-    int h = 10;  //fm.height()-2;
+    int h = 10;  // fm.height()-2;
     expandTb_->setIconSize(QSize(h, h));
     clearTb_->setIconSize(QSize(h, h));
 
@@ -127,12 +127,12 @@ EditLineHeader::EditLineHeader(QString name, QGridLayout* grid, QWidget* parent)
     connect(this, SIGNAL(needRepaint()),
             parent, SLOT(delayedForceRepaint()));
 
-    //label_->setFixedHeight(fm.height()+4);
+    // label_->setFixedHeight(fm.height()+4);
 }
 
 void EditLineHeader::init()
 {
-    //slotExpand();
+    // slotExpand();
 }
 
 void EditLineHeader::addLine(EditLine* line)
@@ -255,10 +255,10 @@ void EditLineHeader::paintEvent(QPaintEvent*)
 EditLine::EditLine(MvQProperty* prop, QGridLayout* grid, EditLineHeader* header, QWidget* parent) :
     prop_(prop),
     parentWidget_(parent),
-    resetTb_(0),
-    nameLabel_(0),
-    helpTb_(0),
-    suffixLabel_(0),
+    resetTb_(nullptr),
+    nameLabel_(nullptr),
+    helpTb_(nullptr),
+    suffixLabel_(nullptr),
     row_(-1),
     visible_(true),
     hiddenByRule_(false)
@@ -266,7 +266,7 @@ EditLine::EditLine(MvQProperty* prop, QGridLayout* grid, EditLineHeader* header,
     Q_ASSERT(prop_);
 
     QString tooltip = prop->param("tooltip");
-    name_           = prop->param("label");
+    name_ = prop->param("label");
     if (!name_.isEmpty()) {
         nameLabel_ = new QLabel(name_, parent);
         nameLabel_->setProperty("lineEdit", "1");
@@ -285,9 +285,9 @@ EditLine::EditLine(MvQProperty* prop, QGridLayout* grid, EditLineHeader* header,
     }
 
     row_ = grid->rowCount();
-    //QSpacerItem *spItem=new QSpacerItem(2,0,
-    //      QSizePolicy::Fixed,QSizePolicy::Preferred);
-    //grid->addItem(spItem,row_,SpacerColumn);
+    // QSpacerItem *spItem=new QSpacerItem(2,0,
+    //       QSizePolicy::Fixed,QSizePolicy::Preferred);
+    // grid->addItem(spItem,row_,SpacerColumn);
 
     if (resetTb_)
         grid->addWidget(resetTb_, row_, ResetColumn);
@@ -345,17 +345,17 @@ bool EditLine::isSet() const
 
 void EditLine::setLabelBold(bool b)
 {
-    //return;
+    // return;
     if (!nameLabel_)
         return;
 
     if (b) {
         nameLabel_->setText("<b>" + name_ + "</b>");
-        //nameLabel_->setStyleSheet(boldNameLabelSh_);
+        // nameLabel_->setStyleSheet(boldNameLabelSh_);
     }
     else {
         nameLabel_->setText(name_);
-        //nameLabel_->setStyleSheet(normalNameLabelSh_);
+        // nameLabel_->setStyleSheet(normalNameLabelSh_);
     }
 }
 
@@ -392,7 +392,7 @@ void EditLine::setCompleterForLe(const std::set<std::string>& coVals, QLineEdit*
     for (const auto& coVal : coVals) {
         lst << QString::fromStdString(coVal);
     }
-    le->setCompleter(0);
+    le->setCompleter(nullptr);
     le->setCompleter(new QCompleter(lst, le));
 }
 
@@ -416,7 +416,7 @@ void EditLine::updateCompleterForLe(const std::set<std::string>& coVals,
         }
     }
 
-    le->setCompleter(0);
+    le->setCompleter(nullptr);
     le->setCompleter(new QCompleter(lst, le));
 }
 
@@ -527,7 +527,7 @@ QWidget* EditLabelLine::widget()
 
 EditDateLine::EditDateLine(MvQProperty* prop, QGridLayout* grid, EditLineHeader* header, QWidget* parent) :
     EditLine(prop, grid, header, parent),
-    cal_(0)
+    cal_(nullptr)
 {
     helpTb_ = new QToolButton(parent);
     helpTb_->setToolTip("Choose date from calendar");
@@ -553,7 +553,7 @@ EditDateLine::EditDateLine(MvQProperty* prop, QGridLayout* grid, EditLineHeader*
     QString tooltip = prop->param("tooltip");
     le_->setToolTip(tooltip);
 
-    //le_->setPlaceholderText("ANY  (format YYYYMMDD)");
+    // le_->setPlaceholderText("ANY  (format YYYYMMDD)");
 #if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
     le_->setClearButtonEnabled(true);
 #endif
@@ -593,8 +593,8 @@ void EditDateLine::slotHelp()
 {
     if (!cal_) {
         cal_ = new CalendarDialog(parentWidget_);
-        //cal_->move(helpTb_->pos()+QPoint(helpTb_->size().width(),helpTb_->size().height()));
-        //cal_->resize(QSize(300,300));
+        // cal_->move(helpTb_->pos()+QPoint(helpTb_->size().width(),helpTb_->size().height()));
+        // cal_->resize(QSize(300,300));
         cal_->setModal(true);
         connect(cal_, SIGNAL(dateSelected(QDate)),
                 this, SLOT(slotDateSelected(QDate)));
@@ -637,7 +637,7 @@ EditTimeLine::EditTimeLine(MvQProperty* prop, QGridLayout* grid, EditLineHeader*
     EditLine(prop, grid, header, parent)
 {
     le_ = new QLineEdit(parent);
-    //le_->setPlaceholderText("ANY  (format hh[:mm[:ss])");
+    // le_->setPlaceholderText("ANY  (format hh[:mm[:ss])");
 #if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
     le_->setClearButtonEnabled(true);
 #endif
@@ -678,7 +678,7 @@ void EditTimeLine::applyChange()
 EditAreaLine::EditAreaLine(MvQProperty* prop, QGridLayout* grid, EditLineHeader* header, QWidget* parent) :
     EditLine(prop, grid, header, parent)
 {
-    w_   = new QWidget(parent);
+    w_ = new QWidget(parent);
     nLe_ = new QLineEdit(w_);
     wLe_ = new QLineEdit(w_);
     sLe_ = new QLineEdit(w_);
@@ -779,7 +779,7 @@ EditComboLine::EditComboLine(MvQProperty* prop, QGridLayout* grid, EditLineHeade
     Q_ASSERT(row_ > -1);
     grid->addWidget(cb_, row_, WidgetColumn);
 
-    QStringList lst     = prop_->param("values_label").split("/");
+    QStringList lst = prop_->param("values_label").split("/");
     QStringList lstData = prop_->param("values").split("/");
     if (prop_->param("values_label").simplified().isEmpty())
         lst = lstData;
@@ -789,7 +789,7 @@ EditComboLine::EditComboLine(MvQProperty* prop, QGridLayout* grid, EditLineHeade
         cb_->addItem(lst[i], lstData[i]);
     }
 
-    //Add separators
+    // Add separators
     QStringList sepLst = prop_->param("separator").split("/");
     for (int i = 0; i < sepLst.count(); i++) {
         QString sepKey = sepLst[i].simplified();
@@ -801,7 +801,7 @@ EditComboLine::EditComboLine(MvQProperty* prop, QGridLayout* grid, EditLineHeade
         }
     }
 
-    //Set combo to default value
+    // Set combo to default value
     if (prop_->defaultValue().isValid()) {
         int idx = cb_->findData(prop_->defaultValue().toString());
         if (idx >= 0) {
@@ -810,7 +810,7 @@ EditComboLine::EditComboLine(MvQProperty* prop, QGridLayout* grid, EditLineHeade
         }
     }
 
-    //le_->setPlaceholderText(prop_->defaultValue().toString());
+    // le_->setPlaceholderText(prop_->defaultValue().toString());
 
     connect(cb_, SIGNAL(currentTextChanged(QString)),
             this, SLOT(currentChanged(QString)));
@@ -832,7 +832,7 @@ QString EditComboLine::value() const
     if (idx != -1) {
         return cb_->itemData(idx).toString();
     }
-    return QString();
+    return {};
 }
 
 void EditComboLine::currentChanged(QString)
@@ -870,7 +870,7 @@ EditAddRemoveLine::EditAddRemoveLine(MvQProperty* prop, QGridLayout* grid, EditL
 {
     Q_ASSERT(prop_);
 
-    //Minimum
+    // Minimum
     QString sval = prop_->param("minimum").simplified();
     if (!sval.isEmpty()) {
         int ival = sval.toInt();
@@ -878,7 +878,7 @@ EditAddRemoveLine::EditAddRemoveLine(MvQProperty* prop, QGridLayout* grid, EditL
             minimum_ = ival;
     }
 
-    //Maximum
+    // Maximum
     sval = prop_->param("maximum").simplified();
     if (!sval.isEmpty()) {
         int ival = sval.toInt();
@@ -888,7 +888,7 @@ EditAddRemoveLine::EditAddRemoveLine(MvQProperty* prop, QGridLayout* grid, EditL
 
     Q_ASSERT(minimum_ <= maximum_);
 
-    //Default
+    // Default
     sval = prop_->defaultValue().toString();
     if (!sval.isEmpty()) {
         int ival = sval.toInt();
@@ -898,29 +898,29 @@ EditAddRemoveLine::EditAddRemoveLine(MvQProperty* prop, QGridLayout* grid, EditL
 
     oriVal_ = QString::number(current_);
 
-    w_       = new QWidget(parent);
+    w_ = new QWidget(parent);
     auto* hb = new QHBoxLayout(w_);
     hb->setContentsMargins(0, 0, 0, 0);
     hb->setSpacing(0);
 
-    //label
+    // label
     cntLabel_ = new QLabel(w_);
     cntLabel_->setText(oriVal_);
 
-    //Buttons
+    // Buttons
     addTb_ = new QToolButton(w_);
     addTb_->setAutoRaise(true);
-    //addTb_->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
+    // addTb_->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
     addTb_->setIcon(QPixmap(":/examiner/plus_black.svg"));
     addTb_->setIconSize(QSize(16, 16));
-    //addTb_->setText(tr("Add"));
+    // addTb_->setText(tr("Add"));
 
     removeTb_ = new QToolButton(w_);
     removeTb_->setAutoRaise(true);
     // removeTb_->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
     removeTb_->setIcon(QPixmap(":/examiner/minus_black.svg"));
     removeTb_->setIconSize(QSize(16, 16));
-    //removeTb_->setText(tr("Remove"));
+    // removeTb_->setText(tr("Remove"));
 
     connect(addTb_, SIGNAL(clicked()),
             this, SLOT(slotAdd()));
@@ -930,12 +930,12 @@ EditAddRemoveLine::EditAddRemoveLine(MvQProperty* prop, QGridLayout* grid, EditL
 
     checkButtonStatus();
 
-    //Layout
+    // Layout
     hb->addSpacing(4);
     hb->addWidget(cntLabel_);
     hb->addSpacing(6);
     hb->addWidget(addTb_);
-    //hb->addSpacing(2);
+    // hb->addSpacing(2);
     hb->addWidget(removeTb_);
     hb->addStretch(1);
 
@@ -979,7 +979,7 @@ void EditAddRemoveLine::slotRemove()
 
 void EditAddRemoveLine::checkButtonStatus()
 {
-    bool addSt    = true;
+    bool addSt = true;
     bool removeSt = true;
     if (current_ == minimum_) {
         removeSt = false;
@@ -1016,11 +1016,11 @@ EditBoolLine::EditBoolLine(MvQProperty* prop, QGridLayout* grid, EditLineHeader*
 {
     Q_ASSERT(prop_);
 
-    //Default
+    // Default
     oriVal_ = prop_->defaultValue().toString();
     Q_ASSERT(!oriVal_.isEmpty());
 
-    w_       = new QWidget(parent);
+    w_ = new QWidget(parent);
     auto* hb = new QHBoxLayout(w_);
     hb->setContentsMargins(0, 0, 0, 0);
     hb->setSpacing(0);
@@ -1028,13 +1028,13 @@ EditBoolLine::EditBoolLine(MvQProperty* prop, QGridLayout* grid, EditLineHeader*
     QString strOnVal;
     QString strOffVal;
     if (prop_->type() == MvQProperty::BoolType) {
-        strOnVal    = "True";
-        strOffVal   = "False";
-        strOnData_  = "true";
+        strOnVal = "True";
+        strOffVal = "False";
+        strOnData_ = "true";
         strOffData_ = "false";
     }
     else {
-        QStringList lst     = prop_->param("values_label").split("/");
+        QStringList lst = prop_->param("values_label").split("/");
         QStringList lstData = prop_->param("values").split("/");
         if (prop_->param("values_label").simplified().isEmpty())
             lst = lstData;
@@ -1042,14 +1042,14 @@ EditBoolLine::EditBoolLine(MvQProperty* prop, QGridLayout* grid, EditLineHeader*
         Q_ASSERT(lst.count() == lstData.count());
         Q_ASSERT(lst.count() == 2);
 
-        strOnVal    = lst[0];
-        strOffVal   = lst[1];
-        strOnData_  = lstData[0];
+        strOnVal = lst[0];
+        strOffVal = lst[1];
+        strOnData_ = lstData[0];
         strOffData_ = lstData[1];
     }
 
-    //Radio buttons
-    radioOn_  = new QRadioButton(strOnVal, w_);
+    // Radio buttons
+    radioOn_ = new QRadioButton(strOnVal, w_);
     radioOff_ = new QRadioButton(strOffVal, w_);
     radioOn_->setProperty("data", strOnData_);
     radioOff_->setProperty("data", strOffData_);
@@ -1106,9 +1106,9 @@ void EditBoolLine::applyChange()
 
 EditConditionLine::EditConditionLine(MvQProperty* prop, QGridLayout* grid, EditLineHeader* header, QWidget* parent) :
     EditLine(prop, grid, header, parent),
-    condOperCb_(0),
-    condValueLe_(0),
-    condOperProp_(0),
+    condOperCb_(nullptr),
+    condValueLe_(nullptr),
+    condOperProp_(nullptr),
     broadcastChange_(true)
 {
     Q_ASSERT(prop_);
@@ -1116,12 +1116,12 @@ EditConditionLine::EditConditionLine(MvQProperty* prop, QGridLayout* grid, EditL
     MvQProperty* grProp = header->groupProp();
     Q_ASSERT(grProp);
 
-    //The holder widget
+    // The holder widget
     w_ = new QWidget(parent);
 
-    //Q_ASSERT(prop_->guiType() == MvQProperty::StringGui);
+    // Q_ASSERT(prop_->guiType() == MvQProperty::StringGui);
 
-    //The main editor
+    // The main editor
     condValueLe_ = new QLineEdit(w_);
     if (prop_->defaultValue().isValid()) {
         QString v = prop_->defaultValue().toString();
@@ -1139,8 +1139,8 @@ EditConditionLine::EditConditionLine(MvQProperty* prop, QGridLayout* grid, EditL
     connect(condValueLe_, SIGNAL(textChanged(QString)),
             this, SLOT(condValueChanged(QString)));
 
-    //The additonal editors
-    //First, check if the properties are available
+    // The additonal editors
+    // First, check if the properties are available
     QStringList wLst = prop_->param("with").simplified().split("/");
     Q_FOREACH (QString t, wLst) {
         QStringList opLst = t.simplified().split("=");
@@ -1161,7 +1161,7 @@ EditConditionLine::EditConditionLine(MvQProperty* prop, QGridLayout* grid, EditL
         Q_ASSERT(condOperProp_->guiType() == MvQProperty::StringComboGui);
         condOperCb_ = new QComboBox(w_);
 
-        QStringList lst     = condOperProp_->param("values_label").split("/");
+        QStringList lst = condOperProp_->param("values_label").split("/");
         QStringList lstData = condOperProp_->param("values").split("/");
         if (condOperProp_->param("values_label").simplified().isEmpty())
             lst = lstData;
@@ -1170,7 +1170,7 @@ EditConditionLine::EditConditionLine(MvQProperty* prop, QGridLayout* grid, EditL
         for (int i = 0; i < lst.count(); i++)
             condOperCb_->addItem(lst[i], lstData[i]);
 
-        //Set combo to default value
+        // Set combo to default value
         if (condOperProp_->defaultValue().isValid()) {
             int idx = lstData.indexOf(condOperProp_->defaultValue().toString());
             if (idx >= 0) {
@@ -1183,7 +1183,7 @@ EditConditionLine::EditConditionLine(MvQProperty* prop, QGridLayout* grid, EditL
                 this, SLOT(condOperChanged(int)));
     }
 
-    //The layout
+    // The layout
     auto* hb = new QHBoxLayout(w_);
     hb->setContentsMargins(0, 0, 0, 0);
     hb->setSpacing(0);
@@ -1263,16 +1263,16 @@ void EditConditionLine::applyChange()
 
 EditMultiConditionLine::EditMultiConditionLine(MvQProperty* prop, QGridLayout* grid, EditLineHeader* header, QWidget* parent) :
     EditLine(prop, grid, header, parent),
-    condRankTb_(0),
-    condRankLabel_(0),
-    condRankLe_(0),
-    condControlTb_(0),
-    condControlLabel_(0),
-    condOperCb_(0),
-    condValueLe_(0),
-    condRankProp_(0),
-    condOperProp_(0),
-    condValueProp_(0),
+    condRankTb_(nullptr),
+    condRankLabel_(nullptr),
+    condRankLe_(nullptr),
+    condControlTb_(nullptr),
+    condControlLabel_(nullptr),
+    condOperCb_(nullptr),
+    condValueLe_(nullptr),
+    condRankProp_(nullptr),
+    condOperProp_(nullptr),
+    condValueProp_(nullptr),
     broadcastChange_(true)
 {
     Q_ASSERT(prop_);
@@ -1280,10 +1280,10 @@ EditMultiConditionLine::EditMultiConditionLine(MvQProperty* prop, QGridLayout* g
     MvQProperty* grProp = header->groupProp();
     Q_ASSERT(grProp);
 
-    //The holder widget
+    // The holder widget
     w_ = new QWidget(parent);
 
-    //The main editor
+    // The main editor
     paramLe_ = new QLineEdit(w_);
     if (prop_->defaultValue().isValid()) {
         QString v = prop_->defaultValue().toString();
@@ -1301,8 +1301,8 @@ EditMultiConditionLine::EditMultiConditionLine(MvQProperty* prop, QGridLayout* g
     connect(paramLe_, SIGNAL(textChanged(QString)),
             this, SLOT(paramChanged(QString)));
 
-    //The additonal editors
-    //First, check if the properties are available
+    // The additonal editors
+    // First, check if the properties are available
     QStringList wLst = prop_->param("with").simplified().split("/");
     Q_FOREACH (QString t, wLst) {
         QStringList opLst = t.simplified().split("=");
@@ -1326,7 +1326,7 @@ EditMultiConditionLine::EditMultiConditionLine(MvQProperty* prop, QGridLayout* g
             }
         }
     }
-    //Next, create the editors
+    // Next, create the editors
 
     QFont smallFont;
     smallFont.setPointSize(smallFont.pointSize() - 1);
@@ -1338,7 +1338,7 @@ EditMultiConditionLine::EditMultiConditionLine(MvQProperty* prop, QGridLayout* g
         Q_ASSERT(condRankProp_->guiType() == MvQProperty::StringGui ||
                  condRankProp_->guiType() == MvQProperty::IntGui);
 
-        //Linedit for rank
+        // Linedit for rank
         condRankLe_ = new QLineEdit(w_);
         QFont f;
         QFontMetrics fm(f);
@@ -1354,14 +1354,14 @@ EditMultiConditionLine::EditMultiConditionLine(MvQProperty* prop, QGridLayout* g
         condRankLe_->setToolTip(tooltip);
 
 #if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
-        //condRankLe_->setClearButtonEnabled(true);
+        // condRankLe_->setClearButtonEnabled(true);
 #endif
         connect(condRankLe_, SIGNAL(textChanged(QString)),
                 this, SLOT(condRankChanged(QString)));
 
         QStringList condCnt = prop_->param("control").split("/");
 
-        //If rank can be enabled/disabled
+        // If rank can be enabled/disabled
         if (condCnt.contains("rank")) {
             condRankTb_ = new QToolButton(w_);
             condRankTb_->setAutoRaise(false);
@@ -1374,10 +1374,10 @@ EditMultiConditionLine::EditMultiConditionLine(MvQProperty* prop, QGridLayout* g
             connect(condRankTb_, SIGNAL(clicked(bool)),
                     this, SLOT(condRankTbChanged(bool)));
 
-            //off by default
+            // off by default
             condRankTbChanged(false);
         }
-        //rank is always visible
+        // rank is always visible
         else {
             condRankLabel_ = new QLabel(w_);
             condRankLabel_->setText(" Rank:");
@@ -1390,12 +1390,12 @@ EditMultiConditionLine::EditMultiConditionLine(MvQProperty* prop, QGridLayout* g
     //---------------------
     if (condOperProp_ && condValueProp_) {
         //---------------------
-        //operator
+        // operator
         //---------------------
         Q_ASSERT(condOperProp_->guiType() == MvQProperty::StringComboGui);
         condOperCb_ = new QComboBox(w_);
 
-        QStringList lst     = condOperProp_->param("values_label").split("/");
+        QStringList lst = condOperProp_->param("values_label").split("/");
         QStringList lstData = condOperProp_->param("values").split("/");
         if (condOperProp_->param("values_label").simplified().isEmpty())
             lst = lstData;
@@ -1404,7 +1404,7 @@ EditMultiConditionLine::EditMultiConditionLine(MvQProperty* prop, QGridLayout* g
         for (int i = 0; i < lst.count(); i++)
             condOperCb_->addItem(lst[i], lstData[i]);
 
-        //Set combo to default value
+        // Set combo to default value
         if (condOperProp_->defaultValue().isValid()) {
             int idx = lstData.indexOf(condOperProp_->defaultValue().toString());
             if (idx >= 0) {
@@ -1417,7 +1417,7 @@ EditMultiConditionLine::EditMultiConditionLine(MvQProperty* prop, QGridLayout* g
                 this, SLOT(condOperChanged(int)));
 
         //---------------------
-        //value
+        // value
         //---------------------
         Q_ASSERT(condValueProp_->guiType() == MvQProperty::StringGui);
 
@@ -1441,11 +1441,11 @@ EditMultiConditionLine::EditMultiConditionLine(MvQProperty* prop, QGridLayout* g
 
         QStringList condCnt = prop_->param("control").split("/");
 
-        //If value filter can be enabled/disabled
+        // If value filter can be enabled/disabled
         if (condCnt.contains("value")) {
             condControlTb_ = new QToolButton(w_);
             condControlTb_->setAutoRaise(false);
-            //condControlTb_->setIcon(QPixmap(":/examiner/filter.svg"));
+            // condControlTb_->setIcon(QPixmap(":/examiner/filter.svg"));
             condControlTb_->setText(tr("Value"));
             condControlTb_->setCheckable(true);
             condControlTb_->setChecked(false);
@@ -1455,10 +1455,10 @@ EditMultiConditionLine::EditMultiConditionLine(MvQProperty* prop, QGridLayout* g
             connect(condControlTb_, SIGNAL(clicked(bool)),
                     this, SLOT(condControlChanged(bool)));
 
-            //Disabled by defaut
+            // Disabled by defaut
             condControlChanged(false);
         }
-        //value filter is always visible
+        // value filter is always visible
         else {
             condControlLabel_ = new QLabel(w_);
             condControlLabel_->setText(" Value:");
@@ -1466,14 +1466,14 @@ EditMultiConditionLine::EditMultiConditionLine(MvQProperty* prop, QGridLayout* g
         }
     }
     else {
-        condOperProp_  = 0;
-        condValueProp_ = 0;
+        condOperProp_ = nullptr;
+        condValueProp_ = nullptr;
 
         condOperOriVal_.clear();
         condValueOriVal_.clear();
     }
 
-    //The layout
+    // The layout
     auto* hb = new QHBoxLayout(w_);
     hb->setContentsMargins(0, 0, 0, 0);
     hb->setSpacing(0);
@@ -1481,7 +1481,7 @@ EditMultiConditionLine::EditMultiConditionLine(MvQProperty* prop, QGridLayout* g
 
     if (condRankLe_) {
         if (condRankTb_) {
-            Q_ASSERT(condRankLabel_ == 0);
+            Q_ASSERT(condRankLabel_ == nullptr);
             hb->addWidget(condRankTb_);
         }
         else if (condRankLabel_) {
@@ -1493,7 +1493,7 @@ EditMultiConditionLine::EditMultiConditionLine(MvQProperty* prop, QGridLayout* g
 
     if (condOperCb_ && condValueLe_) {
         if (condControlTb_) {
-            Q_ASSERT(condControlLabel_ == 0);
+            Q_ASSERT(condControlLabel_ == nullptr);
             hb->addWidget(condControlTb_);
         }
         else if (condControlLabel_)
