@@ -92,11 +92,14 @@ struct Chunk
 
     mutable QString data;
     Chunk *previous, *next;
-    int size() const { return data.isEmpty() ? length : data.size(); }
+    int size() const
+    {
+        return data.isEmpty() ? length : data.size();
+    }
 #ifdef QT_DEBUG
     int pos() const
     {
-        int p    = 0;
+        int p = 0;
         Chunk* c = previous;
         while (c) {
             p += c->size();
@@ -124,9 +127,9 @@ struct Chunk
 static inline QPair<int, int> intersection(int index1, int size1, int index2, int size2)
 {
     QPair<int, int> ret;
-    ret.first       = qMax(index1, index2);
+    ret.first = qMax(index1, index2);
     const int right = qMin(index1 + size1, index2 + size2);
-    ret.second      = right - ret.first;
+    ret.second = right - ret.first;
     if (ret.second <= 0)
         return qMakePair(-1, 0);
     return ret;
@@ -191,9 +194,9 @@ public:
         ownDevice(false),
         modified(false),
         deviceMode(TextPagerDocument::Sparse),
-        chunkSize(64 * 1024),  //chunkSize(1024*64), //chunkSize(16384),
-                               //undoRedoStackCurrent(0), modifiedIndex(-1), undoRedoEnabled(true), ignoreUndoRedo(false),
-                               //collapseInsertUndo(false),
+        chunkSize(64 * 1024),  // chunkSize(1024*64), //chunkSize(16384),
+                               // undoRedoStackCurrent(0), modifiedIndex(-1), undoRedoEnabled(true), ignoreUndoRedo(false),
+                               // collapseInsertUndo(false),
         hasChunksWithLineNumbers(false),
         textCodec(0),
         options(TextPagerDocument::DefaultOptions),
@@ -281,7 +284,10 @@ public:
     friend class TextPagerDocument;
     void swapOutChunk(Chunk* c);
     QList<TextPagerSection*> getSections(int from, int size, TextPagerSection::TextSectionOptions opt, const TextPagerEdit* filter) const;
-    inline TextPagerSection* sectionAt(int pos, const TextPagerEdit* filter) const { return getSections(pos, 1, TextPagerSection::IncludePartial, filter).value(0); }
+    inline TextPagerSection* sectionAt(int pos, const TextPagerEdit* filter) const
+    {
+        return getSections(pos, 1, TextPagerSection::IncludePartial, filter).value(0);
+    }
     void textEditDestroyed(TextPagerEdit* edit);
 Q_SIGNALS:
     void sectionFormatChanged(TextPagerSection* section);
@@ -318,14 +324,14 @@ public:
         chunk = doc->chunkAt(p, &offset);
         Q_ASSERT(chunk);
         const int chunkPos = p - offset;
-        chunkData          = doc->chunkData(chunk, chunkPos);
-        //chunkLines = chunkData.split('\n');
+        chunkData = doc->chunkData(chunk, chunkPos);
+        // chunkLines = chunkData.split('\n');
         Q_COMPARE_ASSERT(chunkData.size(), chunk->size());
 #ifdef QT_DEBUG
         if (p != d->documentSize) {
             if (doc->q->readCharacter(p) != chunkData.at(offset)) {
-                //qDebug() << "got" << chunkData.at(offset) << "at" << offset << "in" << chunk << "of size" << chunkData.size()
-                //         << "expected" << doc->q->readCharacter(p) << "at document pos" << pos;
+                // qDebug() << "got" << chunkData.at(offset) << "at" << offset << "in" << chunk << "of size" << chunkData.size()
+                //          << "expected" << doc->q->readCharacter(p) << "at document pos" << pos;
             }
             Q_ASSERT(chunkData.at(offset) == doc->q->readCharacter(p));
         }
@@ -362,7 +368,7 @@ public:
         max = bound;
         Q_ASSERT(pos <= max);
 
-        //We suppose that the document size does not change
+        // We suppose that the document size does not change
         end_ = end();
     }
 
@@ -391,7 +397,7 @@ public:
         if (pos == end())
             return QChar();
 
-//Calling readCharacter is very expensive during find!!! So we try not to call it!!!
+// Calling readCharacter is very expensive during find!!! So we try not to call it!!!
 #if 0
 #ifdef QT_DEBUG
         if (doc->q->readCharacter(pos) != chunkData.at(offset)) {
@@ -404,7 +410,7 @@ public:
         ASSUME(doc->q->readCharacter(pos) == chunkData.at(offset));
 #endif
         return convert ? chunkData.at(offset).toLower() : chunkData.at(offset);
-        //return convert ? chunkData[offset].toLower() : chunkData[offset];
+        // return convert ? chunkData[offset].toLower() : chunkData[offset];
 #else
         return convert ? doc->q->readCharacter(pos).toLower() : doc->q->readCharacter(pos);
 #endif
@@ -418,7 +424,7 @@ public:
         Q_ASSERT(chunk);
         if (++offset >= chunkData.size() && chunk->next) {  // special case for offset == chunkData.size() and !chunk->next
             offset = 0;
-            chunk  = chunk->next;
+            chunk = chunk->next;
             Q_ASSERT(chunk);
             chunkData = doc->chunkData(chunk, pos);
             Q_COMPARE_ASSERT(chunkData.size(), chunk->size());
@@ -449,10 +455,10 @@ public:
 
     enum Direction
     {
-        None  = 0x0,
-        Left  = 0x1,
+        None = 0x0,
+        Left = 0x1,
         Right = 0x2,
-        Both  = Left | Right
+        Both = Left | Right
     };
     inline QChar nextPrev(Direction dir, bool& ok)
     {
@@ -484,29 +490,29 @@ public:
         Q_ASSERT(doc);
 
 #ifdef _UI_TEXTPAGER_ITERATOR_DEBUG
-        //qDebug() << "prevLine --->" << pos << offset;  //<< chunkData;
+        // qDebug() << "prevLine --->" << pos << offset;  //<< chunkData;
 #endif
 
-        //If we are at the start
+        // If we are at the start
         if (pos <= min)
             return 0;
 
-        //Get the QString in the chunk as a const pointer. It is faster to iterate through it than
-        //calling QString::at()
+        // Get the QString in the chunk as a const pointer. It is faster to iterate through it than
+        // calling QString::at()
         const QChar* data = chunkData.constData();
         data += offset;
 
         Q_ASSERT(*data == chunkData.at(offset));
 
-        //The current character is probably a newline (the
-        //result of the previous call) so we need to take a step back
+        // The current character is probably a newline (the
+        // result of the previous call) so we need to take a step back
         if (*data == newline) {
             --pos;
             --offset;
 
-            //See if we need the previous chunk
+            // See if we need the previous chunk
             if (offset < 0) {
-                //The previous chunk must exist
+                // The previous chunk must exist
                 bool b = loadPrevChunk();
                 Q_ASSERT(b == true);
                 data = chunkData.constData();
@@ -520,14 +526,14 @@ public:
                 return 0;
         }
 
-        //Mark the line end position within the chunk
+        // Mark the line end position within the chunk
         int to = offset;
 
-        //We will go backwards until we find a newline
+        // We will go backwards until we find a newline
         while (*data != newline) {
-            //Q_ASSERT(*data  == chunkData.at(offset));
+            // Q_ASSERT(*data  == chunkData.at(offset));
 #ifdef _UI_TEXTPAGER_ITERATOR_DEBUG
-            //qDebug() << pos << offset << chunkData.at(offset) << to;
+            // qDebug() << pos << offset << chunkData.at(offset) << to;
 #endif
             if (pos <= min) {
                 if (to != offset) {
@@ -543,25 +549,25 @@ public:
 
             --pos;
 
-            //If we need the previous chunk
+            // If we need the previous chunk
             if (--offset < 0) {
-                //Copy the line portion from this chunk to the result
+                // Copy the line portion from this chunk to the result
                 if (str.size() == 0)
                     str = chunkData.mid(0, to);
                 else
                     str.prepend(chunkData.mid(0, to));
 
-                //Get previous chunk
+                // Get previous chunk
                 bool b = loadPrevChunk();
                 Q_ASSERT(b == true);
 
-                //Initialise the search positions
+                // Initialise the search positions
                 data = chunkData.constData();
                 data += offset;
                 to = offset;
 
 #ifdef _UI_TEXTPAGER_ITERATOR_DEBUG
-                //qDebug() << "change" << pos << offset << *data << chunkData.at(offset);
+                // qDebug() << "change" << pos << offset << *data << chunkData.at(offset);
 #endif
             }
             else {
@@ -570,10 +576,10 @@ public:
         }
 
 #ifdef _UI_TEXTPAGER_ITERATOR_DEBUG
-        //qDebug() << pos << offset << to;
+        // qDebug() << pos << offset << to;
 #endif
 
-        //offset is either a newline charter or 0 (the start of the document)
+        // offset is either a newline charter or 0 (the start of the document)
 
         if (to != offset) {
             if (str.size() == 0) {
@@ -586,7 +592,7 @@ public:
 #endif
 
 #ifdef _UI_TEXTPAGER_ITERATOR_DEBUG
-        //qDebug() << "line:" << str;
+        // qDebug() << "line:" << str;
 #endif
 
         return 1;
@@ -602,28 +608,28 @@ public:
         Q_ASSERT(doc);
 
 #ifdef _UI_TEXTPAGER_ITERATOR_DEBUG
-        //qDebug() << "nextLine --->" << pos << offset << chunkData.size() << chunkData.at(offset);
+        // qDebug() << "nextLine --->" << pos << offset << chunkData.size() << chunkData.at(offset);
 #endif
         int posEnd = end();
         if (pos >= posEnd)
             return 0;
 
-        //Get the QString in the chunk as a const pointer. It is faster to iterate through it than
-        //calling QString::at()
+        // Get the QString in the chunk as a const pointer. It is faster to iterate through it than
+        // calling QString::at()
         const QChar* data = chunkData.constData();
         data += offset;
 
         Q_ASSERT(*data == chunkData.at(offset));
 
-        //The current character is probably a newline (the
-        //result of the previous call) so we need to take a step forward
+        // The current character is probably a newline (the
+        // result of the previous call) so we need to take a step forward
         if (*data == newline) {
             ++pos;
             ++offset;
 
-            //See if we need the next chunk
+            // See if we need the next chunk
             if (offset >= chunkData.size()) {
-                //Has next chunk
+                // Has next chunk
                 if (loadNextChunk()) {
                     data = chunkData.constData();
                     Q_ASSERT(offset == 0);
@@ -642,13 +648,13 @@ public:
                 return 0;
         }
 
-        //Mark the line start position within the chunk
+        // Mark the line start position within the chunk
         int from = offset;
 
-        //We will go forward until we find a newline
+        // We will go forward until we find a newline
         while (*data != newline) {
 #ifdef _UI_TEXTPAGER_ITERATOR_DEBUG
-            //qDebug() << pos << offset << chunkData.at(offset);
+            // qDebug() << pos << offset << chunkData.at(offset);
 #endif
             if (pos >= posEnd) {
                 if (str.size() == 0)
@@ -661,17 +667,17 @@ public:
 
             ++pos;
 
-            //If we need the next chunk
+            // If we need the next chunk
             if (++offset >= chunkData.size()) {
-                //Copy the line portion from this chunk to the result
+                // Copy the line portion from this chunk to the result
                 if (str.size() == 0)
                     str = chunkData.mid(from, offset - from);
                 else
                     str.append(chunkData.mid(from, offset - from));
 
-                //Get next chunk
+                // Get next chunk
                 if (loadNextChunk()) {
-                    //Initialise the search positions
+                    // Initialise the search positions
                     data = chunkData.constData();
                     from = 0;
                 }
@@ -697,7 +703,7 @@ public:
 #endif
 
 #ifdef _UI_TEXTPAGER_ITERATOR_DEBUG
-        //qDebug() << "line:" << str;
+        // qDebug() << "line:" << str;
 #endif
 
         return 1;
