@@ -23,23 +23,23 @@ class BufrMessageScanner : public MvQAbstractMessageScanner
     Q_OBJECT
 
 public:
-    BufrMessageScanner(MvMessageMetaData* data, QObject* parent = 0);
-    ~BufrMessageScanner();
+    BufrMessageScanner(MvMessageMetaData* data, QObject* parent = nullptr);
+    ~BufrMessageScanner() override;
 
 protected slots:
     void slotProgress(int, MvKeyProfile*, int, int, std::vector<MvEccBufrMessage*>);
-    void slotTotalMessageNumComputed();
+    void slotTotalMessageNumComputed() override;
 
 signals:
     void progress(int, MvKeyProfile*, int, int, std::vector<MvEccBufrMessage*>);
 
 protected:
-    bool useThreadForScanning(qint64 fSize) const;
-    bool precomputeMessageNum() const;
-    void run();
-    void loadKeyProfile(MvKeyProfile* prof);
-    void readMessages(MvKeyProfile* prof);
-    //void readMessage(MvKeyProfile* prof, codes_handle* ch, int msgCnt, int profIndex);
+    bool useThreadForScanning(qint64 fSize) const override;
+    bool precomputeMessageNum() const override;
+    void run() override;
+    void loadKeyProfile(MvKeyProfile* prof) override;
+    void readMessages(MvKeyProfile* prof) override;
+    // void readMessage(MvKeyProfile* prof, codes_handle* ch, int msgCnt, int profIndex);
     void readMessage(MvKeyProfile* prof, codes_bufr_header* bh, int profIndex);
 
     BufrMetaData* bufrData_;
