@@ -94,7 +94,7 @@ void safeDrawLine(const QPointF& p1, const QPointF& p2, QPainter* painter);
 void safeDrawLine(const QPoint& p1, const QPoint& p2, QPainter* painter);
 void drawPolyline(const QVector<QPointF>& pp, QPainter* painter);
 void drawPolyline(const std::vector<double>& x, const std::vector<double>& y, QPainter* painter);
-void showMessageBox(const std::string& msg, MvLogLevel level);
+void showMessageBox(const std::string& msg, MvLogLevel level, const std::string& details ={});
 
 template <typename T>
 QPoint eventPos(T* event)
