@@ -21,7 +21,7 @@
 #include <algorithm>
 #include <array>
 #include <cmath>
-#include <ctype.h>
+#include <cctype>
 
 #include "ConfigLoader.h"
 #include "Tokenizer.h"
@@ -35,36 +35,35 @@ static const float toDegFactor = 180. / 3.14159265359;
 
 //#define DEBUG_MV_MVQPALETTE__
 
-namespace {
+namespace
+{
 // CIE contants
 const float CIE_EPS = 0.008856451679035631;
 const float CIE_KAPPA = 903.2962962962963;
 
-//reference values for the XYZ colour model. Observer=2 deg, illuminant=d65
+// reference values for the XYZ colour model. Observer=2 deg, illuminant=d65
 const float D65_X = 95.047;
 const float D65_Y = 100.000;
 const float D65_Z = 108.883;
 
-//reference values for the XYZ colour model. Observer=2 deg, illuminant=d50
-//const float D50_X = 0.96422;
+// reference values for the XYZ colour model. Observer=2 deg, illuminant=d50
+// const float D50_X = 0.96422;
 const float D50_Y = 1;
-//const float D50_Z = 0.82521;
+// const float D50_Z = 0.82521;
 const float D50_U = 0.20916005282038627;
 const float D50_V = 0.48807338454488514;
 
 // conversion matrix for srgb (d65) to xyz (d50)
 const std::array<float, 9> matrixLrgbToXyzd50 = {
-  0.4360747, 0.3850649, 0.1430804,
-  0.2225045, 0.7168786, 0.0606169,
-  0.0139322, 0.0971045, 0.7141733
-};
+    0.4360747, 0.3850649, 0.1430804,
+    0.2225045, 0.7168786, 0.0606169,
+    0.0139322, 0.0971045, 0.7141733};
 
 // conversion matrix for xyz (d50) to srgb (d65)
 const std::array<float, 9> matrixXyzd50ToLrgb = {
-  3.1338561, -1.6168667, -0.4906146,
-  -0.9787684, 1.9161415, 0.0334540,
-  0.0719453, -0.2289914, 1.4052427
-};
+    3.1338561, -1.6168667, -0.4906146,
+    -0.9787684, 1.9161415, 0.0334540,
+    0.0719453, -0.2289914, 1.4052427};
 
 void rgbToXyz(float r, float g, float b, float& x, float& y, float& z);
 void xyzToRgb(float x, float y, float z, float& r, float& g, float& b);
@@ -110,9 +109,9 @@ void rgbToXyz(float r, float g, float b, float& x, float& y, float& z)
 // r,g,b : 0-1
 void xyzToRgb(float x, float y, float z, float& r, float& g, float& b)
 {
-    x = x / 100.;  //x from 0 to  95.047
-    y = y / 100.;  //y from 0 to 100.000
-    z = z / 100.;  //z from 0 to 108.883
+    x = x / 100.;  // x from 0 to  95.047
+    y = y / 100.;  // y from 0 to 100.000
+    z = z / 100.;  // z from 0 to 108.883
 
     r = x * 3.2406 + y * (-1.5372) + z * (-0.4986);
     g = x * (-0.9689) + y * 1.8758 + z * 0.0415;
@@ -151,12 +150,12 @@ void xyzToRgb(float x, float y, float z, float& r, float& g, float& b)
 
 float rgbToLinearLightRgb(float v)
 {
-    return (v > 0.04045)?std::pow((v + 0.055) / 1.055, 2.4):(v / 12.92);
+    return (v > 0.04045) ? std::pow((v + 0.055) / 1.055, 2.4) : (v / 12.92);
 }
 
 float linearLightRgbToRgb(float v)
 {
-    return (v > 0.0031308)?(1.055 * std::pow(v, 1. / 2.4) - 0.055):(12.92 * v);
+    return (v > 0.0031308) ? (1.055 * std::pow(v, 1. / 2.4) - 0.055) : (12.92 * v);
 }
 
 // Convert normalised sRGB (illuminant=d65) to CIE XYZ  (illuminant=d50)
@@ -176,9 +175,9 @@ void rgbToXyzd50(float r, float g, float b, float& x, float& y, float& z)
     // Apply the conversion matrix. Since sRGB uses d65 and the target XYZ uses d50
     // a chromatic adaptation must also be performed on the result. This operation
     // is already incorporated into the conversion matrix.
-    x = r * matrixLrgbToXyzd50[0] + g * matrixLrgbToXyzd50[1]  + b * matrixLrgbToXyzd50[2];
-    y = r * matrixLrgbToXyzd50[3] + g * matrixLrgbToXyzd50[4]  + b * matrixLrgbToXyzd50[5];
-    z = r * matrixLrgbToXyzd50[6] + g * matrixLrgbToXyzd50[7]  + b * matrixLrgbToXyzd50[8];
+    x = r * matrixLrgbToXyzd50[0] + g * matrixLrgbToXyzd50[1] + b * matrixLrgbToXyzd50[2];
+    y = r * matrixLrgbToXyzd50[3] + g * matrixLrgbToXyzd50[4] + b * matrixLrgbToXyzd50[5];
+    z = r * matrixLrgbToXyzd50[6] + g * matrixLrgbToXyzd50[7] + b * matrixLrgbToXyzd50[8];
 }
 
 // Convert CIE XYZ  (illuminant=d50) to normalised sRGB (illuminant=d65)
@@ -186,16 +185,16 @@ void rgbToXyzd50(float r, float g, float b, float& x, float& y, float& z)
 // r,g,b : 0-1
 void xyzd50ToRgb(float x, float y, float z, float& r, float& g, float& b)
 {
-    x = x / 100.;  //x from 0 to  95.047
-    y = y / 100.;  //y from 0 to 100.000
-    z = z / 100.;  //z from 0 to 108.883
+    x = x / 100.;  // x from 0 to  95.047
+    y = y / 100.;  // y from 0 to 100.000
+    z = z / 100.;  // z from 0 to 108.883
 
     // Apply the conversion matrix. Since the source XYZ uses d50 and sRGB uses
     // d65 the chromatic adaptation must also be performed on the result. This operation
     // is already incorporated into the conversion matrix.
-    r = x * matrixXyzd50ToLrgb[0] + y * matrixXyzd50ToLrgb[1]  + z * matrixXyzd50ToLrgb[2];
-    g = x * matrixXyzd50ToLrgb[3] + y * matrixXyzd50ToLrgb[4]  + z * matrixXyzd50ToLrgb[5];
-    b = x * matrixXyzd50ToLrgb[6] + y * matrixXyzd50ToLrgb[7]  + z * matrixXyzd50ToLrgb[8];
+    r = x * matrixXyzd50ToLrgb[0] + y * matrixXyzd50ToLrgb[1] + z * matrixXyzd50ToLrgb[2];
+    g = x * matrixXyzd50ToLrgb[3] + y * matrixXyzd50ToLrgb[4] + z * matrixXyzd50ToLrgb[5];
+    b = x * matrixXyzd50ToLrgb[6] + y * matrixXyzd50ToLrgb[7] + z * matrixXyzd50ToLrgb[8];
 
     // convert linear-light RGB to gamma encoded sRGB (companding)
     r = linearLightRgbToRgb(r);
@@ -230,7 +229,7 @@ void xyzToHclLab(float x, float y, float z, float& h, float& c, float& l)
     else
         z = (7.787 * z) + (16. / 116.);
 
-    l       = (116. * y) - 16.;
+    l = (116. * y) - 16.;
     float a = 500. * (x - y);
     float b = 200. * (y - z);
 #ifdef DEBUG_MV_MVQPALETTE__
@@ -294,39 +293,40 @@ void xyzToHclLuv(float x, float y, float z, float& h, float& c, float& l)
     float u = 0.;
     float v = 0.;
     if (d != 0) {
-        u = 4.0 * x/ d;
-        v = 9.0 * y/ d;
+        u = 4.0 * x / d;
+        v = 9.0 * y / d;
     }
 
     y /= D50_Y;
-    y = (y > CIE_EPS) ? std::cbrt(y) : ((7.787  * y) + 16./116.);
+    y = (y > CIE_EPS) ? std::cbrt(y) : ((7.787 * y) + 16. / 116.);
 
-    //D50_U = (4.0 * D50_X) / (D50_X + (15.0 * D50_Y) + (3.0 * D50_Z));
-    //D50_V = (9.0 * D50_Y) / (D50_X + (15.0 * D50_Y) + (3.0 * D50_Z));
+    // D50_U = (4.0 * D50_X) / (D50_X + (15.0 * D50_Y) + (3.0 * D50_Z));
+    // D50_V = (9.0 * D50_Y) / (D50_X + (15.0 * D50_Y) + (3.0 * D50_Z));
 
     l = (116.0 * y) - 16.0;
     u = 13.0 * l * (u - D50_U);
     v = 13.0 * l * (v - D50_V);
 
-//#ifdef DEBUG_MV_MVQPALETTE__
-    //qDebug() << "   uvl" << u << v << l;
-//#endif
+    //#ifdef DEBUG_MV_MVQPALETTE__
+    // qDebug() << "   uvl" << u << v << l;
+    //#endif
     h = atan2(v, u);
-//#ifdef DEBUG_MV_MVQPALETTE__
-    //qDebug() << "   h1" << h;
-//#endif
+    //#ifdef DEBUG_MV_MVQPALETTE__
+    // qDebug() << "   h1" << h;
+    //#endif
     if (h > 0) {
         h = h * toDegFactor;
-    } else {
+    }
+    else {
         h = 360. + h * toDegFactor;
     }
-//#ifdef DEBUG_MV_MVQPALETTE__
-    //qDebug() << "   h2" << h;
-//#endif
+    //#ifdef DEBUG_MV_MVQPALETTE__
+    // qDebug() << "   h2" << h;
+    //#endif
     h = h / 360.;
     c = sqrt(u * u + v * v);
 
-    qDebug() << "xyzToHclLuv: (" <<  x << y << z << ") ->" << h << c << l;
+    qDebug() << "xyzToHclLuv: (" << x << y << z << ") ->" << h << c << l;
 }
 
 // h,c,l : 0-1
@@ -334,9 +334,9 @@ void xyzToHclLuv(float x, float y, float z, float& h, float& c, float& l)
 void hclLuvToXyz(float h, float c, float l, float& x, float& y, float& z)
 {
     if (l <= 0) {
-        x =0.;
-        y =0.;
-        z =0.;
+        x = 0.;
+        y = 0.;
+        z = 0.;
         return;
     }
     float u = cos(360 * h * toRadFactor) * c;
@@ -345,33 +345,31 @@ void hclLuvToXyz(float h, float c, float l, float& x, float& y, float& z)
     const float up = u / (13 * l) + D50_U;
     const float vp = v / (13 * l) + D50_V;
 
-    if (l > l / CIE_KAPPA*CIE_EPS) {
+    if (l > l / CIE_KAPPA * CIE_EPS) {
         y = std::pow((l + 16) / 116., 3.);
-    } else {
+    }
+    else {
         y = l / CIE_KAPPA;
     }
 
     const float d = 4 * vp;
     x = y * 9 * up / d;
-    z = y * (12 - 3 * up - 20 * vp)/d;
+    z = y * (12 - 3 * up - 20 * vp) / d;
 
     //#ifdef DEBUG_MV_MVQPALETTE__
-    //qDebug() << "hclLuvToXyz: " <<  x << y << z;
+    // qDebug() << "hclLuvToXyz: " <<  x << y << z;
     //#endif
     x *= 100;
     y *= 100;
     z *= 100;
 }
-}
+}  // namespace
 
 void MvQPalette::load(request* r)
 {
     // populate our list of 'special'/'pseudo' colour names
     if (pseudoColourNames_.empty()) {
-        pseudoColourNames_.push_back("AUTOMATIC");
-        pseudoColourNames_.push_back("CONTOUR_LINE_COLOUR");
-        pseudoColourNames_.push_back("BACKGROUND");
-        pseudoColourNames_.push_back("FOREGROUND");
+        pseudoColourNames_ = {"AUTOMATIC", "CONTOUR_LINE_COLOUR", "BACKGROUND", "FOREGROUND"};
     }
 
     const char* fname = get_value(r, "colour_file", 0);
@@ -389,9 +387,9 @@ void MvQPalette::load(request* r)
 
     while (fgets(line, sizeof(line), f)) {
         char* p = line;
-        int i   = 0;
+        int i = 0;
 
-        sscanf(p, "%s ; %s", color, name);
+        sscanf(p, "%79s ; %79s", color, name);
         while (*p && !i) {
             if (*p == '#') {
                 color[i++] = *p++;
@@ -405,7 +403,7 @@ void MvQPalette::load(request* r)
         }
         if (i) {
             bool pseudo = MvQPalette::isPseudo(name);
-            names_.push_back(name);
+            names_.emplace_back(name);
             items_[name] = MvQPaletteItem(name,
                                           (pseudo) ? QColor() : MvQPalette::hexaCharToColour(color), pseudo);
         }
@@ -426,7 +424,7 @@ bool MvQPalette::isPseudo(const std::string& name)
 QColor MvQPalette::hexaCharToColour(const char* hexaChar)
 {
     if (strlen(hexaChar) == 13) {
-        unsigned int r, g, b;
+        unsigned int r = 0, g = 0, b = 0;
         char cval[5];
 
         strncpy(cval, hexaChar + 1, 4);
@@ -444,7 +442,7 @@ QColor MvQPalette::hexaCharToColour(const char* hexaChar)
         return QColor(r / 256, g / 256, b / 256);
     }
 
-    return QColor();
+    return {};
 }
 
 
@@ -462,9 +460,9 @@ void MvQPalette::scan(PaletteScanner& p)
 
 std::string MvQPalette::toString(QColor col)
 {
-    for (auto it = items_.begin(); it != items_.end(); it++) {
-        if (it->second.pseudo_ == false && it->second.col_ == col)
-            return it->first;
+    for (auto& item : items_) {
+        if (item.second.pseudo_ == false && item.second.col_ == col)
+            return item.first;
     }
 
     return toRgbString(col).toStdString();
@@ -576,14 +574,14 @@ QList<QColor> MvQPalette::toColourList(QString txt)
 
     QList<QColor> cLst;
 
-    //strip off the closing and ending brackets
+    // strip off the closing and ending brackets
     txt = txt.simplified();
     if (!txt.startsWith("[") || !txt.endsWith("]"))
         return cLst;
 
     txt = txt.mid(1, txt.size() - 2);
 
-    QRegExp rx("(\".*\")(?=\\s*,|\\s*$)");
+    QRegExp rx(R"((".*")(?=\s*,|\s*$))");
     rx.setMinimal(true);
 
     int pos = 0;
@@ -603,7 +601,7 @@ QColor MvQPalette::magics(const std::string& nameIn)
     std::string name = nameIn;
     std::transform(name.begin(), name.end(), name.begin(), ::toupper);
 
-    //remove quotes
+    // remove quotes
     if (name.empty())
         return col;
 
@@ -645,7 +643,7 @@ QColor MvQPalette::magics(const std::string& nameIn)
                 case 'r':
                 case 'R':
                     if (x1 > 255.5)
-                        x1 = 255.;  //to handle values like r=256 !!!
+                        x1 = 255.;  // to handle values like r=256 !!!
                     if (x2 > 255.5)
                         x2 = 255.;
                     if (x3 > 255.5)
@@ -663,14 +661,14 @@ QColor MvQPalette::magics(const std::string& nameIn)
                     break;
             }
 
-            //Alpha
+            // Alpha
             if (v.size() == 5) {
                 double x4 = atof(v[4].c_str());
                 col.setAlphaF(x4);
             }
 
             if (col.isValid()) {
-                //colors[name] = col;
+                // colors[name] = col;
             }
         }
         else if (name.empty()) {
@@ -682,15 +680,15 @@ QColor MvQPalette::magics(const std::string& nameIn)
         }
     }
 
-    //colors[name] = c;
-    //return PaletteRGBColor(palette,&c);
+    // colors[name] = c;
+    // return PaletteRGBColor(palette,&c);
 
     return col;
 }
 
 void MvQPalette::toHclLabF(QColor c, float& hue, float& chroma, float& luminance)
 {
-    float x, y, z;
+    float x = 0., y = 0., z = 0.;
     rgbToXyz(c.redF(), c.greenF(), c.blueF(), x, y, z);
 #ifdef DEBUG_MV_MVQPALETTE__
     qDebug() << "xyz" << x << y << z;
@@ -702,25 +700,25 @@ void MvQPalette::toHclLabF(QColor c, float& hue, float& chroma, float& luminance
 
 void MvQPalette::toHclLab(QColor c, int& hue, int& chroma, int& luminance)
 {
-    float h, ch, l;
+    float h = 0., ch = 0., l = 0.;
     toHclLabF(c, h, ch, l);
-    //qDebug() << "toHcl=" << h << ch << l;
-    hue = static_cast<int>(h*360);
+    // qDebug() << "toHcl=" << h << ch << l;
+    hue = static_cast<int>(h * 360);
     chroma = static_cast<int>(ch);
     luminance = static_cast<int>(l);
 }
 
-QColor MvQPalette::fromHclLab(int hue,int chroma, int luminance)
+QColor MvQPalette::fromHclLab(int hue, int chroma, int luminance)
 {
-    float h = static_cast<float>(hue)/359.;
-    float ch = static_cast<float>(chroma);
-    float l = static_cast<float>(luminance);
+    float h = static_cast<float>(hue) / 359.;
+    auto ch = static_cast<float>(chroma);
+    auto l = static_cast<float>(luminance);
     return fromHclLabF(h, ch, l);
 }
 
 QColor MvQPalette::fromHclLabF(float hue, float chroma, float luminance)
 {
-    float x, y, z, r, g, b;
+    float x = 0., y = 0., z = 0., r = 0., g = 0., b = 0.;
     hclLabToXyz(hue, chroma, luminance, x, y, z);
     xyzToRgb(x, y, z, r, g, b);
     return QColor::fromRgbF(r, g, b);
@@ -729,11 +727,11 @@ QColor MvQPalette::fromHclLabF(float hue, float chroma, float luminance)
 
 void MvQPalette::toHclLuvF(QColor c, float& hue, float& chroma, float& luminance)
 {
-    float x, y, z;
+    float x = 0., y = 0., z = 0.;
     rgbToXyzd50(c.redF(), c.greenF(), c.blueF(), x, y, z);
-//#ifdef DEBUG_MV_MVQPALETTE__
-    //qDebug() << "xyz" << x << y << z;
-//#endif
+    //#ifdef DEBUG_MV_MVQPALETTE__
+    // qDebug() << "xyz" << x << y << z;
+    //#endif
     xyzToHclLuv(x, y, z, hue, chroma, luminance);
     if (c.red() == 255 && c.green() == 255 && c.blue() == 255)
         hue = 40. / 360.;
@@ -741,34 +739,34 @@ void MvQPalette::toHclLuvF(QColor c, float& hue, float& chroma, float& luminance
 
 void MvQPalette::toHclLuv(QColor c, int& hue, int& chroma, int& luminance)
 {
-    float h, ch, l;
+    float h = 0., ch = 0., l = 0.;
     toHclLuvF(c, h, ch, l);
     qDebug() << "toHclLuv:" << c << "->" << h << ch << l;
-    hue = static_cast<int>(h*360);
+    hue = static_cast<int>(h * 360);
     chroma = static_cast<int>(ch);
     luminance = static_cast<int>(l);
     qDebug() << "->" << hue << chroma << luminance;
 }
 
-QColor MvQPalette::fromHclLuv(int hue,int chroma, int luminance)
+QColor MvQPalette::fromHclLuv(int hue, int chroma, int luminance)
 {
-    float h = static_cast<float>(hue)/355.;
-    float ch = static_cast<float>(chroma);
-    float l = static_cast<float>(luminance);
+    float h = static_cast<float>(hue) / 355.;
+    auto ch = static_cast<float>(chroma);
+    auto l = static_cast<float>(luminance);
     auto col = fromHclLuvF(h, ch, l);
-    //qDebug() << "toHclLuv:" << h << ch << l << "->" << col;
+    // qDebug() << "toHclLuv:" << h << ch << l << "->" << col;
     return col;
 }
 
 QColor MvQPalette::fromHclLuvF(float hue, float chroma, float luminance)
 {
-    float x, y, z, r, g, b;
+    float x = 0., y = 0., z = 0., r = 0., g = 0., b = 0.;
     hclLuvToXyz(hue, chroma, luminance, x, y, z);
     xyzd50ToRgb(x, y, z, r, g, b);
     return QColor::fromRgbF(r, g, b);
 }
 
-//paint the chequered background when alpha is set
+// paint the chequered background when alpha is set
 void MvQPalette::paintAlphaBg(QPainter* painter, QRect area)
 {
     painter->save();
@@ -776,9 +774,9 @@ void MvQPalette::paintAlphaBg(QPainter* painter, QRect area)
 
     QColor c1(170, 170, 170);
     QColor c2(190, 190, 190);
-    int rs      = 8;
-    int nx      = area.width() / rs;
-    int ny      = area.height() / rs;
+    int rs = 8;
+    int nx = area.width() / rs;
+    int ny = area.height() / rs;
     QColor cAct = c1;
     for (int i = 0; i <= nx; i++)
         for (int j = 0; j <= ny; j++) {
