@@ -28,9 +28,9 @@ std::vector<WsGroup*> WsGroup::items_;
 std::vector<WsType*> WsType::items_;
 std::map<std::string, MvIconClassCore*> WsType::cls_;
 WsType* WsType::userImageAllItem_ = nullptr;
-WsType* WsType::wmoAllItem_      = nullptr;
-WsType::Mode WsType::mode_       = WsType::NoMode;
-int WsType::defaultPixSize_      = 20;
+WsType* WsType::wmoAllItem_ = nullptr;
+WsType::Mode WsType::mode_ = WsType::NoMode;
+int WsType::defaultPixSize_ = 20;
 static QColor defaultPixBgColor(Qt::transparent);
 
 //=================================================================
@@ -139,14 +139,18 @@ void WsType::load_system_feature_items()
                     if (mode_ == DesktopMode) {
                         items_.push_back(wmoAllItem_);
                     }
-                } else if(strcmp(req, "WS_HIGH") == 0  || strcmp(req, "WS_LOW") == 0) {
+                }
+                else if (strcmp(req, "WS_HIGH") == 0 || strcmp(req, "WS_LOW") == 0) {
                     items_.push_back(new WsCharImageType(r));
-                } else if(strcmp(req, "WS_STORM") == 0 ) {
+                }
+                else if (strcmp(req, "WS_STORM") == 0) {
                     items_.push_back(new WsSvgImageType(r));
-                } else if(strcmp(req, "WS_IMAGE") == 0  || strcmp(req, "WS_MARKER") == 0 ||
-                          strcmp(req, "WS_SHAPE") == 0) {
+                }
+                else if (strcmp(req, "WS_IMAGE") == 0 || strcmp(req, "WS_MARKER") == 0 ||
+                         strcmp(req, "WS_SHAPE") == 0) {
                     items_.push_back(new WsStandardMultiType(r));
-                } else {
+                }
+                else {
                     items_.push_back(new WsStandardType(r));
                 }
             }
@@ -172,7 +176,6 @@ void WsType::load_user_feature_items()
 
     QList<QString> added;
     for (auto items_dir : dirs) {
-
         // Search directory to get all items (svg and png)
         if (items_dir.isEmpty()) {
             continue;
@@ -195,7 +198,7 @@ void WsType::load_user_feature_items()
             }
             else {
                 if (!added.contains(fileName)) {
-//                    MvLog().dbg() << MV_FN_INFO << " name=" << name;
+                    //                    MvLog().dbg() << MV_FN_INFO << " name=" << name;
                     items_.push_back(new WsUserImageSingleType(fileName, items_dir));
                     added << fileName;
                 }
@@ -245,10 +248,10 @@ WsType* WsType::findByReq(const MvRequest& req)
             }
         }
 
-//        MvLog().dbg() << MV_FN_INFO << " verb=" << verb << " rType=" << rType << " uType=" << uType;
+        //        MvLog().dbg() << MV_FN_INFO << " verb=" << verb << " rType=" << rType << " uType=" << uType;
         for (auto it : items_) {
-            if (it->matchReq(verb, rType, uType)) {              
-//                MvLog().dbg() << " it=" << it->name() << " " << it->reqVerb();
+            if (it->matchReq(verb, rType, uType)) {
+                //                MvLog().dbg() << " it=" << it->name() << " " << it->reqVerb();
                 return it;
             }
         }
@@ -258,7 +261,7 @@ WsType* WsType::findByReq(const MvRequest& req)
 
 MvRequest WsType::expandRequest(const MvRequest& r, long flags)
 {
-    if(const char* ch = r.getVerb()) {
+    if (const char* ch = r.getVerb()) {
         std::string verb(ch);
         auto it = cls_.find(verb);
         if (it != cls_.end()) {
@@ -348,7 +351,8 @@ bool WsStandardType::matchReq(QString verb, QString /*reqType*/, QString /*reqUs
 //
 //=================================================================
 
-WsSvgImageType::WsSvgImageType(const MvRequest& r) : WsStandardMultiType(r)
+WsSvgImageType::WsSvgImageType(const MvRequest& r) :
+    WsStandardMultiType(r)
 {
     const char* verb = r.getVerb();
     assert(verb);
@@ -365,7 +369,7 @@ QPixmap WsSvgImageType::pixmap(int width, int height, QColor fg, QPen /*boxPen*/
     if (!svgTemplateColour_.isEmpty() && fg.isValid()) {
         return MvQ::makePixmapFromSvgTemplate(iconPath(), width, height,
                                               fg, svgTemplateColour_, {}, {});
-        }
+    }
     return MvQ::makePixmap(iconPath(), width, height, col);
 }
 
@@ -375,7 +379,8 @@ QPixmap WsSvgImageType::pixmap(int width, int height, QColor fg, QPen /*boxPen*/
 //
 //=================================================================
 
-WsCharImageType::WsCharImageType(const MvRequest& r) : WsStandardType(r)
+WsCharImageType::WsCharImageType(const MvRequest& r) :
+    WsStandardType(r)
 {
     const char* verb = r.getVerb();
     assert(verb);
@@ -394,8 +399,8 @@ QPixmap WsCharImageType::pixmapWithChar(int width, int height, QColor fg, QChar
     auto col = QColor(Qt::transparent);
     QString templateTxt = ">" + QString(svgTemplateChar_) + "</tspan></text>";
     QString txt = ">" + QString(ch) + "</tspan></text>";
-//    MvLog().dbg() << MV_FN_INFO << "svgTemplateColour=" <<  svgTemplateColour_ <<
-//                     " svgTemplateChar=" << QString(svgTemplateChar_) << " fg=" << fg <<" txt=" << txt;
+    //    MvLog().dbg() << MV_FN_INFO << "svgTemplateColour=" <<  svgTemplateColour_ <<
+    //                     " svgTemplateChar=" << QString(svgTemplateChar_) << " fg=" << fg <<" txt=" << txt;
 
     if (!svgTemplateColour_.isEmpty() && fg.isValid()) {
         return MvQ::makePixmapFromSvgTemplate(iconPath(), width, height,
@@ -433,7 +438,7 @@ QString WsUserImageAllType::nameFromRequest(const MvRequest& req) const
         rType = rType.toLower();
         if (rType == "user") {
             if (const char* u = req("NAME")) {
-                return QString(u);
+                return {u};
             }
         }
     }
@@ -461,7 +466,7 @@ QString WsWmoAllType::nameFromRequest(const MvRequest& req) const
 //
 //=================================================================
 
-WsUserImageSingleType::WsUserImageSingleType(QString iconName, QString iconDir):
+WsUserImageSingleType::WsUserImageSingleType(QString iconName, QString iconDir) :
     iconName_(iconName),
     iconDir_(iconDir)
 {
@@ -613,7 +618,7 @@ QPixmap WsWmoSingleType::pixmap(int width, int height, QColor fg, QPen boxPen, Q
     if (symbol_) {
         return symbol_->pixmap(width, height, fg, boxPen, boxBrush);
     }
-    return QPixmap(width, height);
+    return {width, height};
 }
 
 void WsWmoSingleType::updateTypeInReq(MvRequest& r)
