@@ -44,10 +44,11 @@ class CommonXSectView : public PlotModView, public PlotModService
 public:
     // -- Constructor
     CommonXSectView(Page&, const MvRequest&, const MvRequest&);
-    CommonXSectView(const CommonXSectView&);
+    CommonXSectView(const CommonXSectView&) = default;
+    CommonXSectView& operator=(const CommonXSectView&) = delete;
 
     // -- Destructor
-    ~CommonXSectView();
+    ~CommonXSectView() override = default;
 
     // --  Methods overriden from PlotModView class
     std::string Name() override;
@@ -67,11 +68,11 @@ public:
     void ParentDataUnitId(int parentDataUnitId)
     {
         viewRequest_("_PARENT_DATAUNIT_ID") = parentDataUnitId;
-        appViewReq_("_PARENT_DATAUNIT_ID")  = parentDataUnitId;
-        parentDataUnitId_                   = parentDataUnitId;
+        appViewReq_("_PARENT_DATAUNIT_ID") = parentDataUnitId;
+        parentDataUnitId_ = parentDataUnitId;
     }
 
-    int ParentDataUnitId() { return parentDataUnitId_; }
+    int ParentDataUnitId() const { return parentDataUnitId_; }
 
     bool ConsistencyCheck(MvRequest&, MvRequest&) override { return true; }
 
@@ -100,47 +101,12 @@ protected:
     // same tag _MODULEID
     bool DropFromModule(MvRequest&, MvRequest&, bool&);
 
-#if 0
-    // Provide Axis information
-    void DescribeAxis ( ObjectInfo& description,
-                        MvRequest& axisRequest,
-                        const Cached& axisName );
-
-    // Check and set axis values.
-    void CheckAxis(double minValue,double maxValue,
-                   int axisType,MvRequest&,
-                   std::string title = "");
-
-    bool CheckLatLon(const std::string&,double,double,MvRequest&, const char *);  
-
-    virtual void SetVariables(const MvRequest&, bool) {}
-
-    // Check horizontal value
-    virtual bool CheckHorizontal(MvRequest &) = 0;
-
-    // Add values to a request
-    void AddValues ( MvRequest& dataRequest, std::vector<double>& dataVector, const char* variableName ); 
-
-    // Functions for generating matrix data.
-
-    // convert a netcdf file into a matrix file for use by magics.
-    bool NetCDFtoMatrix(MvIcon&,MvRequest&);
-
-    void GenerateData(FILE *fp,int startIndex,double yMin,
-                      double yMax,vector<double> &xvector,
-                      std::vector<double> &yvector, int nrPoints, 
-                      bool logax = false, bool modlev = false);
-
-    bool FindPressure(vector<double> &yvector,double pk,
-                      int &firstindex,int &nextindex, int);
-#endif
-
-    double latMin_, latMax_, lonMin_, lonMax_;
-    double yMin_, yMax_;
+    double latMin_{0.};
+    double latMax_{0.};
+    double lonMin_{0.};
+    double lonMax_{0.};
+    double yMin_{0.};
+    double yMax_{0.};
     std::string applicationName_;
-    MvRequest appViewReq_;  //original application view request
-
-private:
-    // No assignment
-    CommonXSectView& operator=(const CommonXSectView&);
+    MvRequest appViewReq_;  // original application view request
 };
