@@ -45,7 +45,7 @@ DataObject::DataObject(int dataUnitId, long offset, long offset2,
         return;
     }
     else if (strcmp(dt, "GRIB") == 0) {
-        int ndim                    = 1;
+        int ndim = 1;
         myRequest_("GRIB_POSITION") = offset;
         if (offset != offset2) {
             ndim = 2;
@@ -55,15 +55,14 @@ DataObject::DataObject(int dataUnitId, long offset, long offset2,
         }
 
         myRequest_("GRIB_DIMENSION") = ndim;
-        dimFlag_                     = dimFlag_ | ndim;
+        dimFlag_ = dimFlag_ | ndim;
     }
 }
 
 DataObject::DataObject(MvRequest& reqst) :
-    Presentable(reqst),
-    dimFlag_(0)
+    Presentable(reqst)
 {
-    //empty
+    // empty
 }
 
 DataObject::DataObject(const DataObject& old) :
@@ -74,7 +73,7 @@ DataObject::DataObject(const DataObject& old) :
     titleText_(old.titleText_),
     titleRequest_(old.titleRequest_)
 {
-    //segmentNameMap_ not copied.
+    // segmentNameMap_ not copied.
 }
 
 bool DataObject::AppendDataUnit(int dataunitId, long offset, long offset2, const MvRequest& req)
@@ -86,7 +85,7 @@ bool DataObject::AppendDataUnit(int dataunitId, long offset, long offset2, const
     // Update position and dimension parameters
     int ndim = 1;
     myRequest_("GRIB_POSITION") += offset;
-    if (offset != offset2)  //two dimensional data
+    if (offset != offset2)  // two dimensional data
     {
         ndim = 2;
         myRequest_("GRIB_POSITION") += offset2;
@@ -107,7 +106,7 @@ bool DataObject::Match(int dataunitId, const MvRequest& req)
         return false;
 
     // The request verbs are not the same -> return false
-    if (strcmp(myRequest_.getVerb(), req("DATA_TYPE")))
+    if (strcmp(myRequest_.getVerb(), req("DATA_TYPE")) != 0)
         return false;
 
     return true;
@@ -128,11 +127,11 @@ DataObject::DrawPriority(MvIconList& visdefList)
     // Create Priority string based on only the first visdef.
     // It assumes that all the other visdefs will have the same "priority"
     MvListCursor vdCursor;
-    vdCursor             = visdefList.begin();
-    MvIcon& visDef       = *(vdCursor);
+    vdCursor = visdefList.begin();
+    MvIcon& visDef = *(vdCursor);
     MvRequest visRequest = visDef.Request();
 
-    int visDefId     = visDef.Id();
+    int visDefId = visDef.Id();
     Cached drawPrior = tmpDrawingPriority.DrawSegmentName(myDataUnitId_,
                                                           visRequest,
                                                           visDefId);
@@ -156,9 +155,9 @@ DataObject::DrawPriority()
     // Retrieve the DataUnit
     // (the object only stores its dataunit Id and index)
     MvIcon dataUnit;
-    //if ( dataBase.RetrieveDataUnit (myDataUnitId_, dataUnit) == false)
+    // if ( dataBase.RetrieveDataUnit (myDataUnitId_, dataUnit) == false)
     if (dataBase.RetrieveIconFromList(DB_DATAUNIT, myDataUnitId_, dataUnit) == false)
-        return DrawPriorMap();
+        return {};
 
     // Retrieve the VisDefs associated to the DataUnit
     MvIconList visdefList;
@@ -193,7 +192,7 @@ void DataObject::DrawVisDef(MvIcon& visDef, std::string& /* segmentName */)
 void DataObject::DrawDataVisDef()
 {
     // Retrieve the Graphics Engine and the data base info
-    GraphicsEngine& ge       = GetGraphicsEngine();
+    GraphicsEngine& ge = GetGraphicsEngine();
     MvIconDataBase& dataBase = IconDataBase();
 
     // Retrieve the DataUnit
@@ -233,7 +232,7 @@ void DataObject::DrawDataVisDef()
     // all valid visdefs. After calling ge.Draw, it contains only the visdefs
     // used in the plotting. If this is not the first plot, the Drop scheme (executed
     // earlier) should update (add/replace/delete) the list of visdefs accordingly.
-    //F   if ( first && defaultVD )
+    // F   if ( first && defaultVD )
     if (defaultVD) {
         // Insert new VD in the dataBase connect to the superpage
         int spId = this->FindSuperPage()->Id();
@@ -294,7 +293,7 @@ bool DataObject::RetrieveMyVisDefList(MvIcon& dataUnit, MvIconList& visdefList)
     if (dataBase.RetrieveVisDefList(dataUnit, visdefList)) {
         // Check if there is any valid visdef
         if (ObjectList::CheckValidVisDefList(myRequest_.getVerb(), visdefList))
-            return usingDefault;  //found a valid visdef
+            return usingDefault;  // found a valid visdef
     }
 
     // Check if there is a parent DataUnit
@@ -307,7 +306,7 @@ bool DataObject::RetrieveMyVisDefList(MvIcon& dataUnit, MvIconList& visdefList)
 
         // Check that the parent has a valid visdef for this dataunit
         if (ObjectList::CheckValidVisDefList(myRequest_.getVerb(), visdefList))
-            return usingDefault;  //found a valid visdef
+            return usingDefault;  // found a valid visdef
     }
 
     // There is no visdef associated to the dataunit -> get another visdef
@@ -372,7 +371,7 @@ DataObject::SetTitle ( const MvRequest& treq )
 
 void DataObject::GetTitle(MvRequest& rqst, int* order)
 {
-    int i;
+    int i = 0;
 
     // Set TEXT_ORIGIN, internal parameter between PlotMod and Magics
     this->SetTextOrigin(rqst);
@@ -386,7 +385,7 @@ void DataObject::GetTitle(MvRequest& rqst, int* order)
         rqst("$METVIEW_TITLE_PACKAGE_COUNT") = *order;
 
         Cached titlePackageName = "$METVIEW_TITLE_PACKAGE_";
-        titlePackageName        = titlePackageName + *order;
+        titlePackageName = titlePackageName + *order;
 
         rqst(titlePackageName) = titleText_[0];
         for (i = 1; i < nValues; i++)
@@ -397,7 +396,7 @@ void DataObject::GetTitle(MvRequest& rqst, int* order)
 
         (*order)++;
     }
-    else  //Title defined by the user
+    else  // Title defined by the user
     {
         // Merge 2 TEXT requests
         const char* origin = rqst("TEXT_ORIGIN");
@@ -406,7 +405,7 @@ void DataObject::GetTitle(MvRequest& rqst, int* order)
             char saux[13];
             strcpy(saux, "TEXT_LINE_");
             int size = strlen(saux);
-            int j    = myRequest_("TEXT_LINE_COUNT");
+            int j = myRequest_("TEXT_LINE_COUNT");
             rqst.unsetParam("TEXT_LINE_COUNT");
             for (i = 1; i <= j; i++) {
                 sprintf(saux + size, "%d", i);
@@ -419,7 +418,7 @@ void DataObject::GetTitle(MvRequest& rqst, int* order)
         else if (origin == Cached("BOTH") || origin == Cached("MERGE"))
             metview::MergeTextParameters(myRequest_, rqst, false);
 
-        ///F		( *order ) = rqst("TEXT_LINE_COUNT");
+        /// F		( *order ) = rqst("TEXT_LINE_COUNT");
 
         // Now we have already set the Text request.
         // For the Magics point of view, if the title came from
@@ -434,7 +433,7 @@ void DataObject::GetTitle(MvRequest& rqst, int* order)
 void DataObject::SetTextOrigin(MvRequest& request)
 {
     // If TEXT_ORIGIN has already been set, return.
-    if ( metview::IsParameterSet(request, "TEXT_ORIGIN")) {
+    if (metview::IsParameterSet(request, "TEXT_ORIGIN")) {
         std::string val = (const char*)request("TEXT_ORIGIN");
         if (val != "NOTSET")
             return;
@@ -444,18 +443,18 @@ void DataObject::SetTextOrigin(MvRequest& request)
     // been set (these are PlotMod parameters and
     // must not be sent to Magics)
     MvRequest reqAux = request;
-    bool expand      = false;
-    if ( metview::IsParameterSet(reqAux, "TEXT_AUTOMATIC"))
+    bool expand = false;
+    if (metview::IsParameterSet(reqAux, "TEXT_AUTOMATIC"))
         request.unsetParam("TEXT_AUTOMATIC");
     else
         expand = true;
 
-    if ( metview::IsParameterSet(reqAux, "TEXT_USER"))
+    if (metview::IsParameterSet(reqAux, "TEXT_USER"))
         request.unsetParam("TEXT_USER");
     else
         expand = true;
 
-    if ( metview::IsParameterSet(reqAux, "TEXT_MERGE"))
+    if (metview::IsParameterSet(reqAux, "TEXT_MERGE"))
         request.unsetParam("TEXT_MERGE");
     else
         expand = true;
@@ -466,8 +465,8 @@ void DataObject::SetTextOrigin(MvRequest& request)
 
     // Set TEXT_ORIGIN
     Cached yes("YES");
-    bool autoText  = (reqAux("TEXT_AUTOMATIC") == yes) ? true : false;
-    bool userText  = (reqAux("TEXT_USER") == yes) ? true : false;
+    bool autoText = (reqAux("TEXT_AUTOMATIC") == yes) ? true : false;
+    bool userText = (reqAux("TEXT_USER") == yes) ? true : false;
     bool mergeText = (reqAux("TEXT_MERGE") == yes) ? true : false;
 
     if (mergeText)
@@ -532,7 +531,7 @@ bool DataObject::GetLegend(MvRequest& rqst, int* order)
                 rqst(titlePackageName) += (legendPackage.second)[i];
 
             Cached fileName = Cached("METVIEW_LEGEND_STORE_FILE_") + *order;
-            rqst(fileName)  = (legendPackage.first).c_str();
+            rqst(fileName) = (legendPackage.first).c_str();
 
             (*order)++;
             if (*order > MAX_LEGENDS_PACKAGE)
@@ -641,7 +640,7 @@ void DataObject::DataUnit(MvIcon& dataUnit)
     MvIconDataBase& dataBase = IconDataBase();
 
     // Retrieve the DataUnit
-    //if (dataBase.RetrieveDataUnit (myDataUnitId_, dataUnit) == false)
+    // if (dataBase.RetrieveDataUnit (myDataUnitId_, dataUnit) == false)
     if (dataBase.RetrieveIconFromList(DB_DATAUNIT, myDataUnitId_, dataUnit) == false) {
         MvLog().popup().err() << "uPlot DataObject::DataUnit-> No Data Unit";
         return;
@@ -656,9 +655,9 @@ void DataObject::DataUnit(MvIcon& dataUnit)
 void DataObject::UpdateVisDef(MvRequest dataUnit, MvIconList& iconList)
 {
     // Get application name without the prefix
-    std::string verb   = dataUnit.getVerb();
-    size_t ipos        = verb.find("_");
-    std::string sapp   = verb.substr(ipos + 1);
+    std::string verb = dataUnit.getVerb();
+    size_t ipos = verb.find("_");
+    std::string sapp = verb.substr(ipos + 1);
     std::string prefix = verb.substr(0, ipos);
 
     // Update visdef parameters only for the following applications
@@ -674,7 +673,7 @@ void DataObject::UpdateVisDef(MvRequest dataUnit, MvIconList& iconList)
             // Update only MSYMB visdefs
             MvListCursor vdc;
             for (vdc = iconList.begin(); vdc != iconList.end(); ++vdc) {
-                MvIcon& visDef      = *(vdc);
+                MvIcon& visDef = *(vdc);
                 MvRequest vdRequest = visDef.Request();
                 if (strcmp(vdRequest.getVerb(), "MSYMB") == 0) {
                     vdRequest("SYMBOL_TABLE_MODE") = "ADVANCED";
@@ -695,7 +694,7 @@ void DataObject::UpdateVisDef(MvRequest dataUnit, MvIconList& iconList)
             // Update only MWIND visdefs
             MvListCursor vdc;
             for (vdc = iconList.begin(); vdc != iconList.end(); ++vdc) {
-                MvIcon& visDef      = *(vdc);
+                MvIcon& visDef = *(vdc);
                 MvRequest vdRequest = visDef.Request();
                 if (strcmp(vdRequest.getVerb(), "MWIND") == 0) {
                     vdRequest("WIND_ADVANCED_METHOD") = "ON";
@@ -708,7 +707,7 @@ void DataObject::UpdateVisDef(MvRequest dataUnit, MvIconList& iconList)
         // Update MGRAPH visdefs
         MvListCursor vdc;
         for (vdc = iconList.begin(); vdc != iconList.end(); ++vdc) {
-            MvIcon& visDef      = *(vdc);
+            MvIcon& visDef = *(vdc);
             MvRequest vdRequest = visDef.Request();
             if (strcmp(vdRequest.getVerb(), "MGRAPH") == 0) {
                 vdRequest("GRAPH_TYPE") = "BAR";
