@@ -25,9 +25,9 @@ public:
     DataToolManager(const char* kw);
 
     // Destructor
-    ~DataToolManager() {}
+    ~DataToolManager() override = default;
 
-    void serve(MvRequest&, MvRequest&);
+    void serve(MvRequest&, MvRequest&) override;
 
 protected:
 };
@@ -45,7 +45,7 @@ public:
     // Methods
 
     // Perform actions after receiving response from the data tools
-    virtual void endOfTask(MvTask*);
+    void endOfTask(MvTask*) override;
 
     // Call data tiik
     void CallDataTool(MvRequest& in, MvRequest& out);
