@@ -72,8 +72,8 @@ class Presentable;
 // Class Device Factory - clones a new Device on Request
 struct DeviceFactoryTraits
 {
-    typedef Device Type;
-    typedef const MvRequest& Parameter;
+    using Type = Device;
+    using Parameter = const MvRequest&;
     static Cached FactoryName(Parameter);
     static Type* DefaultObject(Parameter);
 };
@@ -93,7 +93,7 @@ public:
     Device(const MvRequest& deviceRequest);
 
     // Destructor
-    virtual ~Device();
+    ~Device() override;
 
     // Visitor methods
     virtual void Initialise(Presentable& p);
@@ -135,5 +135,8 @@ protected:
 private:
     // No copy allowed
     Device(const Device&);
-    Device& operator=(const Device&) { return *this; }
+    Device& operator=(const Device&)
+    {
+        return *this;
+    }
 };
