@@ -41,20 +41,20 @@ GeoTool::GeoTool(MvRequest& req, QWidget* parent) :
     setAttribute(Qt::WA_DeleteOnClose);
     setWindowTitle("Metview - Geography Tool");
 
-    //Initial size
+    // Initial size
     setInitialSize(600, 400);
 
-    //uPlot area. Define the whole lot as central widget
+    // uPlot area. Define the whole lot as central widget
     auto* w = new QWidget;
     setCentralWidget(w);
     auto* vlay = new QVBoxLayout(w);
     vlay->addWidget(plotView_);
 
-    //Setup the bottom layout (coordinates + buttons)
+    // Setup the bottom layout (coordinates + buttons)
     auto* hlay = new QHBoxLayout();
     vlay->addLayout(hlay);
     auto* coordLabel = new QLabel(tr("S/W/N/E:"));
-    coordEdit_       = new QLineEdit();
+    coordEdit_ = new QLineEdit();
     coordEdit_->setMinimumSize(170, 0);
     coordEdit_->setText(tr(coord.toStdString().c_str()));
     auto* okPb = new QPushButton(tr("&OK"));
@@ -67,12 +67,12 @@ GeoTool::GeoTool(MvRequest& req, QWidget* parent) :
     hlay->addWidget(okPb);
     hlay->addWidget(cancelPb);
 
-    //Setup the actions
+    // Setup the actions
     setupZoomActions();
     setupViewActions();
     setupInputSelectionActions();
 
-    //Setup menus and toolbars
+    // Setup menus and toolbars
     setupMenus(menuItems_, MvQMainWindow::ToolBarOnlyOption);
 
     isFirstMap_ = true;
@@ -94,18 +94,18 @@ GeoTool::GeoTool(MvRequest& req, QWidget* parent) :
     connect(this, SIGNAL(pointChanged(double, double)),
             plotView_, SLOT(slotChangePoint(double, double)));
 
-    //Read qt geometry settings
+    // Read qt geometry settings
     readSettings();
 
-    //Enable antialias
+    // Enable antialias
     slotEnableAntialias(true);
 
-    //Hide view toolbar
+    // Hide view toolbar
     QToolBar* tb = findToolBar(MvQMainWindow::ViewMenu);
     if (tb)
         tb->hide();
 
-    //Size is set to Fit to window
+    // Size is set to Fit to window
     int sizeIndex = predefSizeValues_.indexOf(uPlotBase::FitToWindow);
     if (sizeIndex != -1)
         sizeCombo_->setCurrentIndex(sizeIndex);
@@ -120,7 +120,7 @@ GeoTool::~GeoTool()
 
 void GeoTool::setupInputSelectionActions()
 {
-    //Selection action
+    // Selection action
     auto* actionSelection = new QAction(this);
     actionSelection->setObjectName(QString::fromUtf8("actionSelection"));
     actionSelection->setCheckable(true);
@@ -149,8 +149,8 @@ void GeoTool::setupInputSelectionActions()
     }
     actionSelection->setText(selectionName);
 
-    //Clear selection action
-    QAction *actionClear, *actionAll, *actionChDir;
+    // Clear selection action
+    QAction *actionClear = nullptr, *actionAll = nullptr, *actionChDir = nullptr;
     if (inputType_ == "AREA") {
         actionClear = new QAction(this);
         actionClear->setObjectName(QString::fromUtf8("actionClear"));
@@ -297,7 +297,7 @@ void GeoTool::setupInputSelectionActions()
 QString GeoTool::InitializeParams(MvRequest& req)
 {
     // Create a default superpage request
-    spRequest_          = ObjectList::CreateDefaultRequest("PLOT_SUPERPAGE");
+    spRequest_ = ObjectList::CreateDefaultRequest("PLOT_SUPERPAGE");
     spRequest_("_NAME") = "Geographical Tool Window";
 
     // Get input type
@@ -306,19 +306,19 @@ QString GeoTool::InitializeParams(MvRequest& req)
     if (const char* cv = req("INPUT_TYPE"))
         inputType_ = std::string(cv);
     else
-        return QString("ERROR");
+        return {"ERROR"};
 
     if (inputType_ == "MAP")
         inputType_ = "AREA";
 
-    //Get the paramater name
+    // Get the paramater name
     if (const char* cv = req("INPUT_PARAM"))
         inputPar_ = std::string(cv);
 
     // Update size
-    spRequest_("CUSTOM_WIDTH")  = req("CUSTOM_WIDTH");
+    spRequest_("CUSTOM_WIDTH") = req("CUSTOM_WIDTH");
     spRequest_("CUSTOM_HEIGHT") = req("CUSTOM_HEIGHT");
-    spRequest_("LAYOUT_SIZE")   = "CUSTOM";
+    spRequest_("LAYOUT_SIZE") = "CUSTOM";
     req.advance();  // skip EDIT_MAP request
 
     // Create a coastline request from user's preferences
@@ -326,18 +326,18 @@ QString GeoTool::InitializeParams(MvRequest& req)
 
     // Create a default mapview request
     // Customize dimensions and add coastlines
-    MvRequest viewRequest             = ObjectList::CreateDefaultRequest(DEFAULTVIEW.c_str());
+    MvRequest viewRequest = ObjectList::CreateDefaultRequest(DEFAULTVIEW.c_str());
     viewRequest("SUBPAGE_X_POSITION") = 7;
     viewRequest("SUBPAGE_Y_POSITION") = 7;
-    viewRequest("SUBPAGE_X_LENGTH")   = 86;
-    viewRequest("SUBPAGE_Y_LENGTH")   = 86,
-    viewRequest("COASTLINES")         = coastRequest;
+    viewRequest("SUBPAGE_X_LENGTH") = 86;
+    viewRequest("SUBPAGE_Y_LENGTH") = 86,
+    viewRequest("COASTLINES") = coastRequest;
 
     // Initialize parameters
     QString coord;
     geoRequest_.setVerb("INPUT");
     if (inputType_ == "POINT") {
-        //If there is no par specified we need to guess it
+        // If there is no par specified we need to guess it
         if (inputPar_.empty()) {
             if (static_cast<const char*>(req("POINT")))
                 inputPar_ = "POINT";
@@ -345,7 +345,7 @@ QString GeoTool::InitializeParams(MvRequest& req)
                 inputPar_ = "POSITION";
             else {
                 MvLog().popup().err() << "GeoTool-> Invalid parameter value. Valid values: POINT/POSITION";
-                return QString("ERROR");
+                return {"ERROR"};
             }
         }
 
@@ -354,13 +354,13 @@ QString GeoTool::InitializeParams(MvRequest& req)
         coord = (const char*)req(inputPar_.c_str(), 0) % QChar('/') % (const char*)req(inputPar_.c_str(), 1);
     }
     else if (inputType_ == "LINE") {
-        //If there is no par specified we need to guess it
+        // If there is no par specified we need to guess it
         if (inputPar_.empty()) {
             if (static_cast<const char*>(req("LINE")))
                 inputPar_ = "LINE";
             else {
                 MvLog().popup().err() << "GeoTool-> No parameter is specified for line helper";
-                return QString("ERROR");
+                return {"ERROR"};
             }
         }
 
@@ -371,7 +371,7 @@ QString GeoTool::InitializeParams(MvRequest& req)
         coord = requestToCoord(req, inputPar_.c_str());
     }
     else if (inputType_ == "AREA") {
-        //If there is no par specified we need to guess it
+        // If there is no par specified we need to guess it
         if (inputPar_.empty()) {
             if (static_cast<const char*>(req("AREA")))
                 inputPar_ = "AREA";
@@ -381,16 +381,16 @@ QString GeoTool::InitializeParams(MvRequest& req)
                 inputPar_ = "area";
             else {
                 MvLog().popup().err() << "GeoTool-> No parameter is specified for area helper";
-                return QString("ERROR");
+                return {"ERROR"};
             }
         }
 
         /*if(static_cast<const char*>(req("AREA")))
-	  		areaParam_="AREA";
-		else if(static_cast<const char*>(req("FLEXTRA_AREA")))
-		  	areaParam_="FLEXTRA_AREA";
-		else if(static_cast<const char*>(req("area")))
-		  	areaParam_="area";*/
+            areaParam_="AREA";
+        else if(static_cast<const char*>(req("FLEXTRA_AREA")))
+            areaParam_="FLEXTRA_AREA";
+        else if(static_cast<const char*>(req("area")))
+            areaParam_="area";*/
 
         geoRequest_(inputPar_.c_str()) = req(inputPar_.c_str(), 0);
         geoRequest_(inputPar_.c_str()) += req(inputPar_.c_str(), 1);
@@ -415,8 +415,8 @@ QString GeoTool::InitializeParams(MvRequest& req)
     // Finalize superpage request
     // Create default page and add view to this request
     MvRequest pageRequest = ObjectList::CreateDefaultRequest("PLOT_PAGE");
-    pageRequest("VIEW")   = viewRequest;
-    spRequest_("PAGES")   = pageRequest;
+    pageRequest("VIEW") = viewRequest;
+    spRequest_("PAGES") = pageRequest;
 
     return coord;
 }
@@ -458,30 +458,27 @@ void GeoTool::newRequestForDriversBegin()
         prevActiveSceneId_ = activeScene_->layout().id();
         if (prevActiveSceneId_.empty()) {
             MgQLayoutItem* projItem = activeScene_->firstProjectorItem();
-            prevActiveSceneId_      = projItem->layout().id();
+            prevActiveSceneId_ = projItem->layout().id();
         }
     }
     else {
         prevActiveSceneId_.clear();
     }
 
-    activeScene_ = 0;
+    activeScene_ = nullptr;
 }
 
 
 void GeoTool::newRequestForDriversEnd()
 {
-    //Select the active scene
+    // Select the active scene
     if (!activeScene_) {
         if (!prevActiveSceneId_.empty()) {
             foreach (MgQSceneItem* item, plotScene_->sceneItems()) {
                 MgQLayoutItem* projItem = item->firstProjectorItem();
-                if (item->layout().id() == prevActiveSceneId_) {
-                    activeScene_ = item;
-                    break;
-                }
-                else if (item->layout().id().empty() && projItem &&
-                         prevActiveSceneId_ == projItem->layout().id()) {
+                if ((item->layout().id() == prevActiveSceneId_) ||
+                    (item->layout().id().empty() && projItem &&
+                     prevActiveSceneId_ == projItem->layout().id())) {
                     activeScene_ = item;
                     break;
                 }
@@ -494,25 +491,25 @@ void GeoTool::newRequestForDriversEnd()
         }
     }
 
-    //Resize without rendering!!
+    // Resize without rendering!!
     changeSize(sizeCombo_->itemData(sizeCombo_->currentIndex(), Qt::UserRole).toInt(), false);
 
-    //Load steps/layers and generate layer thumbnails - No rendering at this point!
-    //It tries to set the current step for all the scenes!
-    //The current step should be correctly set at least for the active scene.
+    // Load steps/layers and generate layer thumbnails - No rendering at this point!
+    // It tries to set the current step for all the scenes!
+    // The current step should be correctly set at least for the active scene.
     plotScene_->updateAfterNewRequest();
 
-    //Zoom stack
+    // Zoom stack
     zoomStackWidget_->reset(activeScene_, false);
     updateZoomActionState();
 
-    //Magnifier, cursordata etc
+    // Magnifier, cursordata etc
     plotView_->resetEnd();
 
-    //NOW RENDER IT! We render the whole scene into the pixmap cache at this point!
+    // NOW RENDER IT! We render the whole scene into the pixmap cache at this point!
     plotScene_->sceneItemChanged();
 
-    //Emit a signal that the plot windows has been updated
+    // Emit a signal that the plot windows has been updated
     emit plotWindowUpdated();
 }
 
@@ -543,7 +540,7 @@ void GeoTool::slotCoordChanged()
         double blLon = clist.at(1).toDouble();
         double trLat = clist.at(2).toDouble();
         double trLon = clist.at(3).toDouble();
-        //plotView_->DrawRectangle(north,west,south,east);
+        // plotView_->DrawRectangle(north,west,south,east);
 
         emit areaChanged(blLat, blLon, trLat, trLon);
     }
@@ -552,7 +549,7 @@ void GeoTool::slotCoordChanged()
         double lon1 = clist.at(1).toDouble();
         double lat2 = clist.at(2).toDouble();
         double lon2 = clist.at(3).toDouble();
-        //plotView_->DrawRectangle(north,west,south,east);
+        // plotView_->DrawRectangle(north,west,south,east);
 
         emit lineChanged(lat1, lon1, lat2, lon2);
     }
@@ -560,7 +557,7 @@ void GeoTool::slotCoordChanged()
         double lat = clist.at(0).toDouble();
         double lon = clist.at(1).toDouble();
 
-        //plotView_->DrawRectangle(north,west,south,east);
+        // plotView_->DrawRectangle(north,west,south,east);
 
         emit pointChanged(lat, lon);
     }
@@ -638,40 +635,24 @@ void GeoTool::slotPointIsUndefined()
 
 void GeoTool::slotPlotWindowUpdated()
 {
-    if (inputType_ == "AREA") {
-        if (isFirstMap_ == true) {
-            //plotView_->slotSelectAllArea();
-            slotCoordChanged();
-            isFirstMap_ = false;
-        }
-        //slotCoordChanged();
-    }
-    else if (inputType_ == "LINE") {
+    if (inputType_ == "AREA" || inputType_ == "LINE" || inputType_ == "POINT") {
         if (isFirstMap_ == true) {
             slotCoordChanged();
             isFirstMap_ = false;
         }
-        //slotCoordChanged();
-    }
-    else if (inputType_ == "POINT") {
-        if (isFirstMap_ == true) {
-            slotCoordChanged();
-            isFirstMap_ = false;
-        }
-        //slotCoordChanged();
     }
 }
 
-//void GeoTool::slotClearSelection()
+// void GeoTool::slotClearSelection()
 //{
 //	slotAreaIsUndefined();
 //	plotView_->slotClearArea();
-//}
+// }
 
 QString GeoTool::requestToCoord(MvRequest& req, const char* param)
 {
     if (!param)
-        return QString();
+        return {};
 
     QString coord = (const char*)req(param, 0) % QChar('/') %
                     (const char*)req(param, 1) % QChar('/') %
