@@ -51,15 +51,15 @@ public:
     GeopointsDecoder(const MvRequest& inRequest);
 
     // Destructor
-    virtual ~GeopointsDecoder();
+    ~GeopointsDecoder() override;
 
     // Overridden methods from Decoder class
     // Returns true first time it's called
-    virtual bool ReadNextData();
+    bool ReadNextData() override;
 
-    virtual MatchingInfo CreateMatchingInfo();
+    MatchingInfo CreateMatchingInfo() override;
 
-    virtual bool UpdateDataRequest(MvRequest&);
+    bool UpdateDataRequest(MvRequest&) override;
 
 private:
     // No copy allowed
