@@ -61,10 +61,10 @@ public:
     MagicsGraphicsEngine(Presentable& owner);
 
     // Destructor
-    ~MagicsGraphicsEngine();
+    ~MagicsGraphicsEngine() override;
 
     // Methods
-    virtual Canvas* MakeCanvas(Device&, const Rectangle&, const PaperSize&, int) const;
+    Canvas* MakeCanvas(Device&, const Rectangle&, const PaperSize&, int) const override;
 
     // Draws a dataUnit+visDef onto a device
     // REQUIRE: 1. dataUnit must provide a valid request, which contains
@@ -73,7 +73,7 @@ public:
     //             whithin the dataUnit (where applicable)
     //          3. List of Visdefs (1D and 2D)
     //          4. data unit n-dim flag: 0-not defined, 1-1D, 2-2D, 3-1D&2D
-    virtual void DrawDataVisDef(MvIcon&, MvRequest&, MvIconList&, int = 0);
+    void DrawDataVisDef(MvIcon&, MvRequest&, MvIconList&, int = 0) override;
 
     // Draws a dataUnit onto a device
     // REQUIRE: 1. dataUnit must provide a valid request, which contains
@@ -81,25 +81,25 @@ public:
     //          2. dataUnitIndex indicates the location of the field/obs
     //             whithin the dataUnit (where applicable)
     //          3. Device must have been pre-configured
-    virtual void DrawDataUnit(MvIcon&, MvRequest&, MvIcon&);
+    void DrawDataUnit(MvIcon&, MvRequest&, MvIcon&) override;
 
-    virtual void DrawNewPage(MvRequest&);
-    virtual void Draw(const MvRequest&, bool = false);
+    void DrawNewPage(MvRequest&) override;
+    void Draw(const MvRequest&, bool = false) override;
 
-    virtual void DrawProlog();
-    virtual void DrawPageHeader(Canvas&);
+    void DrawProlog() override;
+    void DrawPageHeader(Canvas&) override;
     // virtual void DrawTrailer    ( Canvas& );  //CHECK IF THIS IS STILL NEEDED
-    virtual void DrawTrailer(MvRequest&);
+    void DrawTrailer(MvRequest&) override;
 
-    virtual void StartPicture(const char*);
-    virtual void EndPicture();
+    void StartPicture(const char*) override;
+    void EndPicture() override;
 
     // Translate METVIEW calls into MAGICS calls
     virtual void TranslateVisDefRequest(MvIconList&, MvRequest&, MvRequest&);
 
 private:
-    MvRequest serviceRequest_;  //temporary request
-    MvRequest fullRequest_;     //full request
+    MvRequest serviceRequest_;  // temporary request
+    MvRequest fullRequest_;     // full request
     std::string drawType_;
 
     double ComputeAspectRatio(Canvas& canvas, MvRequest&);
